@@ -29,6 +29,7 @@
 #include "tasks_items.h"
 #include "contacts.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "options_prefs.h"
 #include "options_gui_tasks.h"
 #include "calendar_notes.h"
@@ -306,6 +307,8 @@ GDate *tmpdate;
 
 /*------------------------------------------------------------------------------*/
 
+#ifdef TASKS_ENABLED
+
 gint
 check_add_tasks (GDate *date, gboolean count, GUI *appGUI)
 {
@@ -360,8 +363,12 @@ gint i;
 	return i;
 }
 
+#endif  /* TASKS_ENABLED */
+
 /*------------------------------------------------------------------------------*/
 
+#ifdef CONTACTS_ENABLED
+
 gint
 check_add_contacts (GDate *sdate, gboolean count, GUI *appGUI)
 {
@@ -424,6 +431,8 @@ gint i, age, syear;
 	return i;
 }
 
+#endif /* CONTACTS_ENABLED */
+
 /*------------------------------------------------------------------------------*/
 
 gchar *
@@ -489,7 +498,7 @@ gint edays;
 GDate *date;
 
 	date = appGUI->cal->date;
-	gui_clear_text_buffer (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter);
+	utl_gui_clear_text_buffer (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter);
 
 	dday = g_date_get_day (date);
 	dmonth = g_date_get_month (date) - 1;
@@ -777,6 +786,7 @@ GDate *date;
 
 	if (appGUI->calendar_only != TRUE && appGUI->all_pages_added != FALSE && config.enable_day_mark) {
 
+#ifdef TASKS_ENABLED
 		/* check tasks */
 		i = check_add_tasks (date, TRUE, appGUI);
 
@@ -787,7 +797,9 @@ GDate *date;
 			check_add_tasks (date, FALSE, appGUI);
 			gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, "\n", -1);
 		}
+#endif  /* TASKS_ENABLED */
 
+#ifdef CONTACTS_ENABLED
 		/* check contacts */
 		i = check_add_contacts (date, TRUE, appGUI);
 
@@ -798,6 +810,8 @@ GDate *date;
 			check_add_contacts (date, FALSE, appGUI);
 			gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, "\n", -1);
 		}
+#endif  /* CONTACTS_ENABLED */
+
 	}
 
 #ifdef HAVE_LIBICAL
@@ -948,7 +962,7 @@ gchar tmpbuf[BUFFER_SIZE];
 	}
 
 	g_snprintf (tmpbuf, BUFFER_SIZE, "%s\n\n%s", _("Selected day note will be removed."), _("Continue?"));
-	response = gui_create_dialog (GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW (appGUI->main_window));
+	response = utl_gui_create_dialog (GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW (appGUI->main_window));
 
 	if (response == GTK_RESPONSE_YES) {
 		gtk_text_buffer_set_text (GTK_TEXT_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->cal->calendar_note_textview))), "", -1);
@@ -1385,6 +1399,7 @@ mouse_button_click_handler_cb (GtkWidget * widget, GdkEventButton * event, gpoin
 
 /*------------------------------------------------------------------------------*/
 
+#ifdef TASKS_ENABLED
 void
 popup_add_task_entry_selected_cb (gpointer user_data)
 {
@@ -1396,6 +1411,7 @@ popup_add_task_entry_selected_cb (gpointer user_data)
 	julian_date = utl_dmy_to_julian (cday, cmonth + 1, cyear);
 	tasks_add_edit_dialog_show (FALSE, julian_date, get_seconds_for_today(), appGUI);
 }
+#endif  /* TASKS_ENABLED */
 
 /*------------------------------------------------------------------------------*/
 
@@ -1417,12 +1433,14 @@ popup_browse_notes_cb (gpointer user_data)
 
 /*------------------------------------------------------------------------------*/
 
+#ifdef PRINTING_SUPPORT
 void
 calendar_print_cb (GtkWidget *widget, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
-    calendar_print (appGUI);
+    calendar_create_print_window (appGUI);
 }
+#endif /* PRINTING_SUPPORT */
 
 /*------------------------------------------------------------------------------*/
 
@@ -1462,7 +1480,9 @@ GError          *error = NULL;
 GtkActionGroup  *action_group = NULL;
 GtkWidget       *note_scrolledwindow;
 GtkWidget       *calendars_table;
+#ifdef TASKS_ENABLED
 GtkWidget       *popup_menu_add_task_entry;
+#endif  /* TASKS_ENABLED */
 GtkWidget       *popup_menu_separator;
 GtkWidget       *popup_menu_browse_notes;
 
@@ -1486,7 +1506,9 @@ const gchar *ui_info =
 "    <toolitem name=\"jump_to_date\" action=\"jump_to_date\" />\n"
 "    <toolitem name=\"full_year\" action=\"full_year\" />\n"
 "    <toolitem name=\"date_calc\" action=\"date_calc\" />\n"
+#ifdef PRINTING_SUPPORT
 "    <toolitem name=\"print\" action=\"print\" />\n"
+#endif /* PRINTING_SUPPORT */
 "    <separator name=\"sep2\" />\n"
 "    <toolitem name=\"edit_note\" action=\"edit_note\" />\n"
 "  </toolbar>\n";
@@ -1501,7 +1523,9 @@ GtkActionEntry entries[] = {
     { "next_year", OSMO_STOCK_NEXT_YEAR, _("Next year"), NULL, _("Next year"), NULL},
     { "jump_to_date", OSMO_STOCK_JUMPTO, _("Jump to date"), NULL, _("Jump to date"), NULL},
     { "full_year", OSMO_STOCK_FULLYEAR, _("Full-year calendar"), NULL, _("Full-year calendar"), NULL},   
+#ifdef PRINTING_SUPPORT
     { "print", OSMO_STOCK_PRINT, _("Print calendar"), NULL, _("Print calendar"), NULL },
+#endif /* PRINTING_SUPPORT */
     { "date_calc", OSMO_STOCK_CALCULATOR, _("Date calculator"), NULL, _("Date calculator"), NULL},
 };
 
@@ -1547,11 +1571,12 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
 
     appGUI->cal->notes_button = gtk_ui_manager_get_widget (uim_widget, "/toolbar/edit_note");
 
-    gtk_toolbar_set_tooltips (appGUI->cal->calendar_toolbar, config.enable_tooltips);
-
     if (appGUI->calendar_only == TRUE) {
-        gtk_widget_hide(appGUI->cal->notes_button);
-        gtk_widget_set_sensitive(appGUI->cal->notes_button, FALSE);
+        gtk_widget_hide (appGUI->cal->notes_button);
+        gtk_widget_set_sensitive (appGUI->cal->notes_button, FALSE);
+#ifdef PRINTING_SUPPORT
+        gtk_widget_hide (gtk_ui_manager_get_widget (uim_widget, "/toolbar/print"));
+#endif /* PRINTING_SUPPORT */
     }
 
     /*-------------------------------------------------------------------------------------*/
@@ -1578,8 +1603,10 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
                       G_CALLBACK(calendar_create_fullyear_window_cb), appGUI);
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/date_calc")), "clicked", 
                       G_CALLBACK(calendar_create_datecalc_window_cb), appGUI);
+#ifdef PRINTING_SUPPORT
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/print")), "clicked", 
                       G_CALLBACK(calendar_print_cb), appGUI);
+#endif /* PRINTING_SUPPORT */
 
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (uim_widget, "/toolbar/edit_note")), "toggled", 
                       G_CALLBACK(calendar_edit_note_cb), appGUI);
@@ -1608,11 +1635,14 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
     if (appGUI->calendar_only == FALSE) {
 
         appGUI->cal->popup_menu = gtk_menu_new();
+
+#ifdef TASKS_ENABLED
         popup_menu_add_task_entry = gtk_menu_item_new_with_label(_("Add task"));
         gtk_menu_shell_append(GTK_MENU_SHELL(appGUI->cal->popup_menu), popup_menu_add_task_entry);
         g_signal_connect_swapped(G_OBJECT(popup_menu_add_task_entry), "activate", 
                                  G_CALLBACK(popup_add_task_entry_selected_cb), appGUI);
         gtk_widget_show(popup_menu_add_task_entry);
+#endif  /* TASKS_ENABLED */
 
         appGUI->cal->popup_menu_select_day_color_entry = gtk_menu_item_new_with_label(_("Select day color"));
         gtk_menu_shell_append(GTK_MENU_SHELL(appGUI->cal->popup_menu), appGUI->cal->popup_menu_select_day_color_entry);
@@ -1778,13 +1808,15 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
         gtk_container_add (GTK_CONTAINER (alignment), label);
 
         if (config.default_stock_icons) {
-            appGUI->cal->n_close_button = gui_stock_button(GTK_STOCK_CLOSE, FALSE);
+            appGUI->cal->n_close_button = utl_gui_stock_button (GTK_STOCK_CLOSE, FALSE);
         } else {
-            appGUI->cal->n_close_button = gui_stock_button(OSMO_STOCK_BUTTON_CLOSE, FALSE);
+            appGUI->cal->n_close_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLOSE, FALSE);
         }
         GTK_WIDGET_UNSET_FLAGS(appGUI->cal->n_close_button, GTK_CAN_FOCUS);
         gtk_button_set_relief (GTK_BUTTON(appGUI->cal->n_close_button), GTK_RELIEF_NONE);
-        gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->cal->n_close_button, _("Close note panel"), NULL);
+		if (config.enable_tooltips) {
+			gtk_widget_set_tooltip_text (appGUI->cal->n_close_button, _("Close note panel"));
+		}
         gtk_box_pack_end (GTK_BOX (hbox3), appGUI->cal->n_close_button, FALSE, FALSE, 1);
         g_signal_connect (G_OBJECT (appGUI->cal->n_close_button), "clicked",
                             G_CALLBACK (calendar_close_text_cb), appGUI);
@@ -1793,29 +1825,35 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
         gtk_widget_show (vseparator);
         gtk_box_pack_end (GTK_BOX (hbox3), vseparator, FALSE, TRUE, 0);
 
-        appGUI->cal->n_timeline_button = gui_stock_button(OSMO_STOCK_BUTTON_INSERT_TIMELINE, FALSE);
-        gtk_widget_show(appGUI->cal->n_timeline_button);
+        appGUI->cal->n_timeline_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_INSERT_TIMELINE, FALSE);
+        gtk_widget_show (appGUI->cal->n_timeline_button);
         GTK_WIDGET_UNSET_FLAGS(appGUI->cal->n_timeline_button, GTK_CAN_FOCUS);
         gtk_button_set_relief (GTK_BUTTON(appGUI->cal->n_timeline_button), GTK_RELIEF_NONE);
-        gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->cal->n_timeline_button, _("Insert timeline"), NULL);
+		if (config.enable_tooltips) {
+			gtk_widget_set_tooltip_text (appGUI->cal->n_timeline_button, _("Insert timeline"));
+		}
         gtk_box_pack_end (GTK_BOX (hbox3), appGUI->cal->n_timeline_button, FALSE, FALSE, 1);
         g_signal_connect (G_OBJECT (appGUI->cal->n_timeline_button), "clicked",
                             G_CALLBACK (calendar_insert_timeline_cb), appGUI);
 
-        appGUI->cal->n_clear_button = gui_stock_button(OSMO_STOCK_BUTTON_CLEAR, FALSE);
-        gtk_widget_show(appGUI->cal->n_clear_button);
-        GTK_WIDGET_UNSET_FLAGS(appGUI->cal->n_clear_button, GTK_CAN_FOCUS);
+        appGUI->cal->n_clear_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLEAR, FALSE);
+        gtk_widget_show (appGUI->cal->n_clear_button);
+        GTK_WIDGET_UNSET_FLAGS (appGUI->cal->n_clear_button, GTK_CAN_FOCUS);
         gtk_button_set_relief (GTK_BUTTON(appGUI->cal->n_clear_button), GTK_RELIEF_NONE);
-        gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->cal->n_clear_button, _("Clear text"), NULL);
+		if (config.enable_tooltips) {
+			gtk_widget_set_tooltip_text (appGUI->cal->n_clear_button, _("Clear text"));
+		}
         gtk_box_pack_end (GTK_BOX (hbox3), appGUI->cal->n_clear_button, FALSE, FALSE, 1);
         g_signal_connect (G_OBJECT (appGUI->cal->n_clear_button), "clicked",
                             G_CALLBACK (calendar_clear_text_cb), appGUI);
 
-        appGUI->cal->n_select_color_button = gui_stock_button(OSMO_STOCK_BUTTON_SELECT_COLOR, FALSE);
-        gtk_widget_show(appGUI->cal->n_select_color_button);
-        GTK_WIDGET_UNSET_FLAGS(appGUI->cal->n_select_color_button, GTK_CAN_FOCUS);
+        appGUI->cal->n_select_color_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_COLOR, FALSE);
+        gtk_widget_show (appGUI->cal->n_select_color_button);
+        GTK_WIDGET_UNSET_FLAGS (appGUI->cal->n_select_color_button, GTK_CAN_FOCUS);
         gtk_button_set_relief (GTK_BUTTON(appGUI->cal->n_select_color_button), GTK_RELIEF_NONE);
-        gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->cal->n_select_color_button, _("Select day color"), NULL);
+		if (config.enable_tooltips) {
+			gtk_widget_set_tooltip_text (appGUI->cal->n_select_color_button, _("Select day color"));
+		}
         gtk_box_pack_end (GTK_BOX (hbox3), appGUI->cal->n_select_color_button, FALSE, FALSE, 1);
         g_signal_connect (G_OBJECT (appGUI->cal->n_select_color_button), "clicked",
                             G_CALLBACK (calendar_select_color_cb), appGUI);
@@ -2100,7 +2138,7 @@ GdkColor color;
 
     color = (appGUI->cal->calendar)->style->base[GTK_WIDGET_STATE (appGUI->cal->calendar)];
     g_snprintf (tmpbuf, BUFFER_SIZE, "#%02X%02X%02X", color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
-    image = gui_create_color_swatch (tmpbuf);
+    image = utl_gui_create_color_swatch (tmpbuf);
     gtk_list_store_append(appGUI->cal->colors_category_store, &iter);
     gtk_list_store_set(appGUI->cal->colors_category_store, &iter, 0, image, 1, tmpbuf, 2, _("None"), 3, 0, -1);
     g_object_unref (image);
@@ -2111,7 +2149,7 @@ GdkColor color;
 
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->calendar_category_store), &iter, NULL, i++)) {
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->calendar_category_store), &iter, 1, &color_val, 2, &color_name, -1);
-        image = gui_create_color_swatch (color_val);
+        image = utl_gui_create_color_swatch (color_val);
         gtk_list_store_append(appGUI->cal->colors_category_store, &iter);
         gtk_list_store_set(appGUI->cal->colors_category_store, &iter, 0, image, 1, color_val, 2, color_name, 3, i, -1);
 
