@@ -22,6 +22,7 @@
 #include "calendar_fullyear.h"
 #include "i18n.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "options_prefs.h"
 #include "calendar.h"
 #include "calendar_notes.h"
@@ -256,7 +257,7 @@ gchar tmpbuf[BUFFER_SIZE];
 	            _("Number of weeks"), weeks_in_year (year),
 	            _("Number of weekend days"), w_days, (double) w_days / utl_get_days_per_year (year) * 100.0);
 
-	gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->cal->fullyear_window));
+	utl_gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->cal->fullyear_window));
 }
 
 /*------------------------------------------------------------------------------*/
@@ -333,7 +334,7 @@ guint       month, year;
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_misc_set_padding (GTK_MISC (label), 0, 4);
 
-	fy_spinbutton_adj = gtk_adjustment_new (utl_get_current_year (), JULIAN_GREGORIAN_YEAR, 9999, 1, 10, 10);
+	fy_spinbutton_adj = gtk_adjustment_new (utl_get_current_year (), JULIAN_GREGORIAN_YEAR, 9999, 1, 10, 0);
 	appGUI->cal->fy_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (fy_spinbutton_adj), 1, 0);
 	gtk_widget_show (appGUI->cal->fy_spinbutton);
 	g_signal_connect(appGUI->cal->fy_spinbutton, "value-changed", G_CALLBACK(change_year_spin_button_cb), appGUI);
@@ -343,14 +344,16 @@ guint       month, year;
 	gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), GTK_UPDATE_IF_VALID);
 
 	if (config.default_stock_icons) {
-		info_button = gui_stock_button (GTK_STOCK_INFO, FALSE);
+		info_button = utl_gui_stock_button (GTK_STOCK_INFO, FALSE);
 	} else {
-		info_button = gui_stock_button (OSMO_STOCK_BUTTON_INFO, FALSE);
+		info_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_INFO, FALSE);
 	}
 	GTK_WIDGET_UNSET_FLAGS(info_button, GTK_CAN_FOCUS);
 	gtk_widget_show (info_button);
 	g_signal_connect (info_button, "clicked", G_CALLBACK (year_info_cb), appGUI);
-	gtk_tooltips_set_tip (appGUI->osmo_tooltips, info_button, _("Year info"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (info_button, _("Year info"));
+	}
 	gtk_button_set_relief (GTK_BUTTON (info_button), GTK_RELIEF_NONE);
 	gtk_box_pack_start (GTK_BOX (hbox1), info_button, FALSE, FALSE, 2);
 
@@ -359,38 +362,44 @@ guint       month, year;
 	gtk_box_pack_start (GTK_BOX (hbox1), vseparator, FALSE, FALSE, 8);
 
 	if (config.default_stock_icons) {
-		prev_button = gui_stock_button (GTK_STOCK_GO_BACK, FALSE);
+		prev_button = utl_gui_stock_button (GTK_STOCK_GO_BACK, FALSE);
 	} else {
-		prev_button = gui_stock_button (OSMO_STOCK_BUTTON_PREV_YEAR, FALSE);
+		prev_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_PREV_YEAR, FALSE);
 	}
 	GTK_WIDGET_UNSET_FLAGS (prev_button, GTK_CAN_FOCUS);
 	gtk_widget_show (prev_button);
 	g_signal_connect (prev_button, "clicked", G_CALLBACK (change_to_previous_year_cb), appGUI);
-	gtk_tooltips_set_tip (appGUI->osmo_tooltips, prev_button, _("Previous year"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (prev_button, _("Previous year"));
+	}
 	gtk_button_set_relief (GTK_BUTTON (prev_button), GTK_RELIEF_NONE);
 	gtk_box_pack_start (GTK_BOX (hbox1), prev_button, FALSE, FALSE, 2);
 
 	if (config.default_stock_icons) {
-		appGUI->cal->cyear_button = gui_stock_button (GTK_STOCK_HOME, FALSE);
+		appGUI->cal->cyear_button = utl_gui_stock_button (GTK_STOCK_HOME, FALSE);
 	} else {
-		appGUI->cal->cyear_button = gui_stock_button (OSMO_STOCK_BUTTON_TODAY, FALSE);
+		appGUI->cal->cyear_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_TODAY, FALSE);
 	}
 	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->cyear_button, GTK_CAN_FOCUS);
 	gtk_widget_show (appGUI->cal->cyear_button);
 	g_signal_connect (appGUI->cal->cyear_button, "clicked", G_CALLBACK (change_to_current_year_cb), appGUI);
-	gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->cal->cyear_button, _("Current year"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (appGUI->cal->cyear_button, _("Current year"));
+	}
 	gtk_button_set_relief (GTK_BUTTON (appGUI->cal->cyear_button), GTK_RELIEF_NONE);
 	gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->cyear_button, FALSE, FALSE, 2);
 
 	if (config.default_stock_icons) {
-		next_button = gui_stock_button (GTK_STOCK_GO_FORWARD, FALSE);
+		next_button = utl_gui_stock_button (GTK_STOCK_GO_FORWARD, FALSE);
 	} else {
-		next_button = gui_stock_button (OSMO_STOCK_BUTTON_NEXT_YEAR, FALSE);
+		next_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_NEXT_YEAR, FALSE);
 	}
 	GTK_WIDGET_UNSET_FLAGS(next_button, GTK_CAN_FOCUS);
 	gtk_widget_show (next_button);
 	g_signal_connect (next_button, "clicked", G_CALLBACK (change_to_next_year_cb), appGUI);
-	gtk_tooltips_set_tip (appGUI->osmo_tooltips, next_button, _("Next year"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (next_button, _("Next year"));
+	}
 	gtk_button_set_relief (GTK_BUTTON (next_button), GTK_RELIEF_NONE);
 	gtk_box_pack_start (GTK_BOX (hbox1), next_button, FALSE, FALSE, 2);
 
