@@ -23,6 +23,7 @@
 #include "i18n.h"
 #include "calendar.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
 #include "options_prefs.h"
@@ -558,6 +559,8 @@ ical_events_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_d
 
     GUI *appGUI = (GUI *)user_data;
 
+	gtk_window_get_size (GTK_WINDOW (appGUI->cal->events_window),
+	                     &config.ib_window_size_x, &config.ib_window_size_y);
     gtk_widget_destroy (appGUI->cal->events_window);
 }
 
@@ -580,7 +583,7 @@ ical_events_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
     switch(event->keyval) {
 
         case GDK_Escape:
-            gtk_widget_destroy(appGUI->cal->events_window);
+			ical_events_window_close_cb (NULL, NULL, appGUI);
             return TRUE;
     }
 
@@ -697,14 +700,14 @@ gint i, k;
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, NULL, i++));
 
     if (i-1 == 0) {
-        gui_create_dialog(GTK_MESSAGE_INFO, _("No calendars defined"), GTK_WINDOW(appGUI->cal->fullyear_window));
+        utl_gui_create_dialog (GTK_MESSAGE_INFO, _("No calendars defined"), GTK_WINDOW(appGUI->cal->fullyear_window));
         return;
     }
 
     appGUI->cal->events_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title (GTK_WINDOW (appGUI->cal->events_window), _("iCalendar events"));
     gtk_window_set_position (GTK_WINDOW (appGUI->cal->events_window), GTK_WIN_POS_CENTER_ON_PARENT);
-    gtk_window_set_default_size (GTK_WINDOW(appGUI->cal->events_window), 550, 650);
+    gtk_window_set_default_size (GTK_WINDOW(appGUI->cal->events_window), config.ib_window_size_x, config.ib_window_size_y);
     gtk_window_set_modal (GTK_WINDOW (appGUI->cal->events_window), TRUE);
     g_signal_connect (G_OBJECT (appGUI->cal->events_window), "delete_event",
                       G_CALLBACK(ical_events_window_close_cb), appGUI);
@@ -1091,7 +1094,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
     sprintf (tmpbuf, "%s\n\n%s", _("The list will be cleared and all entries will be lost."), _("Are you sure?"));
 
-    response = gui_create_dialog(GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->cal->ical_export_window));
+    response = utl_gui_create_dialog (GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->cal->ical_export_window));
 
     if (response == GTK_RESPONSE_YES) {   
         gtk_list_store_clear (appGUI->cal->export_events_list_store);
@@ -1112,11 +1115,11 @@ gchar *text;
     GUI *appGUI = (GUI *)user_data;
     
     text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(appGUI->cal->export_day_note_textview));
-    gui_clear_text_buffer (text_buffer, &titer);
+    utl_gui_clear_text_buffer (text_buffer, &titer);
 
     if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
         gtk_tree_model_get (model, &iter, IE_COLUMN_DESCRIPTION, &text, -1);
-        gtk_text_buffer_insert(text_buffer, &titer, text, -1);
+        gtk_text_buffer_insert (text_buffer, &titer, text, -1);
         g_free (text);
     }
 }
@@ -1147,7 +1150,7 @@ gchar tmpbuf[BUFFER_SIZE];
         return;
     }
 
-    if (gui_check_overwrite_file (filename, appGUI->cal->ical_export_window, appGUI) != 0) {
+    if (utl_gui_check_overwrite_file (filename, appGUI->cal->ical_export_window, appGUI) != 0) {
         return;
     } else {
         g_unlink (filename);
@@ -1216,9 +1219,9 @@ gchar tmpbuf[BUFFER_SIZE];
 
     if (i >= 2) {
         sprintf(tmpbuf, "%s %d %s.\n", _("Done!"), i-1,
-            ngettext ("event exported", "events exported", i-1));
+				ngettext ("event exported", "events exported", i-1));
 
-        gui_create_dialog(GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW(appGUI->cal->ical_export_window));
+        utl_gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW(appGUI->cal->ical_export_window));
     }
 
     ical_export_window_close_cb (NULL, NULL, user_data);
@@ -1430,15 +1433,11 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (hbox4);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox4, FALSE, TRUE, 0);
 
-    if (config.default_stock_icons) {
-        remove_item_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
-    } else {
-        remove_item_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_REMOVE);
-    }
-    gtk_widget_show (remove_item_button);
-    GTK_WIDGET_UNSET_FLAGS (remove_item_button, GTK_CAN_FOCUS);
-    gtk_box_pack_end (GTK_BOX (hbox4), remove_item_button, FALSE, FALSE, 0);
-    g_signal_connect(remove_item_button, "clicked", G_CALLBACK(button_remove_date_cb), appGUI);
+    hbuttonbox = gtk_hbutton_box_new ();
+    gtk_widget_show (hbuttonbox);
+    gtk_box_pack_end (GTK_BOX (hbox4), hbuttonbox, FALSE, TRUE, 0);
+    gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
+    gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
     if (config.default_stock_icons) {
         clear_list_button = gtk_button_new_from_stock (GTK_STOCK_CLEAR);
@@ -1447,9 +1446,19 @@ gchar tmpbuf[BUFFER_SIZE];
     }
     gtk_widget_show (clear_list_button);
     GTK_WIDGET_UNSET_FLAGS (clear_list_button, GTK_CAN_FOCUS);
-    gtk_box_pack_end (GTK_BOX (hbox4), clear_list_button, FALSE, FALSE, 4);
+    gtk_container_add (GTK_CONTAINER (hbuttonbox), clear_list_button);
     g_signal_connect(clear_list_button, "clicked", G_CALLBACK(button_clear_list_cb), appGUI);
 
+    if (config.default_stock_icons) {
+        remove_item_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
+    } else {
+        remove_item_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_REMOVE);
+    }
+    gtk_widget_show (remove_item_button);
+    GTK_WIDGET_UNSET_FLAGS (remove_item_button, GTK_CAN_FOCUS);
+    gtk_container_add (GTK_CONTAINER (hbuttonbox), remove_item_button);
+    g_signal_connect(remove_item_button, "clicked", G_CALLBACK(button_remove_date_cb), appGUI);
+
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, TRUE, 0);
@@ -1477,7 +1486,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_editable_set_editable (GTK_EDITABLE(appGUI->cal->output_file_entry), FALSE);
 
     if (config.default_stock_icons) {
-        browse_dir_button = gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
+        browse_dir_button = utl_gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
     } else {
         browse_dir_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OPEN);
     }
