@@ -31,6 +31,7 @@
 #define ICAL_ENTRIES_FILENAME   "ical_files.xml"
 
 struct ics_entry {
+/* FIXME */
     DATE date;
     gchar *summary;
     gchar *description;
@@ -49,6 +50,14 @@ enum {
     ICAL_EVENTS_NUM_COLUMNS
 };
 
+enum {     
+    IE_COLUMN_DATE = 0,
+    IE_COLUMN_DATE_JULIAN,
+    IE_COLUMN_SUMMARY,
+    IE_COLUMN_DESCRIPTION,
+    ICAL_EXPORT_NUM_COLUMNS
+};
+
 void        calendar_display_ics    (GDate *date, GUI *appGUI);
 
 void        ics_initialize_timezone (void);
@@ -56,7 +65,7 @@ void        ics_check_if_valid      (GUI *appGUI);
 void        ics_calendar_refresh    (GUI *appGUI);
 
 void        ical_events_browser     (GUI *appGUI);
-
+void        ical_export             (GUI *appGUI);
 void        read_ical_entries       (GUI *appGUI);
 void        write_ical_entries      (GUI *appGUI);
 
