@@ -23,6 +23,7 @@
 #include "i18n.h"
 #include "calendar.h"
 #include "calendar_utils.h"
+#include "utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 
@@ -79,7 +80,7 @@ gint a;
     if (event->keyval == GDK_Return) {
 
         if (check_number(gtk_entry_get_text(GTK_ENTRY(appGUI->cal->day_entry))) == FALSE) {
-            sprintf(tmpbuf, "%d", get_current_day());
+            g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_get_current_day ());
             gtk_entry_set_text (GTK_ENTRY(appGUI->cal->day_entry), tmpbuf);
         }
 
@@ -110,7 +111,7 @@ gint a;
     if (event->keyval == GDK_Return) {
 
         if (check_number(gtk_entry_get_text(GTK_ENTRY(appGUI->cal->month_entry))) == FALSE) {
-            sprintf(tmpbuf, "%d", get_current_month()+1);
+            g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_get_current_month ());
             gtk_entry_set_text (GTK_ENTRY(appGUI->cal->month_entry), tmpbuf);
         }
 
@@ -149,7 +150,7 @@ GDate *cdate;
 			cdate = g_date_new_dmy (appGUI->cal->jday, appGUI->cal->jmonth, appGUI->cal->jyear);
 			g_return_if_fail (cdate != NULL);
 
-			calendar_jump_to_date (cdate, appGUI);
+			cal_jump_to_date (cdate, appGUI);
 			update_aux_calendars (appGUI);
 			g_date_free (cdate);
 		}
@@ -259,12 +260,12 @@ char tmpbuf[BUFFER_SIZE];
                         G_CALLBACK (year_key_press_cb), appGUI);
     gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->year_entry, FALSE, TRUE, 1);
 
-    sprintf(tmpbuf, "%d", get_current_day());
-    gtk_entry_set_text (GTK_ENTRY(appGUI->cal->day_entry), tmpbuf);
-    sprintf(tmpbuf, "%d", get_current_month()+1);
-    gtk_entry_set_text (GTK_ENTRY(appGUI->cal->month_entry), tmpbuf);
-    sprintf(tmpbuf, "%d", get_current_year());
-    gtk_entry_set_text (GTK_ENTRY(appGUI->cal->year_entry), tmpbuf);
+	g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_get_current_day ());
+	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->day_entry), tmpbuf);
+	g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_get_current_month ());
+	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->month_entry), tmpbuf);
+	g_snprintf (tmpbuf, BUFFER_SIZE, "%d", utl_get_current_year ());
+	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->year_entry), tmpbuf);
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
