@@ -23,6 +23,7 @@
 #include "calendar_notes.h"
 #include "i18n.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "options_prefs.h"
 #include "calendar.h"
 #include "stock_icons.h"
@@ -314,7 +315,7 @@ GDate *date;
 							key = xmlNodeListGetString (doc, category_node->xmlChildrenNode, 1);
 							prop = xmlGetProp (category_node, (const xmlChar *) "color");
 							if (key != NULL) {
-								image = gui_create_color_swatch ((gchar *) prop);
+								image = utl_gui_create_color_swatch ((gchar *) prop);
 								gtk_list_store_append (appGUI->opt->calendar_category_store, &iter);
 								gtk_list_store_set (appGUI->opt->calendar_category_store, &iter, 0, image,
 								                    1, prop, 2, (gchar *) key, -1);
@@ -336,12 +337,12 @@ GDate *date;
 					note = NULL;
 
 					while (cnode != NULL) {
-						utl_xml_get_int ("day", &day, cnode, doc);
-						utl_xml_get_int ("month", &month, cnode, doc);
-						utl_xml_get_int ("year", &year, cnode, doc);
-						utl_xml_get_uint ("date", &julian, cnode, doc);
-						utl_xml_get_str ("color", &color_str, cnode, doc);
-						utl_xml_get_str ("message", &note, cnode, doc);
+						utl_xml_get_int ("day", &day, cnode);
+						utl_xml_get_int ("month", &month, cnode);
+						utl_xml_get_int ("year", &year, cnode);
+						utl_xml_get_uint ("date", &julian, cnode);
+						utl_xml_get_str ("color", &color_str, cnode);
+						utl_xml_get_str ("message", &note, cnode);
 						cnode = cnode->next;
 					}
 
@@ -380,6 +381,7 @@ GSList *lnode;
 struct note *a;
 gchar *category, *color_str;
 gint i;
+xmlChar *escaped;
 
 	if ((appGUI->save_status & WRT_CALENDAR_NOTES) != 0) return;
 
@@ -397,10 +399,14 @@ gint i;
 
 	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter, NULL, i++)) {
 		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter, 1, &color_str, 2, &category, -1);
-		dc_node = xmlNewChild (node, NULL, (const xmlChar *) "name", (xmlChar *) category);
+		escaped = xmlEncodeEntitiesReentrant(doc, (const xmlChar *) category);
+		dc_node = xmlNewChild (node, NULL, (const xmlChar *) "name", (xmlChar *) escaped);
 		g_free (category);
-		xmlNewProp (dc_node, (const xmlChar *) "color", (xmlChar *) color_str);
+        xmlFree (escaped);
+		escaped = xmlEncodeEntitiesReentrant(doc, (const xmlChar *) color_str);
+		xmlNewProp (dc_node, (const xmlChar *) "color", (xmlChar *) escaped);
 		g_free (color_str);
+        xmlFree (escaped);
 	}
 
 	for (i = 0, lnode = appGUI->cal->notes_list; lnode; lnode = lnode->next, i++) {
@@ -410,8 +416,8 @@ gint i;
 		utl_xml_put_int ("day", a->day, note_node);
 		utl_xml_put_int ("month", a->month, note_node);
 		utl_xml_put_int ("year", a->year, note_node);
-		utl_xml_put_str ("color", a->color, note_node);
-		utl_xml_put_str ("message", a->note, note_node);
+		utl_xml_put_str ("color", a->color, note_node, doc);
+		utl_xml_put_str ("message", a->note, note_node, doc);
 	}
 
 	xmlSaveFormatFileEnc (prefs_get_config_filename (CALENDAR_NOTES_FILENAME, appGUI), doc, "utf-8", 1);
@@ -426,6 +432,9 @@ void
 day_notes_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 	GUI *appGUI = (GUI *) user_data;
+
+	gtk_window_get_size (GTK_WINDOW (appGUI->cal->day_notes_window),
+	                     &config.cb_window_size_x, &config.cb_window_size_y);
 	gtk_widget_destroy (appGUI->cal->day_notes_window);
 }
 
@@ -447,7 +456,7 @@ day_notes_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_dat
 	switch (event->keyval) {
 
 		case GDK_Escape:
-			gtk_widget_destroy (appGUI->cal->day_notes_window);
+			day_notes_window_close_cb (NULL, NULL, appGUI);
 			return TRUE;
 
 	}
@@ -511,84 +520,81 @@ gchar           tmpbuf[BUFFER_SIZE];
 	n_items = 0;
 	gtk_list_store_clear (GTK_LIST_STORE (appGUI->cal->day_notes_list_store));
 
-/*	if (julian_start+julian_end != 0) {*/
+	for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
 
-		for (i = 0, lnode = appGUI->cal->notes_list; lnode != NULL; lnode = lnode->next, i++) {
+		day_note = g_slist_nth_data (appGUI->cal->notes_list, i);
+		julian_day = utl_dmy_to_julian (day_note->day, day_note->month, day_note->year);
 
-			day_note = g_slist_nth_data (appGUI->cal->notes_list, i);
-			julian_day = utl_dmy_to_julian (day_note->day, day_note->month, day_note->year);
+		tmp_note = cal_note_remove_empty_lines (day_note->note);
 
-			tmp_note = cal_note_remove_empty_lines (day_note->note);
+		if (search_string == NULL) {
+			show_flag = TRUE;
+		} else {
+			if (strlen(search_string) != 0) {
 
-			if (search_string == NULL) {
-				show_flag = TRUE;
-			} else {
-				if (strlen(search_string) != 0) {
+				show_flag = FALSE;
 
-					show_flag = FALSE;
+				l = strlen(search_string);
+				m = strlen(tmp_note) - l;
 
-					l = strlen(search_string);
-					m = strlen(tmp_note) - l;
+				if (m >= 0) {
 
-					if (m >= 0) {
+					case_state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cal->notes_search_checkbutton));
 
-						case_state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cal->notes_search_checkbutton));
-
-						if (case_state == FALSE) {
-							search_key_1 = g_utf8_casefold (search_string, l);
-						} else {
-							search_key_1 = g_utf8_collate_key (search_string, l);
-						}
-
-						for (n = 0; n < m; n++) {
-
-							if (case_state == FALSE) {
-								search_key_2 = g_utf8_casefold (tmp_note+n, l);
-							} else {
-								search_key_2 = g_utf8_collate_key (tmp_note+n, l);
-							}
-
-							if (g_utf8_collate(search_key_1, search_key_2) == 0) {
-								show_flag = TRUE;
-								g_free(search_key_2);
-								break;
-							}
-
-							g_free(search_key_2);
-						}
-
-						g_free(search_key_1);
+					if (case_state == FALSE) {
+						search_key_1 = g_utf8_casefold (search_string, l);
+					} else {
+						search_key_1 = g_utf8_collate_key (search_string, l);
 					}
 
-				} else {
-					show_flag = TRUE;
-				}
-			}
+					for (n = 0; n < m; n++) {
 
-			if (((julian_start == 0 && julian_end == 0) ||
-			    (julian_day >= julian_start && julian_day <= julian_end)) && show_flag) {
+						if (case_state == FALSE) {
+							search_key_2 = g_utf8_casefold (tmp_note+n, l);
+						} else {
+							search_key_2 = g_utf8_collate_key (tmp_note+n, l);
+						}
 
-				gtk_list_store_append (appGUI->cal->day_notes_list_store, &iter);
-				gtk_list_store_set (appGUI->cal->day_notes_list_store, &iter,
-				                    DN_COLUMN_DATE, julian_to_str (julian_day, config.date_format),
-				                    DN_COLUMN_DATE_JULIAN, julian_day,
-				                    DN_COLUMN_NOTE_LINE, tmp_note,
-				                    DN_COLUMN_DONE, FALSE, -1);
+						if (g_utf8_collate(search_key_1, search_key_2) == 0) {
+							show_flag = TRUE;
+							g_free(search_key_2);
+							break;
+						}
 
-				if (julian_day < utl_get_current_julian ()
-				    && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->past_notes_checkbutton))) {
+						g_free(search_key_2);
+					}
 
-					gtk_list_store_set (appGUI->cal->day_notes_list_store, &iter, DN_COLUMN_DONE, TRUE, -1);
+					g_free(search_key_1);
 				}
 
-				n_items++;
+			} else {
+				show_flag = TRUE;
+			}
+		}
 
+		if (((julian_start == 0 && julian_end == 0) ||
+			(julian_day >= julian_start && julian_day <= julian_end)) && show_flag) {
+
+			gtk_list_store_append (appGUI->cal->day_notes_list_store, &iter);
+			gtk_list_store_set (appGUI->cal->day_notes_list_store, &iter,
+								DN_COLUMN_DATE, julian_to_str (julian_day, config.date_format),
+								DN_COLUMN_DATE_JULIAN, julian_day,
+								DN_COLUMN_NOTE_LINE, tmp_note,
+								DN_COLUMN_DONE, FALSE, -1);
+
+			if (julian_day < utl_get_current_julian ()
+				&& gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cal->past_notes_checkbutton))) {
+
+				gtk_list_store_set (appGUI->cal->day_notes_list_store, &iter, DN_COLUMN_DONE, TRUE, -1);
 			}
 
-			g_free (tmp_note);
+			n_items++;
 
 		}
-/*	}*/
+
+		g_free (tmp_note);
+
+	}
 
 	if (!n_items) {
 		g_snprintf (tmpbuf, BUFFER_SIZE, "<i>%s</i>", _("no entries"));
@@ -757,7 +763,7 @@ gchar               tmpbuf[BUFFER_SIZE];
     appGUI->cal->day_notes_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title (GTK_WINDOW (appGUI->cal->day_notes_window), _("Calendar notes"));
     gtk_window_set_position (GTK_WINDOW (appGUI->cal->day_notes_window), GTK_WIN_POS_CENTER_ON_PARENT);
-    gtk_window_set_default_size (GTK_WINDOW(appGUI->cal->day_notes_window), 570, 680);
+    gtk_window_set_default_size (GTK_WINDOW(appGUI->cal->day_notes_window), config.cb_window_size_x, config.cb_window_size_y);
     gtk_window_set_modal (GTK_WINDOW (appGUI->cal->day_notes_window), TRUE);
     g_signal_connect (G_OBJECT (appGUI->cal->day_notes_window), "delete_event",
                       G_CALLBACK(day_notes_window_close_cb), appGUI);
@@ -809,14 +815,14 @@ gchar               tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
-    notes_month_spinbutton_adj = gtk_adjustment_new (1, 1, 12, 1, 5, 5);
+    notes_month_spinbutton_adj = gtk_adjustment_new (1, 1, 12, 1, 5, 0);
     appGUI->cal->notes_month_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (notes_month_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cal->notes_month_spinbutton);
     gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->notes_month_spinbutton, TRUE, TRUE, 0);
     g_signal_connect (appGUI->cal->notes_month_spinbutton, "value-changed", 
                       G_CALLBACK (notes_filter_changed_cb), appGUI);
 
-    notes_year_spinbutton_adj = gtk_adjustment_new (2008, 1000, 9999, 1, 10, 10);
+    notes_year_spinbutton_adj = gtk_adjustment_new (2008, 1000, 9999, 1, 10, 0);
     appGUI->cal->notes_year_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (notes_year_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cal->notes_year_spinbutton);
     gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->notes_year_spinbutton, TRUE, TRUE, 0);
