@@ -24,6 +24,7 @@
 #include "calendar.h"
 #include "gui.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "calendar_notes.h"
 #include "options_prefs.h"
 #include "options_gui_tasks.h"
@@ -33,6 +34,9 @@
 
 /*------------------------------------------------------------------------------*/
 
+#ifdef TASKS_ENABLED
+#ifdef HAVE_LIBNOTIFY
+
 void
 free_notifications_list (GUI *appGUI)
 {
@@ -63,7 +67,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
 	g_snprintf (tmpbuf, BUFFER_SIZE, "%s\n%s", _("Cannot perform selected operation."),
 	            _("Task has been modified or removed."));
-	gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->main_window));
+	utl_gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->main_window));
 }
 
 /*------------------------------------------------------------------------------*/
@@ -92,7 +96,7 @@ guint i;
 					gtk_list_store_remove (appGUI->tsk->tasks_list_store, iter);
 				} else {
 					gtk_list_store_set (appGUI->tsk->tasks_list_store, iter,
-					                    TA_COLUMN_COLOR, get_date_color (a->item->due_date_julian, a->item->due_time, TRUE),
+					                    TA_COLUMN_COLOR, get_date_color (a->item->due_date_julian, a->item->due_time, TRUE, appGUI),
 					                    TA_COLUMN_DONE, TRUE, -1);
 				}
 
@@ -128,7 +132,8 @@ guint i;
 		a = g_slist_nth_data (appGUI->tsk->notifications, i);
 
 		if (a->notify == n) {
-			a->time = get_seconds_for_today () + config.postpone_time * 60;
+
+			a->time = get_seconds_for_today () + a->item->postpone_time * 60;
 			a->date = utl_get_current_julian ();
 
 			if (a->time >= 24 * 3600) {
@@ -211,8 +216,9 @@ guint i, id;
 		}
 	}
 
+	/* FIXME: alarm warning bug */
 	notify_notification_clear_actions (a->notify);
-	if (config.postpone_time > 0) {
+	if (a->item->postpone_time > 0) {
 		notify_notification_add_action (a->notify, "postpone", _("Remind me later"),
 		                                (NotifyActionCallback) tsk_postpone_notify_cb, appGUI, NULL);
 	}
@@ -220,24 +226,6 @@ guint i, id;
     notify_notification_show (a->notify, NULL);
 }
 
-/*------------------------------------------------------------------------------*/
-void
-subtract_from_date (guint32 date, gint time, gint days, gint seconds, guint32 *new_date, gint *new_time)
-{
-	*new_date = date - days;
-
-	if (time >= 0) {
-		*new_time = time - seconds;
-
-		if (*new_time < 0) {
-			*new_time = (*new_time) + 24 * 3600;
-			*new_date = (*new_date) - 1;
-		}
-	} else {
-		*new_time = -1;
-	}
-}
-
 /*------------------------------------------------------------------------------*/
 
 gboolean
@@ -250,8 +238,8 @@ gint current_time, warning_time;
 
 		current_date = utl_get_current_julian ();
 		current_time = get_seconds_for_today ();
-		subtract_from_date (item->due_date_julian, item->due_time,
-		                    item->warning_days, item->warning_time, &warning_date, &warning_time);
+		utl_subtract_from_date (item->due_date_julian, item->due_time,
+		                        item->warning_days, item->warning_time, &warning_date, &warning_time);
 
 		if (warning_date < current_date + (warning_time < current_time) ? 1 : 0) {
 
@@ -273,6 +261,54 @@ gint current_time, warning_time;
 
 /*------------------------------------------------------------------------------*/
 
+void
+show_postponed_notification (GUI *appGUI)
+{
+	gchar tmpbuf[BUFFER_SIZE], tmpbuf2[BUFFER_SIZE];
+	guint32 current_date;
+	gint current_time;
+	GSList *tnode;
+	TASK_NTF *a;
+	gint i;
+
+	current_date = utl_get_current_julian ();
+	current_time = get_seconds_for_today ();
+
+	for (i = 0, tnode = appGUI->tsk->notifications; tnode != NULL; tnode = tnode->next, i++) {
+		a = g_slist_nth_data (appGUI->tsk->notifications, i);
+
+		if (a->date > 0 && a->time >= 0) {
+			if (is_date_in_the_past (a->date, a->time, current_date, current_time)) {
+				a->date = 0;
+				a->time = -1;
+				g_snprintf (tmpbuf2, BUFFER_SIZE, "<i>%s</i>", get_date_time_full_str (a->item->due_date_julian, a->item->due_time));
+				g_strlcpy (tmpbuf, tmpbuf2, BUFFER_SIZE);
+				if (a->item->desc != NULL) {
+					if (strlen (a->item->desc)) {
+						g_snprintf (tmpbuf, BUFFER_SIZE, "%s\n%.100s", tmpbuf2, a->item->desc);
+					}
+				}
+				g_snprintf (tmpbuf2, BUFFER_SIZE, "%s (%s)", a->item->summary, _("postponed"));
+				notify_notification_update (a->notify, tmpbuf2, tmpbuf, GTK_STOCK_DIALOG_WARNING);
+
+				if (strlen (config.global_notification_command)) {
+					gui_save_data_and_run_command (config.global_notification_command, appGUI);
+				}
+
+				notify_notification_show (a->notify, NULL);
+			}
+		}
+
+	}
+
+}
+
+/*------------------------------------------------------------------------------*/
+
+#endif /* HAVE_LIBNOTIFY */
+
+/*------------------------------------------------------------------------------*/
+
 gboolean
 tsk_show_task_notification (TASK_ITEM *item, GtkTreeIter *iter, GUI *appGUI)
 {
@@ -294,51 +330,6 @@ tsk_show_task_notification (TASK_ITEM *item, GtkTreeIter *iter, GUI *appGUI)
 
 /*------------------------------------------------------------------------------*/
 
-void
-show_postponed_notification (GUI *appGUI)
-{
-gchar tmpbuf[BUFFER_SIZE];
-gchar tmpbuf2[BUFFER_SIZE];
-guint32 current_date;
-gint current_time;
-GSList *tnode;
-TASK_NTF *a;
-gint i;
-
-	current_date = utl_get_current_julian ();
-	current_time = get_seconds_for_today ();
-
-	for (i = 0, tnode = appGUI->tsk->notifications; tnode != NULL; tnode = tnode->next, i++) {
-		a = g_slist_nth_data (appGUI->tsk->notifications, i);
-
-		if (a->date > 0 && a->time >= 0) {
-			if (is_date_in_the_past (a->date, a->time, current_date, current_time)) {
-				a->date = 0;
-				a->time = -1;
-				g_snprintf (tmpbuf2, BUFFER_SIZE, "<i>%s</i>", get_date_time_full_str (a->item->due_date_julian, a->item->due_time));
-				g_strlcpy (tmpbuf, tmpbuf2, BUFFER_SIZE);
-				if (a->item->desc != NULL) {
-					if (strlen (a->item->desc)) {
-						g_snprintf (tmpbuf, BUFFER_SIZE, "%s\n%.100s", tmpbuf2, a->item->desc);
-					}
-				}
-				g_snprintf (tmpbuf2, BUFFER_SIZE, "%s (%s)", a->item->summary, _("postponed"));
-				notify_notification_update (a->notify, tmpbuf2, tmpbuf, GTK_STOCK_DIALOG_WARNING);
-
-                if (strlen (config.global_notification_command)) {
-                    gui_save_data_and_run_command (config.global_notification_command, appGUI);
-                }
-
-				notify_notification_show (a->notify, NULL);
-			}
-		}
-
-	}
-
-}
-
-/*------------------------------------------------------------------------------*/
-
 gboolean
 notify_tasks (GUI *appGUI)
 {
@@ -349,10 +340,13 @@ gint current_time;
 
 GtkTreeIter iter;
 TASK_ITEM *item;
-TASK_NTF *a;
 gint i;
 
+#ifdef HAVE_LIBNOTIFY
+TASK_NTF *a;
+
 	show_postponed_notification (appGUI);
+#endif /* HAVE_LIBNOTIFY */
 
 	current_date = utl_get_current_julian ();
 	current_time = get_seconds_for_today ();
@@ -382,6 +376,7 @@ gint i;
 						}
 					}
 
+#ifdef HAVE_LIBNOTIFY
 					a = g_malloc (sizeof (TASK_NTF));
 					g_assert (a != NULL);
 
@@ -393,12 +388,12 @@ gint i;
 
 					notify_notification_set_timeout (a->notify, NOTIFY_EXPIRES_NEVER);
 					switch (get_priority_index (item->priority)) {
-						case 0: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_LOW); break;
-						case 1: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_NORMAL); break;
-						case 2: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_CRITICAL); break;
+						case LOW_PRIORITY: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_LOW); break;
+						case MEDIUM_PRIORITY: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_NORMAL); break;
+						case HIGH_PRIORITY: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_CRITICAL); break;
 					}
 
-					if (config.postpone_time > 0) {
+					if (a->item->postpone_time > 0) {
 						notify_notification_add_action (a->notify, "postpone", _("Remind me later"),
 						                                (NotifyActionCallback) tsk_postpone_notify_cb, appGUI, NULL);
 					}
@@ -410,27 +405,39 @@ gint i;
 
 					notify_notification_add_action (a->notify, "done", _("Done"),
 					                                (NotifyActionCallback) tsk_done_cb, appGUI, NULL);
+#endif /* HAVE_LIBNOTIFY */
 
 					if (gtk_status_icon_get_visible (appGUI->osmo_trayicon)) {
+#ifdef HAVE_LIBNOTIFY
 						notify_notification_attach_to_status_icon (a->notify, appGUI->osmo_trayicon);
+#endif /* HAVE_LIBNOTIFY */
+				        gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_TASK);
+
+						if (config.blink_on_events) {
+							gtk_status_icon_set_blinking (appGUI->osmo_trayicon, TRUE);
+						}
 					}
 
                     if (strlen (config.global_notification_command)) {
                         gui_save_data_and_run_command (config.global_notification_command, appGUI);
                     }
 
+#ifdef HAVE_LIBNOTIFY
 					if (!notify_notification_show (a->notify, NULL)) {
 						g_warning ("Failed to send notification");
 						return FALSE;
 					}
 
 					appGUI->tsk->notifications = g_slist_append (appGUI->tsk->notifications, a);
+#endif /* HAVE_LIBNOTIFY */
 
 					gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter,
 					                    TA_COLUMN_ACTIVE, FALSE,
 					                    TA_COLUMN_ACTIVE_WARNING, FALSE, -1);
 
-				} else if (tsk_show_warning_notification (item, &iter, appGUI)) {
+				}
+#ifdef HAVE_LIBNOTIFY
+				else if (tsk_show_warning_notification (item, &iter, appGUI)) {
 
 					g_snprintf (tmpbuf2, BUFFER_SIZE, "<b>%s</b>\n<i>%s</i>",
 					            item->summary, get_date_time_full_str (item->due_date_julian, item->due_time));
@@ -459,10 +466,6 @@ gint i;
 						notify_notification_attach_to_status_icon (a->notify, appGUI->osmo_trayicon);
 					}
 
-                    if (strlen (config.global_notification_command)) {
-                        gui_save_data_and_run_command (config.global_notification_command, appGUI);
-                    }
-
 					if (!notify_notification_show (a->notify, NULL)) {
 						g_warning ("Failed to send notification");
 						return FALSE;
@@ -473,6 +476,7 @@ gint i;
 					gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter,
 					                    TA_COLUMN_ACTIVE_WARNING, FALSE, -1);
 				}
+#endif /* HAVE_LIBNOTIFY */
 
 			}
 			task_item_free (item);
@@ -484,45 +488,6 @@ gint i;
 
 /*------------------------------------------------------------------------------*/
 
-gboolean
-time_handler (GUI *appGUI)
-{
-static gint counter = 0;
-
-	update_clock (appGUI);
-
-	if (counter == 0) {
-		/* check tasks */
-		notify_tasks (appGUI);
-
-		/* check contacts */
-		/* check notes */
-	}
-	counter = (counter + 1) % 60;
-
-	return TRUE;
-}
-
-/*------------------------------------------------------------------------------*/
-
-gboolean
-check_tasks_contacts (guint32 julian_day, GUI *appGUI) {
-
-    if (appGUI->calendar_only == TRUE || appGUI->all_pages_added == FALSE) {
-        return FALSE;
-    }
-
-    /* check contacts */
-    if (check_contacts (julian_day, appGUI) == TRUE) {
-        return TRUE;
-    }
-
-    /* check tasks */
-    return check_tasks (julian_day, TRUE, appGUI);
-}
-
-/*------------------------------------------------------------------------------*/
-
 gboolean
 check_tasks (guint32 julian_day, gboolean calendar, GUI *appGUI) {
 
@@ -558,6 +523,73 @@ guint32 date;
 
 /*------------------------------------------------------------------------------*/
 
+#endif  /* TASKS_ENABLED */
+
+/*------------------------------------------------------------------------------*/
+
+gboolean
+time_handler (GUI *appGUI)
+{
+static gint minute = -1;
+gint current_minute;
+
+	update_clock (appGUI);
+
+    current_minute = get_current_minute ();
+
+	if (minute != current_minute) {
+
+#ifdef TASKS_ENABLED
+		notify_tasks (appGUI);
+#endif  /* TASKS_ENABLED */
+
+		minute = current_minute;
+
+		if (minute == 0) 
+			if (get_current_hour () == 0) {
+#ifdef TASKS_ENABLED
+				refresh_tasks (appGUI);
+#endif  /* TASKS_ENABLED */
+
+				/* update systray status */
+				gui_systray_update_icon (appGUI);
+			}
+
+		gui_systray_tooltip_update (appGUI);
+	}
+
+	return TRUE;
+}
+
+/*------------------------------------------------------------------------------*/
+
+gboolean
+check_tasks_contacts (guint32 julian_day, GUI *appGUI) {
+
+    if (appGUI->calendar_only == TRUE || appGUI->all_pages_added == FALSE) {
+        return FALSE;
+    }
+
+#ifdef CONTACTS_ENABLED
+    /* check contacts */
+    if (check_contacts (julian_day, appGUI) == TRUE) {
+        return TRUE;
+    }
+#endif  /* CONTACTS_ENABLED */
+
+#ifdef TASKS_ENABLED
+    /* check tasks */
+    return check_tasks (julian_day, TRUE, appGUI);
+#else
+    return FALSE;
+#endif  /* TASKS_ENABLED */
+
+}
+
+/*------------------------------------------------------------------------------*/
+
+#ifdef CONTACTS_ENABLED
+
 gboolean
 check_contacts (guint32 julian_day, GUI *appGUI) {
 
@@ -606,6 +638,8 @@ guint32 date, age;
     return FALSE;
 }
 
+#endif  /* CONTACTS_ENABLED */
+
 /*------------------------------------------------------------------------------*/
 
 void
@@ -711,14 +745,30 @@ GtkWidget           *show_osmo_button;
 GtkTreeViewColumn   *column, *julian_day_column;
 GtkCellRenderer     *renderer;
 GtkTreeIter         iter;
+
+#if defined(TASKS_ENABLED) || defined(CONTACTS_ENABLED)
 GtkTreePath         *path;
-guint32             i, j, start_date, current_date, julian_day, date, age;
-gboolean            day_notes_flag, tasks_flag, birthdays_flag;
-GDate               *new_cdate;
+#endif
+
+guint32             i, j, start_date, current_date, julian_day;
+gboolean            day_notes_flag, tasks_flag;
 GSList              *lnode;
 struct note         *day_note;
-gchar               *tmp_note, *summary, *first_name, *last_name, *category;
-gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_SIZE];
+gchar               *tmp_note;
+gchar               date_str[BUFFER_SIZE];
+
+#ifdef TASKS_ENABLED
+gchar               *summary, *category;
+#endif  /* TASKS_ENABLED */
+
+#ifdef CONTACTS_ENABLED
+gboolean            birthdays_flag;
+guint32             date, age;
+GDate               *new_cdate;
+gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE];
+gchar               *first_name, *last_name;
+#endif  /* CONTACTS_ENABLED */
+
 
     start_date = config.lastrun_date;           /* - */
     current_date = utl_get_current_julian () + appGUI->check_ndays_events;     /* + */
@@ -748,6 +798,8 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
         }
     }
 
+
+#ifdef TASKS_ENABLED
     /* check tasks */
 
     tasks_flag = FALSE;
@@ -781,6 +833,10 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
         gtk_tree_path_free(path);
 
     }
+#endif  /* TASKS_ENABLED */
+
+
+#ifdef CONTACTS_ENABLED
 
     /* check birthdays */
 
@@ -826,10 +882,15 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
         }
         gtk_tree_path_free(path);
     }
+#endif  /* CONTACTS_ENABLED */
 
     /* any events available ? */
 
+#ifdef CONTACTS_ENABLED
     if (day_notes_flag == FALSE && tasks_flag == FALSE && birthdays_flag == FALSE) {
+#else
+    if (day_notes_flag == FALSE && tasks_flag == FALSE) {
+#endif  /* CONTACTS_ENABLED */
         return FALSE;           /* if not then quit */
     }
         
@@ -932,6 +993,8 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
 
     }
 
+#ifdef TASKS_ENABLED
+
     /* insert tasks */
 
     if (tasks_flag == TRUE) {
@@ -968,7 +1031,9 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
         }
         gtk_tree_path_free(path);
     }
+#endif  /* TASKS_ENABLED */
 
+#ifdef CONTACTS_ENABLED
     /* insert birthdays */
 
     if (birthdays_flag == TRUE) {
@@ -1031,6 +1096,8 @@ gchar               tmpbuf[BUFFER_SIZE], template[BUFFER_SIZE], date_str[BUFFER_
         gtk_tree_path_free(path);
     }
 
+#endif  /* CONTACTS_ENABLED */
+
     g_signal_emit_by_name(julian_day_column, "clicked");
 
     hseparator = gtk_hseparator_new ();
