@@ -23,6 +23,7 @@
 #include "i18n.h"
 #include "contacts_items.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 #include "contacts_birthdays.h"
@@ -32,7 +33,9 @@
 
 #ifdef HAVE_LIBSYNCML
 #include "contacts_import_syncml.h"
-#endif
+#endif  /* HAVE_LIBSYNCML */
+
+#ifdef CONTACTS_ENABLED
 
 /*------------------------------------------------------------------------------*/
 
@@ -123,7 +126,7 @@ gboolean
 contacts_list_filter_cb (GtkTreeModel *model, GtkTreeIter *iter, gpointer data) {
 
 const gchar *text;
-gchar *value;
+gchar *value = NULL;
 gint i, j, len, text_len;
 guint32 date;
 
@@ -167,7 +170,27 @@ guint32 date;
                 return FALSE;
             }
 
-        } else if (config.find_mode == CONTACTS_FF_ALL_FIELDS) {
+        } else if (config.find_mode == CONTACTS_FF_TAGS) {
+
+			gtk_tree_model_get(model, iter, COLUMN_TAGS, &value, -1);
+
+			if (value != NULL) {
+
+				len = strlen(value) - text_len;
+
+				if (len >= 0) {
+					for(j=0; j <= len; j++) {
+						if(!g_ascii_strncasecmp(g_utf8_casefold(text, -1), g_utf8_casefold(value+j, -1), text_len))
+							return TRUE;
+					}
+				}
+
+				g_free(value);
+			}
+
+			return FALSE;
+
+		} else if (config.find_mode == CONTACTS_FF_ALL_FIELDS) {
 
             for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
 
@@ -213,7 +236,7 @@ guint32 date;
 /*------------------------------------------------------------------------------*/
 
 void
-contacts_select_first_position_in_list(GUI *appGUI) {
+contacts_select_first_position_in_list (GUI *appGUI) {
 
 GtkTreeIter     iter;
 GtkTreePath     *path;
@@ -223,7 +246,7 @@ GtkTreePath     *path;
         path = gtk_tree_model_get_path (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter);
         if (path != NULL) {
             gtk_tree_view_set_cursor (GTK_TREE_VIEW (appGUI->cnt->contacts_list), path, NULL, FALSE);
-            gtk_tree_path_free(path);
+            gtk_tree_path_free (path);
         }
     }
 }
@@ -247,18 +270,30 @@ char tmpbuf[BUFFER_SIZE];
 gboolean activate_home_phone, activate_work_phone, activate_cell_phone;
 gboolean activate_email, activate_www;
 guint32 date;
+gboolean address_available = FALSE;
 PangoFontDescription *item_font;
+gchar *fname, *sname, *lname;
 
     GUI *appGUI = (GUI *)data;
 
     if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
 
-        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/edit"), TRUE);
-        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/delete"), TRUE);
+        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, 
+															"/toolbar/edit"), TRUE);
+        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, 
+															"/toolbar/delete"), TRUE);
+
+		address_available = check_address (HOME_ADDRESS, appGUI);
+		if (address_available == FALSE) {
+			address_available = check_address (WORK_ADDRESS, appGUI);
+		}
+
+        gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, 
+															 "/toolbar/map_location"), address_available);
         set_export_active (appGUI);
 
-        text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_desc_textview));
-        gui_clear_text_buffer (text_buffer, &titer);
+        text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(appGUI->cnt->contacts_desc_textview));
+        utl_gui_clear_text_buffer (text_buffer, &titer);
 
         if (appGUI->cnt->photo_image != NULL) {      /* remove old photo */
             gtk_widget_destroy(appGUI->cnt->photo_image);
@@ -279,7 +314,7 @@ PangoFontDescription *item_font;
         }
 
         if (G_IS_OBJECT(appGUI->cnt->contacts_www_textview)) {
-            gui_url_remove_links (&appGUI->cnt->contacts_www_links_list, &appGUI->cnt->contacts_www_link_index);
+            utl_gui_url_remove_links (&appGUI->cnt->contacts_www_links_list, &appGUI->cnt->contacts_www_link_index);
             g_object_ref_sink (appGUI->cnt->contacts_www_textview);
         }
 
@@ -289,8 +324,8 @@ PangoFontDescription *item_font;
         gtk_text_view_set_pixels_above_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview), 2);
         gtk_text_view_set_pixels_below_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview), 2);
         gtk_widget_show (appGUI->cnt->contacts_www_textview);
-        gui_url_setup(&appGUI->cnt->contacts_www_links_list, 
-                      &appGUI->cnt->contacts_www_link_index, appGUI->cnt->contacts_www_textview, appGUI);
+        utl_gui_url_setup (&appGUI->cnt->contacts_www_links_list, 
+                           &appGUI->cnt->contacts_www_link_index, appGUI->cnt->contacts_www_textview, appGUI);
 
         /* initialize EMAIL links textview */
 
@@ -304,7 +339,7 @@ PangoFontDescription *item_font;
         }
 
         if (G_IS_OBJECT(appGUI->cnt->contacts_email_textview)) {
-            gui_url_remove_links (&appGUI->cnt->contacts_email_links_list, &appGUI->cnt->contacts_email_link_index);
+            utl_gui_url_remove_links (&appGUI->cnt->contacts_email_links_list, &appGUI->cnt->contacts_email_link_index);
             g_object_ref_sink (appGUI->cnt->contacts_email_textview);
         }
 
@@ -314,13 +349,13 @@ PangoFontDescription *item_font;
         gtk_text_view_set_pixels_above_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview), 2);
         gtk_text_view_set_pixels_below_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview), 2);
         gtk_widget_show (appGUI->cnt->contacts_email_textview);
-        gui_url_setup(&appGUI->cnt->contacts_email_links_list, 
-                      &appGUI->cnt->contacts_email_link_index, appGUI->cnt->contacts_email_textview, appGUI);
+        utl_gui_url_setup (&appGUI->cnt->contacts_email_links_list, 
+                           &appGUI->cnt->contacts_email_link_index, appGUI->cnt->contacts_email_textview, appGUI);
 
         /* initialize BLOG link textview */
 
         if (G_IS_OBJECT(appGUI->cnt->contacts_blog_textview)) {
-            gui_url_remove_links (&appGUI->cnt->contacts_blog_links_list, &appGUI->cnt->contacts_blog_link_index);
+            utl_gui_url_remove_links (&appGUI->cnt->contacts_blog_links_list, &appGUI->cnt->contacts_blog_link_index);
             g_object_ref_sink (appGUI->cnt->contacts_blog_textview);
         }
 
@@ -330,8 +365,8 @@ PangoFontDescription *item_font;
         gtk_text_view_set_pixels_above_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_blog_textview), 2);
         gtk_text_view_set_pixels_below_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_blog_textview), 2);
         gtk_widget_show (appGUI->cnt->contacts_blog_textview);
-        gui_url_setup(&appGUI->cnt->contacts_blog_links_list, 
-                      &appGUI->cnt->contacts_blog_link_index, appGUI->cnt->contacts_blog_textview, appGUI);
+        utl_gui_url_setup (&appGUI->cnt->contacts_blog_links_list, 
+                           &appGUI->cnt->contacts_blog_link_index, appGUI->cnt->contacts_blog_textview, appGUI);
 
         gdk_color_parse (config.contact_tag_color, &color);
         item_font = pango_font_description_from_string (config.contact_item_font);
@@ -345,6 +380,30 @@ PangoFontDescription *item_font;
         j_www = 0;      /* www links counter */
         j_email = 0;    /* email links counter */
 
+		gtk_tree_model_get (model, &iter,
+		                    COLUMN_FIRST_NAME, &fname,
+		                    COLUMN_SECOND_NAME, &sname,
+		                    COLUMN_LAST_NAME, &lname,
+		                    -1);
+
+		if (fname != NULL) {
+			gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, fname, -1, "big", NULL);
+			gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, " ", -1, "big", NULL);
+			g_free (fname);
+		}
+
+		if (sname != NULL) {
+			gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, sname, -1, "big", NULL);
+			gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, " ", -1, "big", NULL);
+			g_free (sname);
+		}
+
+		if (lname != NULL) {
+			gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, lname, -1, "big", NULL);
+			gtk_text_buffer_insert (text_buffer, &titer, "\n", -1);
+			g_free (lname);
+		}
+
         for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
 
             if (i != COLUMN_ID) {
@@ -364,22 +423,9 @@ PangoFontDescription *item_font;
                     gtk_tree_model_get (model, &iter, i, &text, -1);
                 }
 
-                    if (i != COLUMN_PHOTO && i != COLUMN_ID) {
+                    if (i != COLUMN_PHOTO && i != COLUMN_FIRST_NAME && i != COLUMN_SECOND_NAME && i != COLUMN_LAST_NAME) {
 
-                        if (i == COLUMN_FIRST_NAME || i == COLUMN_SECOND_NAME || i == COLUMN_LAST_NAME) {
-
-                            if (text != NULL) {
-                                gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, text, -1,
-                                                          "big", NULL);
-                                gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, " ", -1,
-                                                          "big", NULL);
-                            }
-
-                            if (i == COLUMN_LAST_NAME) {
-                                gtk_text_buffer_insert(text_buffer, &titer, "\n", -1);
-                            }
-
-                        } else if (text != NULL && i != COLUMN_GROUP) {
+                        if (text != NULL && i != COLUMN_GROUP) {
 
                             if (anchor == NULL) {
                                 gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, "\n", -1, "normal", NULL);
@@ -437,14 +483,14 @@ PangoFontDescription *item_font;
                                         gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contacts_www_textview, 1, 2, n, n+1,
                                                           (GtkAttachOptions) (GTK_FILL),
                                                           (GtkAttachOptions) (0), 0, 0);
-                                        gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview)), &www_titer);
+                                        utl_gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview)), &www_titer);
                                     }
                                     if (i >= COLUMN_WWW_1 && i <= COLUMN_WWW_4) {
-                                        gui_url_insert_link(&appGUI->cnt->contacts_www_links_list, 
-                                                            &appGUI->cnt->contacts_www_link_index, 
-                                                            appGUI->cnt->contacts_www_textview, 
-                                                            &www_titer, config.contact_link_color, 
-                                                            config.contact_item_font, text, FALSE, appGUI);
+                                        utl_gui_url_insert_link (&appGUI->cnt->contacts_www_links_list, 
+                                                                 &appGUI->cnt->contacts_www_link_index, 
+                                                                 appGUI->cnt->contacts_www_textview, 
+                                                                 &www_titer, config.contact_link_color, 
+                                                                 config.contact_item_font, text, FALSE, appGUI);
                                         j_www++;
                                         if (j_www < n_www) {
                                             gtk_text_buffer_insert (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview)), &www_titer, "\n", -1);
@@ -455,14 +501,14 @@ PangoFontDescription *item_font;
                                         gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contacts_email_textview, 1, 2, n, n+1,
                                                           (GtkAttachOptions) (GTK_FILL),
                                                           (GtkAttachOptions) (0), 0, 0);
-                                        gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview)), &email_titer);
+                                        utl_gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview)), &email_titer);
                                     }
                                     if (i >= COLUMN_EMAIL_1 && i <= COLUMN_EMAIL_4) {
-                                        gui_url_insert_link(&appGUI->cnt->contacts_email_links_list, 
-                                                            &appGUI->cnt->contacts_email_link_index, 
-                                                            appGUI->cnt->contacts_email_textview, 
-                                                            &email_titer, config.contact_link_color, 
-                                                            config.contact_item_font, text, FALSE, appGUI);
+                                        utl_gui_url_insert_link (&appGUI->cnt->contacts_email_links_list, 
+                                                                 &appGUI->cnt->contacts_email_link_index, 
+                                                                 appGUI->cnt->contacts_email_textview, 
+                                                                 &email_titer, config.contact_link_color, 
+                                                                 config.contact_item_font, text, FALSE, appGUI);
                                         j_email++;
                                         if (j_email < n_email) {
                                             gtk_text_buffer_insert (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview)), &email_titer, "\n", -1);
@@ -473,12 +519,12 @@ PangoFontDescription *item_font;
                                         gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contacts_blog_textview, 1, 2, n, n+1,
                                                           (GtkAttachOptions) (GTK_FILL),
                                                           (GtkAttachOptions) (0), 0, 0);
-                                        gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_blog_textview)), &blog_titer);
-                                        gui_url_insert_link(&appGUI->cnt->contacts_blog_links_list, 
-                                                            &appGUI->cnt->contacts_blog_link_index, 
-                                                            appGUI->cnt->contacts_blog_textview, 
-                                                            &blog_titer, config.contact_link_color, 
-                                                            config.contact_item_font, text, FALSE, appGUI);
+                                        utl_gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_blog_textview)), &blog_titer);
+                                        utl_gui_url_insert_link (&appGUI->cnt->contacts_blog_links_list, 
+                                                                 &appGUI->cnt->contacts_blog_link_index, 
+                                                                 appGUI->cnt->contacts_blog_textview, 
+                                                                 &blog_titer, config.contact_link_color, 
+                                                                 config.contact_item_font, text, FALSE, appGUI);
                                     }
 
                                 } else if (i == COLUMN_INFO) {
@@ -524,6 +570,7 @@ PangoFontDescription *item_font;
     } else {
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/edit"), FALSE);
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/delete"), FALSE);
+        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/map_location"), FALSE);
         set_export_active (appGUI);
     }
 }
@@ -606,10 +653,10 @@ gint i;
                 path = gtk_tree_path_new_first();
                 if (path != NULL) {
                     gtk_tree_view_set_cursor (GTK_TREE_VIEW (appGUI->cnt->contacts_list), path, NULL, FALSE);
-                    g_free(path);
+                    gtk_tree_path_free (path);
                 }
             } else {
-                gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_desc_textview)), &titer);
+                utl_gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_desc_textview)), &titer);
             }
         }
     }
@@ -621,7 +668,9 @@ gint i;
 void
 contacts_find_type_selected_cb (GtkComboBox *widget, gpointer user_data) {
 
+GtkTreeIter iter;
 GtkTreePath *path;
+gint i;
 
     GUI *appGUI = (GUI *)user_data;
 
@@ -630,10 +679,13 @@ GtkTreePath *path;
     if(strlen(gtk_entry_get_text (GTK_ENTRY(appGUI->cnt->contacts_find_entry)))) {
         gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->cnt->contacts_filter));
 
+		i = 0;
+		while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->cnt->contacts_filter), &iter, NULL, i++));
+
         path = gtk_tree_path_new_first();
-        if (path != NULL) {
+        if (path != NULL && i-1) {
             gtk_tree_view_set_cursor (GTK_TREE_VIEW (appGUI->cnt->contacts_list), path, NULL, FALSE);
-            g_free(path);
+			gtk_tree_path_free (path);
             show_contacts_desc_panel(TRUE, appGUI);
         }
     }
@@ -825,6 +877,75 @@ contacts_birthdays_item_cb (GtkWidget *widget, gpointer data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+contacts_map_location_cb (GtkWidget *widget, gpointer data) {
+
+gint response = -1;
+gchar buffer[BUFFER_SIZE];
+GtkWidget *info_dialog = NULL;
+GtkWidget *hbox;
+GtkWidget *home_addr_radiobutton;
+GtkWidget *work_addr_radiobutton;
+GSList *hw_radiobutton_group = NULL;
+
+
+    GUI *appGUI = (GUI *)data;
+
+    if (gtk_tree_selection_get_selected (appGUI->cnt->contacts_list_selection, NULL, NULL)) {
+    
+		if (check_address (HOME_ADDRESS, appGUI) && check_address (WORK_ADDRESS, appGUI)) {
+
+			g_snprintf (buffer, BUFFER_SIZE, "\n%s:", _("Please select address"));
+
+			info_dialog = gtk_message_dialog_new (GTK_WINDOW(appGUI->main_window),
+                                                  GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
+                                                  GTK_MESSAGE_INFO, GTK_BUTTONS_OK_CANCEL, buffer);
+
+			gtk_window_set_title(GTK_WINDOW(info_dialog), _("Information"));
+			gtk_widget_show (info_dialog);
+
+			hbox = gtk_hbox_new (FALSE, 4);
+		 	gtk_box_pack_start (GTK_BOX(GTK_DIALOG(info_dialog)->vbox), hbox, FALSE, TRUE, 2);
+			gtk_widget_show (hbox);
+
+			work_addr_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Work"));
+			gtk_widget_show (work_addr_radiobutton);
+		 	gtk_box_pack_end (GTK_BOX(hbox), work_addr_radiobutton, FALSE, TRUE, 2);
+		    gtk_radio_button_set_group (GTK_RADIO_BUTTON (work_addr_radiobutton), hw_radiobutton_group);
+            hw_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (work_addr_radiobutton));
+
+			home_addr_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Home"));
+			gtk_widget_show (home_addr_radiobutton);
+		 	gtk_box_pack_end (GTK_BOX(hbox), home_addr_radiobutton, FALSE, TRUE, 2);
+		  	gtk_radio_button_set_group (GTK_RADIO_BUTTON (home_addr_radiobutton), hw_radiobutton_group);
+			hw_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (home_addr_radiobutton));
+
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (home_addr_radiobutton), TRUE);
+
+			response = gtk_dialog_run(GTK_DIALOG(info_dialog));
+
+			if (response == GTK_RESPONSE_OK) {
+				if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (home_addr_radiobutton)) == TRUE) {
+					show_contact_location_on_map (HOME_ADDRESS, appGUI);
+				} else {
+					show_contact_location_on_map (WORK_ADDRESS, appGUI);
+				}
+			}
+
+			gtk_widget_destroy(info_dialog);
+
+		} else {
+			if (check_address (HOME_ADDRESS, appGUI)) {
+				show_contact_location_on_map (HOME_ADDRESS, appGUI);
+			} else {
+				show_contact_location_on_map (WORK_ADDRESS, appGUI);
+			}
+		}
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 contacts_export_items_cb (GtkWidget *widget, gpointer data) {
 
@@ -881,6 +1002,23 @@ contacts_selection_activate (gboolean active, GUI *appGUI) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+store_contact_columns_info (GUI *appGUI) {
+
+	config.contacts_column_idx_0 = utl_gui_get_column_position (appGUI->cnt->contacts_columns[COLUMN_GROUP],
+																GTK_TREE_VIEW(appGUI->cnt->contacts_list), MAX_VISIBLE_CONTACT_COLUMNS, appGUI);
+	config.contacts_column_idx_1 = utl_gui_get_column_position (appGUI->cnt->contacts_columns[COLUMN_FIRST_NAME], 
+																GTK_TREE_VIEW(appGUI->cnt->contacts_list), MAX_VISIBLE_CONTACT_COLUMNS, appGUI);
+	config.contacts_column_idx_2 = utl_gui_get_column_position (appGUI->cnt->contacts_columns[COLUMN_LAST_NAME], 
+																GTK_TREE_VIEW(appGUI->cnt->contacts_list), MAX_VISIBLE_CONTACT_COLUMNS, appGUI);
+
+	config.contacts_column_idx_0_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), 0));
+	config.contacts_column_idx_1_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), 1));
+	config.contacts_column_idx_2_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), 2));
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 gui_create_contacts(GUI *appGUI) {
 
@@ -896,16 +1034,24 @@ GtkWidget       *close_button;
 GtkCellRenderer *renderer[CONTACTS_NUM_COLUMNS];
 GType           contact_columns_types[CONTACTS_NUM_COLUMNS];
 GtkTextBuffer   *text_buffer;
-gint            i;
+gint            i, n;
 GError          *error = NULL;
 GtkActionGroup  *action_group = NULL;
 GtkAdjustment   *adjustment;
 gchar tmpbuf[BUFFER_SIZE];
 
+gint columns_order[MAX_VISIBLE_CONTACT_COLUMNS];
+
+gint co_columns[MAX_VISIBLE_CONTACT_COLUMNS] = { 
+		COLUMN_GROUP, COLUMN_FIRST_NAME, COLUMN_LAST_NAME
+};
+
 static gchar *contact_fields_tags_name[] = {
-    N_("Group"), "group", N_("First name"), "first_name", N_("Second name"), "second_name", 
-    N_("Last name"), "last_name", 
-    N_("Nickname"), "nickname", N_("Birthday date"), "birthday_date", N_("Name day date"), "name_day_date",
+    N_("Group"), "group", 
+	N_("First name"), "first_name", N_("Last name"), "last_name", 
+	N_("Second name"), "second_name", 
+    N_("Nickname"), "nickname", N_("Tags"), "tags", 
+	N_("Birthday date"), "birthday_date", N_("Name day date"), "name_day_date",
 
     /*--------------------------------------------------*/
     N_("Home address"), "home_address", N_("Home postcode"), "home_postcode", N_("Home city"), 
@@ -946,6 +1092,7 @@ const gchar *ui_info =
 "    <toolitem name=\"delete\" action=\"delete\" />\n"
 "    <separator name=\"sep1\" />\n"
 "    <toolitem name=\"birthdays\" action=\"birthdays\" />\n"
+"    <toolitem name=\"map_location\" action=\"map_location\" />\n"
 "    <separator name=\"sep2\" />\n"
 "    <toolitem name=\"import\" action=\"import\" />\n"
 "    <toolitem name=\"export\" action=\"export\" />\n"
@@ -956,6 +1103,7 @@ GtkActionEntry entries[] = {
     { "delete", OSMO_STOCK_CONTACTS_REMOVE, _("Remove contact"), NULL, _("Remove contact"), NULL },
     { "edit", OSMO_STOCK_CONTACTS_EDIT, _("Edit contact"), NULL, _("Edit contact"), NULL },
     { "birthdays", OSMO_STOCK_CONTACTS_BIRTHDAYS, _("Show birthdays"), NULL, _("Show birthdays"), NULL },
+    { "map_location", OSMO_STOCK_CONTACTS_MAP_LOCATION, _("Show contact location on the map"), NULL, _("Show contact location on the map"), NULL },
     { "import", OSMO_STOCK_CONTACTS_IMPORT, _("Import contacts"), NULL, _("Import contacts"), NULL },
     { "export", OSMO_STOCK_CONTACTS_EXPORT, _("Export contacts"), NULL, _("Export contacts"), NULL },
 };
@@ -994,7 +1142,6 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_ui_manager_ensure_update (appGUI->cnt->contacts_uim_widget);
 
     gtk_toolbar_set_style (appGUI->cnt->contacts_toolbar, GTK_TOOLBAR_ICONS);
-    gtk_toolbar_set_tooltips (appGUI->cnt->contacts_toolbar, config.enable_tooltips);
 
     /*-------------------------------------------------------------------------------------*/
     /* assign callbacks */
@@ -1011,6 +1158,8 @@ guint n_entries = G_N_ELEMENTS (entries);
                       G_CALLBACK(contacts_export_items_cb), appGUI);
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/import")), "clicked", 
                       G_CALLBACK(contacts_import_items_cb), appGUI);
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/map_location")), "clicked", 
+                      G_CALLBACK(contacts_map_location_cb), appGUI);
 
     /*-------------------------------------------------------------------------------------*/
 
@@ -1049,6 +1198,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                      G_CALLBACK(find_combo_box_focus_cb), appGUI);
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->contacts_find_combobox), _("First Name"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->contacts_find_combobox), _("Last Name"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->contacts_find_combobox), _("Tags"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->contacts_find_combobox), _("All fields"));
 
     hseparator = gtk_hseparator_new ();
@@ -1115,16 +1265,46 @@ guint n_entries = G_N_ELEMENTS (entries);
         if(i != COLUMN_FIRST_NAME && i != COLUMN_LAST_NAME && i != COLUMN_GROUP) {
             gtk_tree_view_column_set_visible (appGUI->cnt->contacts_columns[i], FALSE);
         } else {
-            if (config.hide_group_column == TRUE && i == COLUMN_GROUP) {
+
+			if (config.hide_group_column == TRUE && i == COLUMN_GROUP) {
                 gtk_tree_view_column_set_visible (appGUI->cnt->contacts_columns[i], FALSE);
             }
-            gtk_tree_view_column_set_expand (appGUI->cnt->contacts_columns[i], TRUE);
+
+			gtk_tree_view_column_set_reorderable (appGUI->cnt->contacts_columns[i], TRUE);
+			gtk_tree_view_column_set_resizable (appGUI->cnt->contacts_columns[i], TRUE);
+			gtk_tree_view_column_set_sizing (appGUI->cnt->contacts_columns[i], GTK_TREE_VIEW_COLUMN_FIXED);
+
         }
     }
 
     gtk_container_add (GTK_CONTAINER (top_scrolledwindow), appGUI->cnt->contacts_list);
     gtk_tree_view_set_enable_search (GTK_TREE_VIEW(appGUI->cnt->contacts_list), FALSE);
 
+	/* restore columns order */
+
+	columns_order[0] = config.contacts_column_idx_0;
+	columns_order[1] = config.contacts_column_idx_1;
+	columns_order[2] = config.contacts_column_idx_2;
+
+	n = MAX_VISIBLE_CONTACT_COLUMNS-1;
+
+	while (n >= 0) {
+		for (i = 0; i < MAX_VISIBLE_CONTACT_COLUMNS; i++) {
+			if (n == columns_order[i]) {
+				gtk_tree_view_move_column_after(GTK_TREE_VIEW(appGUI->cnt->contacts_list),
+												appGUI->cnt->contacts_columns[co_columns[i]], NULL);
+				n--;
+			}
+		}
+	}
+
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), COLUMN_GROUP),
+										  config.contacts_column_idx_0_width);
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), COLUMN_FIRST_NAME),
+										  config.contacts_column_idx_1_width);
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->cnt->contacts_list), COLUMN_LAST_NAME),
+										  config.contacts_column_idx_2_width - 2 * utl_gui_get_sw_vscrollbar_width (top_scrolledwindow));
+
     /* configure sorting */
 
     gtk_tree_sortable_set_sort_func((GtkTreeSortable *)appGUI->cnt->contacts_sort, 0,
@@ -1154,13 +1334,15 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_box_pack_start (GTK_BOX (appGUI->cnt->panel_hbox), label, FALSE, FALSE, 0);
 
     if (config.default_stock_icons) {
-        close_button = gui_stock_button(GTK_STOCK_CLOSE, FALSE);
+        close_button = utl_gui_stock_button (GTK_STOCK_CLOSE, FALSE);
     } else {
-        close_button = gui_stock_button(OSMO_STOCK_BUTTON_CLOSE, FALSE);
+        close_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLOSE, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
     gtk_button_set_relief (GTK_BUTTON(close_button), GTK_RELIEF_NONE);
-    gtk_tooltips_set_tip (appGUI->osmo_tooltips, close_button, _("Close contact panel"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (close_button, _("Close contact panel"));
+	}
     gtk_box_pack_end (GTK_BOX (appGUI->cnt->panel_hbox), close_button, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (close_button), "clicked",
                         G_CALLBACK (contacts_panel_close_desc_cb), appGUI);
@@ -1181,15 +1363,6 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_widget_show (appGUI->cnt->contacts_desc_textview);
     gtk_container_add (GTK_CONTAINER (appGUI->cnt->contacts_panel_scrolledwindow), appGUI->cnt->contacts_desc_textview);
 
-    /*gui_url_setup(&appGUI->cnt->contacts_links_list, &appGUI->cnt->contacts_link_index, appGUI->cnt->contacts_desc_textview, appGUI);*/
-
-    /*appGUI->cnt->contacts_www_textview = gtk_text_view_new ();*/
-    /*gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview), FALSE);*/
-    /*gtk_text_view_set_editable (GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview), FALSE);*/
-    /*gtk_widget_show (appGUI->cnt->contacts_www_textview);*/
-    /*gui_url_setup(&appGUI->cnt->contacts_www_links_list, */
-                  /*&appGUI->cnt->contacts_www_link_index, appGUI->cnt->contacts_www_textview, appGUI);*/
-
     adjustment = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(appGUI->cnt->contacts_panel_scrolledwindow));
     g_signal_connect(G_OBJECT(adjustment), "value-changed", G_CALLBACK(contacts_desc_scrolled), appGUI);
     g_signal_connect(G_OBJECT(appGUI->cnt->contacts_desc_textview), "size_allocate", 
@@ -1275,3 +1448,95 @@ gint rowstride, channels, bc1, bc2, bc3, bc4;
 
 /*------------------------------------------------------------------------------*/
 
+gboolean
+check_address (gint address_type, GUI *appGUI) {
+
+GtkTreeIter iter;
+GtkTreeModel *model;
+gchar *text = NULL;
+gint n = 0;
+gint c1, c2, c3;
+	
+    if (gtk_tree_selection_get_selected (appGUI->cnt->contacts_list_selection, &model, &iter)) {
+
+		if (address_type == HOME_ADDRESS) {
+			c1 = COLUMN_HOME_ADDRESS;
+			c2 = COLUMN_HOME_CITY;
+			c3 = COLUMN_HOME_COUNTRY;
+		} else {
+			c1 = COLUMN_WORK_ADDRESS;
+			c2 = COLUMN_WORK_CITY;
+			c3 = COLUMN_WORK_COUNTRY;
+		}
+
+		gtk_tree_model_get (model, &iter, c1, &text, -1);
+		if (text == NULL) return FALSE;
+		if (strlen(text)) n++;
+		g_free (text);
+		gtk_tree_model_get (model, &iter, c2, &text, -1);
+		if (text == NULL) return FALSE;
+		if (strlen(text)) n++;
+		g_free (text);
+		gtk_tree_model_get (model, &iter, c3, &text, -1);
+		if (text == NULL) return FALSE;
+		if (strlen(text)) n++;
+		g_free (text);
+	}
+
+	return (n == 3);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+show_contact_location_on_map (gint address_type, GUI *appGUI) {
+
+GtkTreeIter     iter;
+GtkTreeModel    *model;
+gboolean pn_flag = FALSE;
+gint i;
+gchar *text = NULL;
+gchar google_maps_url[BUFFER_SIZE];
+gint cbegin, cend, cskip1, cskip2;
+
+    if (gtk_tree_selection_get_selected (appGUI->cnt->contacts_list_selection, &model, &iter)) {
+
+		if (address_type == HOME_ADDRESS) {
+			cbegin = COLUMN_HOME_ADDRESS;
+			cend = COLUMN_HOME_COUNTRY;
+			cskip1 = COLUMN_HOME_POST_CODE;
+			cskip2 = COLUMN_HOME_STATE;
+		} else {
+			cbegin = COLUMN_WORK_ADDRESS;
+			cend = COLUMN_WORK_COUNTRY;
+			cskip1 = COLUMN_WORK_POST_CODE;
+			cskip2 = COLUMN_WORK_STATE;
+		}
+
+        g_snprintf (google_maps_url, BUFFER_SIZE, "%s\"", GOOGLE_MAPS_QUERY);
+
+		for (i = cbegin; i <= cend; i++) {
+
+			if (i == cskip1 || i == cskip2) continue;
+
+				gtk_tree_model_get (model, &iter, i, &text, -1);
+				if (text != NULL) {
+					if (pn_flag) {
+						g_strlcat (google_maps_url, ",", BUFFER_SIZE);
+					}
+					g_strlcat (google_maps_url, text, BUFFER_SIZE);
+					pn_flag = TRUE;
+					g_free (text);
+				}
+		}
+
+		g_strlcat (google_maps_url, "\"", BUFFER_SIZE);
+
+		utl_run_helper (google_maps_url, WWW);
+	}
+}
+
+/*------------------------------------------------------------------------------*/
+
+#endif  /* CONTACTS_ENABLED */
+
