@@ -29,6 +29,8 @@
 #define CONTACTS_GROUP_ENTRIES_NAME "contacts_groups"
 #define CONTACTS_ENTRIES_FILENAME   "contacts_records.xml"
 
+#define GOOGLE_MAPS_QUERY           "http://maps.google.com/maps?q="
+
 /* photo widths */
 #define PHOTO_SMALL     80
 #define PHOTO_MEDIUM    120
@@ -37,14 +39,23 @@
 enum {
     CONTACTS_FF_FIRST_NAME = 0,
     CONTACTS_FF_LAST_NAME,
+    CONTACTS_FF_TAGS,
     CONTACTS_FF_ALL_FIELDS
 };
 
+enum {
+	HOME_ADDRESS = 0,
+	WORK_ADDRESS
+};
+
 void        gui_create_contacts                     (GUI *appGUI);
 void        show_contacts_desc_panel                (gboolean enable, GUI *appGUI);
 void        set_export_active                       (GUI *appGUI);
+void        store_contact_columns_info              (GUI *appGUI);
 void        contacts_select_first_position_in_list  (GUI *appGUI);
 void        insert_photo                            (gchar *photo_filename, GtkTextIter *iter, GUI *appGUI);
+gboolean    check_address                           (gint address_type, GUI *appGUI);
+void        show_contact_location_on_map            (gint address_type, GUI *appGUI);
 void        contacts_selection_activate             (gboolean active, GUI *appGUI);
 
 #endif /* _CONTACTS_H */
