@@ -28,6 +28,9 @@
 #include "stock_icons.h"
 #include "calendar_utils.h"
 #include "utils.h"
+#include "utils_gui.h"
+
+#ifdef CONTACTS_ENABLED
 
 /*------------------------------------------------------------------------------*/
 
@@ -170,7 +173,7 @@ gboolean flag, leap;
 	}
 
 	if (n == 0) {
-		gui_create_dialog (GTK_MESSAGE_INFO, _("No birthdays defined"), GTK_WINDOW (appGUI->main_window));
+		utl_gui_create_dialog (GTK_MESSAGE_INFO, _("No birthdays defined"), GTK_WINDOW (appGUI->main_window));
 		return;
 	}
 
@@ -237,17 +240,17 @@ gboolean flag, leap;
 	g_signal_emit_by_name (column, "clicked");
 
 	column = gtk_tree_view_column_new_with_attributes (_("Age"), renderer, "text", B_COLUMN_AGE, NULL);
-	gtk_tree_view_column_set_visible (column, config.visible_age_column);
+	gtk_tree_view_column_set_visible (column, config.cnt_visible_age_column);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (appGUI->cnt->birthdays_list), column);
 	gtk_tree_view_column_set_sort_column_id (column, B_COLUMN_AGE);
 
 	column = gtk_tree_view_column_new_with_attributes (_("Birthday date"), renderer, "text", B_COLUMN_DATE, NULL);
-	gtk_tree_view_column_set_visible (column, config.visible_birthday_date_column);
+	gtk_tree_view_column_set_visible (column, config.cnt_visible_birthday_date_column);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (appGUI->cnt->birthdays_list), column);
 
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Zodiac sign"), renderer, "text", B_COLUMN_ZODIAC, NULL);
-	gtk_tree_view_column_set_visible (column, config.visible_zodiac_sign_column);
+	gtk_tree_view_column_set_visible (column, config.cnt_visible_zodiac_sign_column);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (appGUI->cnt->birthdays_list), column);
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -369,4 +372,5 @@ gboolean flag, leap;
 
 /*------------------------------------------------------------------------------*/
 
+#endif  /* CONTACTS_ENABLED */
 
