@@ -22,11 +22,14 @@
 #include "contacts_export.h"
 #include "i18n.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "contacts.h"
 #include "calendar_utils.h"
 #include "stock_icons.h"
 #include "options_prefs.h"
 
+#ifdef CONTACTS_ENABLED
+
 /*-------------------------------------------------------------------------------------*/
 
 void
@@ -93,7 +96,7 @@ gchar tmpbuf[BUFFER_SIZE];
             sprintf(tmpbuf, "%s %d %s.\n", _("Done!"), n,
                 ngettext ("contact exported", "contacts exported", n));
 
-            gui_create_dialog(GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW(appGUI->cnt->export_window));
+            utl_gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW(appGUI->cnt->export_window));
             export_window_close_cb (widget, NULL, appGUI);
 
         }
@@ -127,7 +130,7 @@ gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
 
     exported = 0;
 
-    if (gui_check_overwrite_file (filename, appGUI->cnt->export_window, appGUI) != 0) {
+    if (utl_gui_check_overwrite_file (filename, appGUI->cnt->export_window, appGUI) != 0) {
         return -1;
     }
 
@@ -399,7 +402,7 @@ gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
 
     } else {
 
-        gui_create_dialog(GTK_MESSAGE_ERROR, _("Cannot create file."), GTK_WINDOW(appGUI->cnt->export_window));
+        utl_gui_create_dialog(GTK_MESSAGE_ERROR, _("Cannot create file."), GTK_WINDOW(appGUI->cnt->export_window));
         return -1;
     }
 
@@ -811,7 +814,7 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
     }
 
     if (config.default_stock_icons) {
-        browse_dir_button = gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
+        browse_dir_button = utl_gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
     } else {
         browse_dir_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OPEN);
     }
@@ -859,3 +862,5 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
 
 /*-------------------------------------------------------------------------------------*/
 
+#endif  /* CONTACTS_ENABLED */
+
