@@ -24,11 +24,14 @@
 #include "contacts_import_syncml.h"
 #include "i18n.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "contacts.h"
 #include "calendar_utils.h"
 #include "stock_icons.h"
 #include "options_prefs.h"
 
+#ifdef CONTACTS_ENABLED
+
 /*-------------------------------------------------------------------------------------*/
 
 void
@@ -240,7 +243,7 @@ import_sel_cb (GtkWidget *widget, gpointer user_data) {
 
         if (!strlen(text)) {
             sprintf (tmpbuf, "%s", _("Please select file first."));
-            gui_create_dialog (GTK_MESSAGE_ERROR, tmpbuf, GTK_WINDOW(appGUI->cnt->import_sel_window));
+            utl_gui_create_dialog (GTK_MESSAGE_ERROR, tmpbuf, GTK_WINDOW(appGUI->cnt->import_sel_window));
             return;
         }
         add_csv_records(text, appGUI);
@@ -354,7 +357,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_editable_set_editable (GTK_EDITABLE(appGUI->cnt->input_file_entry), FALSE);
 
     if (config.default_stock_icons) {
-        appGUI->cnt->contacts_browse_button = gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
+        appGUI->cnt->contacts_browse_button = utl_gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
     } else {
         appGUI->cnt->contacts_browse_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OPEN);
     }
@@ -432,7 +435,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (appGUI->cnt->bluetooth_params_hbox), label, FALSE, FALSE, 0);
 
-    bluetooth_channel_spinbutton_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
+    bluetooth_channel_spinbutton_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
     appGUI->cnt->bluetooth_channel_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (bluetooth_channel_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cnt->bluetooth_channel_spinbutton);
     gtk_box_pack_start (GTK_BOX (appGUI->cnt->bluetooth_params_hbox), appGUI->cnt->bluetooth_channel_spinbutton, FALSE, FALSE, 0);
@@ -446,7 +449,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (appGUI->cnt->usb_params_hbox), label, FALSE, FALSE, 0);
 
-    usb_interface_spinbutton_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
+    usb_interface_spinbutton_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
     appGUI->cnt->usb_interface_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (usb_interface_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cnt->usb_interface_spinbutton);
     gtk_box_pack_start (GTK_BOX (appGUI->cnt->usb_params_hbox), appGUI->cnt->usb_interface_spinbutton, FALSE, FALSE, 0);
@@ -693,7 +696,7 @@ gchar tmpbuf[BUFFER_SIZE];
         k += appGUI->cnt->field_type[i];
     }
     if (!k) {
-        gui_create_dialog(GTK_MESSAGE_WARNING, _("Nothing to import."), GTK_WINDOW(appGUI->cnt->import_window));
+        utl_gui_create_dialog(GTK_MESSAGE_WARNING, _("Nothing to import."), GTK_WINDOW(appGUI->cnt->import_window));
         return;
     }
 
@@ -797,7 +800,7 @@ gchar tmpbuf[BUFFER_SIZE];
     }
 
     sprintf (tmpbuf, "%d %s.\n", n_records-n, ngettext ("contact added", "contacts added", n_records-n));
-    gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->cnt->import_window));
+    utl_gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->cnt->import_window));
     import_window_close_cb (NULL, NULL, appGUI);
 }
 
@@ -968,7 +971,7 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
                 gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
                 gtk_misc_set_padding (GTK_MISC (label), 6, 0);
 
-                appGUI->cnt->current_record_spinbutton_adj = gtk_adjustment_new (1, 1, n_records, 1, 10, 10);
+                appGUI->cnt->current_record_spinbutton_adj = gtk_adjustment_new (1, 1, n_records, 1, 10, 0);
                 appGUI->cnt->current_record_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (appGUI->cnt->current_record_spinbutton_adj), 1, 0);
                 gtk_widget_show (appGUI->cnt->current_record_spinbutton);
                 g_signal_connect (G_OBJECT (appGUI->cnt->current_record_spinbutton), "value-changed", 
@@ -1140,16 +1143,16 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
                 gtk_widget_set_sensitive (import_button, TRUE);
 
             } else {
-                gui_create_dialog(GTK_MESSAGE_ERROR, _("No records found in selected file."), GTK_WINDOW(appGUI->main_window));
+                utl_gui_create_dialog(GTK_MESSAGE_ERROR, _("No records found in selected file."), GTK_WINDOW(appGUI->main_window));
                 return FALSE;
             }
 
         } else {
-            gui_create_dialog(GTK_MESSAGE_ERROR, _("Cannot read file."), GTK_WINDOW(appGUI->main_window));
+            utl_gui_create_dialog(GTK_MESSAGE_ERROR, _("Cannot read file."), GTK_WINDOW(appGUI->main_window));
             return FALSE;
         }
     } else {
-        gui_create_dialog(GTK_MESSAGE_ERROR, _("Cannot open file."), GTK_WINDOW(appGUI->main_window));
+        utl_gui_create_dialog(GTK_MESSAGE_ERROR, _("Cannot open file."), GTK_WINDOW(appGUI->main_window));
         return FALSE;
     }
 
@@ -1158,3 +1161,5 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
 
 /*------------------------------------------------------------------------------*/
 
+#endif  /* CONTACTS_ENABLED */
+
