@@ -28,9 +28,12 @@
 #include "calendar_widget.h"
 #include "calendar_utils.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 
+#ifdef CONTACTS_ENABLED
+
 /*------------------------------------------------------------------------------*/
 
 void
@@ -199,7 +202,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
                 sprintf (tmpbuf, "%s\n\n%s", _("Selected contact will be removed."), _("Are you sure?"));
 
-                response = gui_create_dialog(GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
+                response = utl_gui_create_dialog(GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
 
                 if (response == GTK_RESPONSE_YES) {
                     gtk_tree_model_get_iter(GTK_TREE_MODEL(list_store), &iter, path);
@@ -280,9 +283,6 @@ const gchar *text;
            i != COLUMN_CELL_PHONE_4 && i != COLUMN_EMAIL_4 && i != COLUMN_WWW_4) {
             gtk_widget_show (msg->appGUI->cnt->contact_entries[i+1]);
             gtk_widget_grab_focus (msg->appGUI->cnt->contact_entries[i+1]);
-            if (i+1 == COLUMN_SECOND_NAME) {
-                gtk_widget_show (msg->appGUI->cnt->second_name_label);
-            }
         }
 
         return TRUE;
@@ -388,18 +388,15 @@ const gchar *text;
 
     if(strlen(text) && i != COLUMN_HOME_PHONE_4 && i != COLUMN_WORK_PHONE_4 &&
        i != COLUMN_CELL_PHONE_4 && i != COLUMN_EMAIL_4 && i != COLUMN_WWW_4) {
-        gtk_widget_set_sensitive (msg->appGUI->cnt->next_field_button[i], FALSE);
-        gtk_widget_show (msg->appGUI->cnt->contact_entries[i+1]);
+        gtk_widget_hide (msg->appGUI->cnt->next_field_button[i]);
 
-        if (msg->appGUI->cnt->next_field_button[i+1] != NULL) {
-            gtk_widget_show (msg->appGUI->cnt->next_field_button[i+1]);
-        }
+		gtk_widget_show (msg->appGUI->cnt->contact_entries[i+1]);
 
-        gtk_widget_grab_focus (msg->appGUI->cnt->contact_entries[i+1]);
+		if (msg->appGUI->cnt->next_field_button[i+1] != NULL) {
+			gtk_widget_show (msg->appGUI->cnt->next_field_button[i+1]);
+		}
 
-        if (i+1 == COLUMN_SECOND_NAME) {
-            gtk_widget_show (msg->appGUI->cnt->second_name_label);
-        }
+		gtk_widget_grab_focus (msg->appGUI->cnt->contact_entries[i+1]);
     }
 }
 
@@ -472,9 +469,9 @@ static MESSAGE msg_selected;
                         G_CALLBACK (select_date_nodate_cb), &msg_selected);
 
     if (config.default_stock_icons) {
-        ok_button = gui_stock_button(GTK_STOCK_OK, FALSE);
+        ok_button = utl_gui_stock_button (GTK_STOCK_OK, FALSE);
     } else {
-        ok_button = gui_stock_button(OSMO_STOCK_BUTTON_OK, FALSE);
+        ok_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_OK, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(ok_button, GTK_CAN_FOCUS);
     gtk_button_set_relief (GTK_BUTTON(ok_button), GTK_RELIEF_NONE);
@@ -484,9 +481,9 @@ static MESSAGE msg_selected;
                         G_CALLBACK (select_date_ok_cb), &msg_selected);
 
     if (config.default_stock_icons) {
-        close_button = gui_stock_button(GTK_STOCK_CANCEL, FALSE);
+        close_button = utl_gui_stock_button (GTK_STOCK_CANCEL, FALSE);
     } else {
-        close_button = gui_stock_button(OSMO_STOCK_BUTTON_CANCEL, FALSE);
+        close_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CANCEL, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
     gtk_button_set_relief (GTK_BUTTON(close_button), GTK_RELIEF_NONE);
@@ -623,7 +620,8 @@ gchar *contact_replace_tags[] = {
 
     appGUI->cnt->birthday_date = appGUI->cnt->nameday_date = 0;
 
-    gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->contacts_add_window), GTK_WINDOW(appGUI->main_window));
+    gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->contacts_add_window), 
+								 GTK_WINDOW(appGUI->main_window));
     gtk_window_set_modal(GTK_WINDOW(appGUI->cnt->contacts_add_window), TRUE);
     gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->contacts_add_window), 
                                  config.contacts_addedit_win_w, config.contacts_addedit_win_h);
@@ -649,13 +647,15 @@ gchar *contact_replace_tags[] = {
     contacts_add_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
     gtk_widget_show (contacts_add_scrolledwindow);
     gtk_box_pack_start (GTK_BOX (vbox2), contacts_add_scrolledwindow, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (contacts_add_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (contacts_add_scrolledwindow), 
+									GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
     viewport = gtk_viewport_new (NULL, NULL);
     gtk_widget_show (viewport);
     gtk_container_add (GTK_CONTAINER (contacts_add_scrolledwindow), viewport);
+	gtk_viewport_set_shadow_type (GTK_VIEWPORT(viewport), GTK_SHADOW_ETCHED_IN);
 
-    table = gtk_table_new (55, 4, FALSE);
+    table = gtk_table_new (60, 4, FALSE);       /* FIXME: don't use hardcoded values */
     gtk_widget_show (table);
     gtk_container_add (GTK_CONTAINER (viewport), table);
     gtk_container_set_border_width (GTK_CONTAINER (table), 4);
@@ -666,29 +666,16 @@ gchar *contact_replace_tags[] = {
 
     pos = 0;
 
-    hseparator = gtk_hseparator_new ();
-    gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 1, pos, pos+1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
-    gtk_widget_set_size_request (hseparator, 20, -1);
-
     sprintf(tmpbuf, "<b><big>%s</big></b>", _("Personal"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_misc_set_padding (GTK_MISC (label), 5, 0);
 
-    hseparator = gtk_hseparator_new ();
-    gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 2, 4, pos, pos+1,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
-
     pos++;
 
     sprintf(tmpbuf, "%s:", _("Group"));
@@ -707,7 +694,9 @@ gchar *contact_replace_tags[] = {
     gtk_table_attach (GTK_TABLE (table), appGUI->cnt->combobox_group, 2, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
-    gui_create_category_combobox (GTK_COMBO_BOX(appGUI->cnt->combobox_group), appGUI->opt->contacts_group_store, TRUE);
+
+	utl_gui_create_category_combobox (GTK_COMBO_BOX(appGUI->cnt->combobox_group), 
+									  appGUI->opt->contacts_group_store, TRUE);
 
     gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->cnt->combobox_group), 0);
 
@@ -717,11 +706,7 @@ gchar *contact_replace_tags[] = {
 
         sprintf(tmpbuf, "%s:", gettext(appGUI->cnt->contact_fields_tags_name[i*2]));
         label = gtk_label_new (tmpbuf);
-        if (i != COLUMN_SECOND_NAME) {
-            gtk_widget_show (label);
-        } else {
-            appGUI->cnt->second_name_label = label;
-        }
+		gtk_widget_show (label);
         gtk_table_attach (GTK_TABLE (table), label, 0, 2, pos, pos+1,
                           (GtkAttachOptions) (GTK_FILL),
                           (GtkAttachOptions) (0), 4, 0);
@@ -730,37 +715,19 @@ gchar *contact_replace_tags[] = {
         appGUI->cnt->contact_entries[i] = gtk_entry_new ();
 
         if (i == COLUMN_FIRST_NAME) {
-            appGUI->cnt->next_field_button[i] = gui_stock_button (GTK_STOCK_GO_DOWN, FALSE);
+            if (config.default_stock_icons) {
+                appGUI->cnt->next_field_button[i] = utl_gui_stock_button (GTK_STOCK_GO_DOWN, FALSE);
+            } else {
+                appGUI->cnt->next_field_button[i] = utl_gui_stock_button (OSMO_STOCK_BUTTON_DOWN, FALSE);
+            }
             gtk_widget_show (appGUI->cnt->next_field_button[i]);
             GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->next_field_button[i], GTK_CAN_FOCUS);
         }
 
-        if (i != COLUMN_SECOND_NAME) {
-            gtk_widget_show (appGUI->cnt->contact_entries[i]);
-        }
-
-        if (i == COLUMN_FIRST_NAME) {
-            msg_index[i].appGUI = appGUI;
-            msg_index[i].data = GINT_TO_POINTER(i);
-            g_signal_connect (G_OBJECT (appGUI->cnt->contact_entries[i]), "key_press_event",
-                              G_CALLBACK (show_hide_fields_key_press_cb), &msg_index[i]);
-
-            gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 3, pos, pos+1,
-                              (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                              (GtkAttachOptions) (0), 0, 0);
-
-            g_signal_connect (G_OBJECT (appGUI->cnt->next_field_button[i]), "clicked",
-                              G_CALLBACK (next_field_button_clicked_cb), &msg_index[i]);
-            gtk_table_attach (GTK_TABLE (table), appGUI->cnt->next_field_button[i], 3, 4, pos, pos+1,
-                              (GtkAttachOptions) (GTK_FILL),
-                              (GtkAttachOptions) (0), 0, 0);
-        } else {
-
-            gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 4, pos, pos+1,
-                              (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                              (GtkAttachOptions) (0), 0, 0);
-        }
-
+		gtk_widget_show (appGUI->cnt->contact_entries[i]);
+		gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 4, pos, pos+1,
+						  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+						  (GtkAttachOptions) (0), 0, 0);
         pos++;
     }
 
@@ -782,7 +749,7 @@ gchar *contact_replace_tags[] = {
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
-    appGUI->cnt->birth_day_date_button = gui_stock_button (OSMO_STOCK_BUTTON_SELECT_DATE, FALSE);
+    appGUI->cnt->birth_day_date_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_DATE, FALSE);
     GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->birth_day_date_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->cnt->birth_day_date_button);
     msg_date[0].data = (gpointer)COLUMN_BIRTH_DAY_DATE;
@@ -813,7 +780,7 @@ gchar *contact_replace_tags[] = {
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
-    appGUI->cnt->name_day_date_button = gui_stock_button (OSMO_STOCK_BUTTON_SELECT_DATE, FALSE);
+    appGUI->cnt->name_day_date_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_DATE, FALSE);
     GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->name_day_date_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->cnt->name_day_date_button);
     msg_date[1].data = (gpointer)COLUMN_NAME_DAY_DATE;
@@ -845,9 +812,9 @@ gchar *contact_replace_tags[] = {
                       (GtkAttachOptions) (0), 0, 0);
 
     if (config.default_stock_icons) {
-        appGUI->cnt->photo_browse_button = gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
+        appGUI->cnt->photo_browse_button = utl_gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
     } else {
-        appGUI->cnt->photo_browse_button = gui_stock_button (OSMO_STOCK_BUTTON_OPEN, FALSE);
+        appGUI->cnt->photo_browse_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_OPEN, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->photo_browse_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->cnt->photo_browse_button);
@@ -863,27 +830,21 @@ gchar *contact_replace_tags[] = {
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 1, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
-    gtk_widget_set_size_request (hseparator, 20, -1);
+	pos++;
 
     sprintf(tmpbuf, "<b><big>%s</big></b>", _("Home"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_misc_set_padding (GTK_MISC (label), 5, 0);
 
-    hseparator = gtk_hseparator_new ();
-    gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 2, 4, pos, pos+1,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
-
     pos++;
 
     for(i=COLUMN_HOME_ADDRESS; i<COLUMN_WORK_ORGANIZATION; i++) {
@@ -908,27 +869,21 @@ gchar *contact_replace_tags[] = {
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 1, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
-    gtk_widget_set_size_request (hseparator, 20, -1);
+					  (GtkAttachOptions) (GTK_FILL), 0, 0);
+	pos++;
 
     sprintf(tmpbuf, "<b><big>%s</big></b>", _("Work"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_misc_set_padding (GTK_MISC (label), 5, 0);
 
-    hseparator = gtk_hseparator_new ();
-    gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 2, 4, pos, pos+1,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
-
     pos++;
 
     for(i=COLUMN_WORK_ORGANIZATION; i<COLUMN_HOME_PHONE_1; i++) {
@@ -957,27 +912,21 @@ gchar *contact_replace_tags[] = {
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 1, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
-    gtk_widget_set_size_request (hseparator, 20, -1);
+	pos++;
 
     sprintf(tmpbuf, "<b><big>%s</big></b>", _("Phones"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_misc_set_padding (GTK_MISC (label), 5, 0);
 
-    hseparator = gtk_hseparator_new ();
-    gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 2, 4, pos, pos+1,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
-
     pos++;
 
     for(i=COLUMN_HOME_PHONE_1; i<COLUMN_EMAIL_1; i++) {
@@ -1000,7 +949,11 @@ gchar *contact_replace_tags[] = {
 
         if (i != COLUMN_HOME_PHONE_4 && i != COLUMN_WORK_PHONE_4 && i != COLUMN_CELL_PHONE_4) {
 
-            appGUI->cnt->next_field_button[i] = gui_stock_button (GTK_STOCK_GO_DOWN, FALSE);
+            if (config.default_stock_icons) {
+                appGUI->cnt->next_field_button[i] = utl_gui_stock_button (GTK_STOCK_GO_DOWN, FALSE);
+            } else {
+                appGUI->cnt->next_field_button[i] = utl_gui_stock_button (OSMO_STOCK_BUTTON_DOWN, FALSE);
+            }
             gtk_widget_hide (appGUI->cnt->next_field_button[i]);
             GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->next_field_button[i], GTK_CAN_FOCUS);
 
@@ -1026,27 +979,21 @@ gchar *contact_replace_tags[] = {
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 1, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
-    gtk_widget_set_size_request (hseparator, 20, -1);
+	pos++;
 
     sprintf(tmpbuf, "<b><big>%s</big></b>", _("Internet"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_misc_set_padding (GTK_MISC (label), 5, 0);
 
-    hseparator = gtk_hseparator_new ();
-    gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 2, 4, pos, pos+1,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
-
     pos++;
 
     for(i=COLUMN_EMAIL_1; i<COLUMN_PHOTO; i++) {
@@ -1061,9 +1008,6 @@ gchar *contact_replace_tags[] = {
 
         appGUI->cnt->contact_entries[i] = gtk_entry_new ();
         gtk_widget_show (appGUI->cnt->contact_entries[i]);
-        gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 3, pos, pos+1,
-                          (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                          (GtkAttachOptions) (0), 0, 0);
         msg_index[i].appGUI = appGUI;
         msg_index[i].data = GINT_TO_POINTER(i);
         g_signal_connect (G_OBJECT (appGUI->cnt->contact_entries[i]), "key_press_event",
@@ -1072,17 +1016,27 @@ gchar *contact_replace_tags[] = {
         if (i == COLUMN_EMAIL_1 || i == COLUMN_EMAIL_2 || i == COLUMN_EMAIL_3 || 
             i == COLUMN_WWW_1 || i == COLUMN_WWW_2 || i == COLUMN_WWW_3) {
 
-            appGUI->cnt->next_field_button[i] = gui_stock_button (GTK_STOCK_GO_DOWN, FALSE);
+            if (config.default_stock_icons) {
+                appGUI->cnt->next_field_button[i] = utl_gui_stock_button (GTK_STOCK_GO_DOWN, FALSE);
+            } else {
+                appGUI->cnt->next_field_button[i] = utl_gui_stock_button (OSMO_STOCK_BUTTON_DOWN, FALSE);
+            }
             gtk_widget_hide (appGUI->cnt->next_field_button[i]);
             GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->next_field_button[i], GTK_CAN_FOCUS);
 
             g_signal_connect (G_OBJECT (appGUI->cnt->next_field_button[i]), "clicked",
                               G_CALLBACK (next_field_button_clicked_cb), &msg_index[i]);
+			gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 3, pos, pos+1,
+							  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+							  (GtkAttachOptions) (0), 0, 0);
             gtk_table_attach (GTK_TABLE (table), appGUI->cnt->next_field_button[i], 3, 4, pos, pos+1,
                               (GtkAttachOptions) (GTK_FILL),
                               (GtkAttachOptions) (0), 0, 0);
         } else {
             appGUI->cnt->next_field_button[i] = NULL;
+			gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 4, pos, pos+1,
+							  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+							  (GtkAttachOptions) (0), 0, 0);
         }
 
 
@@ -1102,27 +1056,21 @@ gchar *contact_replace_tags[] = {
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 1, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), hseparator, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
-    gtk_widget_set_size_request (hseparator, 20, -1);
+	pos++;
 
     sprintf(tmpbuf, "<b><big>%s</big></b>", _("Additional info"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 4, pos, pos+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_misc_set_padding (GTK_MISC (label), 5, 0);
 
-    hseparator = gtk_hseparator_new ();
-    gtk_widget_show (hseparator);
-    gtk_table_attach (GTK_TABLE (table), hseparator, 2, 4, pos, pos+1,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
-
     pos++;
 
     scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
@@ -1210,14 +1158,14 @@ gchar *contact_replace_tags[] = {
 
                     if (text != NULL) {
                         if (i == COLUMN_GROUP) {
-                            gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->cnt->combobox_group),
-                                                     gui_list_store_get_text_index (appGUI->opt->contacts_group_store, text));
+                            gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->cnt->combobox_group),
+                                                      utl_gui_list_store_get_text_index (appGUI->opt->contacts_group_store, text));
                         } else if (i == COLUMN_INFO) {
-                            text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->add_info_textview));
-                            gui_clear_text_buffer (text_buffer, &titer);
-                            gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(text_buffer), &titer, 0);
-                            gtk_text_buffer_insert(text_buffer, &titer, text, -1);
-                            gtk_text_view_set_buffer(GTK_TEXT_VIEW(appGUI->cnt->add_info_textview), text_buffer);
+                            text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(appGUI->cnt->add_info_textview));
+                            utl_gui_clear_text_buffer (text_buffer, &titer);
+                            gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER(text_buffer), &titer, 0);
+                            gtk_text_buffer_insert (text_buffer, &titer, text, -1);
+                            gtk_text_view_set_buffer (GTK_TEXT_VIEW(appGUI->cnt->add_info_textview), text_buffer);
                         } else {
                             gtk_entry_set_text (GTK_ENTRY(appGUI->cnt->contact_entries[i]), text);
                             if (appGUI->cnt->next_field_button[i] != NULL) {
@@ -1248,9 +1196,10 @@ void
 read_contacts_entries (GUI *appGUI) {
 
 xmlDocPtr doc;
-xmlChar *key;
+xmlChar *key, *out;
 xmlNodePtr node, cnode, main_node;
 xmlNodePtr group_node;
+xmlParserCtxtPtr context;
 GtkTreeIter iter;
 gint j;
 guint32 date;
@@ -1282,12 +1231,15 @@ gchar tmpbuf[BUFFER_SIZE];
                 while (group_node != NULL) {
 
                     if ((!xmlStrcmp(group_node->name, (const xmlChar *) "name"))) {
-                        key = xmlNodeListGetString(doc, group_node->xmlChildrenNode, 1);
-                        if (key != NULL) {
+                        key = xmlNodeGetContent(group_node->xmlChildrenNode);
+                        context = xmlCreateDocParserCtxt(key);
+	                    out = (xmlChar*) xmlStringDecodeEntities(context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
+                	    xmlFreeParserCtxt (context);
+                        if (out != NULL) {
                             gtk_list_store_append(appGUI->opt->contacts_group_store, &iter);
-                            gtk_list_store_set(appGUI->opt->contacts_group_store, &iter, 0, (gchar *) key, -1);
+                            gtk_list_store_set(appGUI->opt->contacts_group_store, &iter, 0, (gchar *) out, -1);
                         }
-                        xmlFree(key);
+                        xmlFree(out);
                     }
 
                     group_node = group_node->next;
@@ -1321,17 +1273,23 @@ gchar tmpbuf[BUFFER_SIZE];
                                     if ((!xmlStrcmp(cnode->name, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1]))) {
 
                                         if (j == COLUMN_BIRTH_DAY_DATE || j == COLUMN_NAME_DAY_DATE) {
-                                            key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
-                                            if (key != NULL) {
-                                                sscanf((gchar *) key, "%d", &date);
+                                            key = xmlNodeGetContent(cnode->xmlChildrenNode);
+                                            context = xmlCreateDocParserCtxt(key);
+	                                        out = (xmlChar*) xmlStringDecodeEntities(context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
+                	                        xmlFreeParserCtxt (context);
+                                            if (out != NULL) {
+                                                sscanf((gchar *) out, "%d", &date);
                                                 gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, j, date, -1);
-                                                xmlFree(key);
+                                                xmlFree(out);
                                             }
                                         } else {
-                                            key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
-                                            if (key != NULL) {
-                                                gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, j, key, -1);
-                                                xmlFree(key);
+                                            key = xmlNodeGetContent(cnode->xmlChildrenNode);
+                                            context = xmlCreateDocParserCtxt(key);
+	                                        out = (xmlChar*) xmlStringDecodeEntities(context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
+                	                        xmlFreeParserCtxt (context);
+                                            if (out != NULL) {
+                                                gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, j, out, -1);
+                                                xmlFree(out);
                                             }
                                         }
                                     }
@@ -1373,35 +1331,34 @@ GtkTreeIter iter;
 gchar *item;
 guint32 date;
 gchar temp[BUFFER_SIZE];
-xmlChar *escaped;
 
     if ((appGUI->save_status & WRT_CONTACTS) != 0) return;
 
     appGUI->save_status |= WRT_CONTACTS;
 
-    doc = xmlNewDoc((const xmlChar *) "1.0");
+    doc = xmlNewDoc ((const xmlChar *) "1.0");
     attr = xmlNewDocProp (doc, (const xmlChar *) "encoding", (const xmlChar *) "utf-8");
 
-    main_node = xmlNewNode(NULL, (const xmlChar *) CONTACTS_NAME);
-    xmlDocSetRootElement(doc, main_node);
+    main_node = xmlNewNode (NULL, (const xmlChar *) CONTACTS_NAME);
+    xmlDocSetRootElement (doc, main_node);
 
-    node = xmlNewChild(main_node, NULL, (const xmlChar *) CONTACTS_GROUP_ENTRIES_NAME, (xmlChar *) NULL);
+    node = xmlNewChild (main_node, NULL, (const xmlChar *) CONTACTS_GROUP_ENTRIES_NAME, (xmlChar *) NULL);
 
     i = 0;
 
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &iter, NULL, i++)) {
-        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &iter, 0, &item, -1);
-        xmlNewChild(node, NULL, (const xmlChar *) "name", (xmlChar *) item);
-        g_free(item);
+        gtk_tree_model_get (GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &iter, 0, &item, -1);
+        utl_xml_put_str ("name", item, node, doc);
+        g_free (item);
     }
 
-    node = xmlNewChild(main_node, NULL, (const xmlChar *) CONTACTS_ENTRIES_NAME, (xmlChar *) NULL);
+    node = xmlNewChild (main_node, NULL, (const xmlChar *) CONTACTS_ENTRIES_NAME, (xmlChar *) NULL);
 
     i = 0;
 
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, NULL, i++)) {
 
-        note_node = xmlNewChild(node, NULL, (const xmlChar *) "record", (xmlChar *) NULL);
+        note_node = xmlNewChild (node, NULL, (const xmlChar *) "record", (xmlChar *) NULL);
 
         for (j = COLUMN_GROUP; j < CONTACTS_NUM_COLUMNS; j++) {
 
@@ -1409,21 +1366,17 @@ xmlChar *escaped;
 
                 if (j == COLUMN_BIRTH_DAY_DATE || j == COLUMN_NAME_DAY_DATE) {
 
-                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, j, &date, -1);
+                    gtk_tree_model_get (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, j, &date, -1);
                     sprintf(temp, "%d", date);
-                    xmlNewChild(note_node, NULL, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1], (xmlChar *) temp);
+                    utl_xml_put_str (appGUI->cnt->contact_fields_tags_name[j*2+1], temp, note_node, doc);
 
                 } else {
 
-                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, j, &item, -1);
+                    gtk_tree_model_get (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, j, &item, -1);
 
                     if (item != NULL) {
                         if (strlen(item)) {
-							escaped = xmlEncodeEntitiesReentrant(doc,
-								(const xmlChar *) item);
-                            xmlNewChild(note_node, NULL, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1],
-                                        escaped);
-							xmlFree(escaped);
+                            utl_xml_put_str (appGUI->cnt->contact_fields_tags_name[j*2+1], item, note_node, doc);
                         }
                     }
 
@@ -1433,12 +1386,13 @@ xmlChar *escaped;
         }
     }
 
-    xmlSaveFormatFileEnc(prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
-    xmlFreeDoc(doc);
+    xmlSaveFormatFileEnc (prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
+    xmlFreeDoc (doc);
 
     appGUI->save_status &= ~WRT_CONTACTS;
 }
 
 /*------------------------------------------------------------------------------*/
 
+#endif  /* CONTACTS_ENABLED */
 
