@@ -44,18 +44,25 @@ static OsmoCreditEntry credits_contributors[] = {
 };
 
 static OsmoCreditEntry credits_translators[] = {
+	{ "ca", "Roger Adell", "roger.adell@gmail.com" },
 	{ "cs", "Jaroslav Lichtblau", "dragonlord@seznam.cz" },
 	{ "de", "Markus Dahms", "mad@automagically.de" },
+    { "el", "Konstantinos Tsakaloglou", "tsakf@yahoo.com" },
 	{ "es", "Nacho Alonso González", "nacho.alonso.gonzalez@gmail.com" },
+	{ "fi", "Toivo Miettinen", "toivo.miettinen@panuma.fi" },
 	{ "fr", "Jean-Jacques Moulinier", "postmaster@moulinier.net" },
+    { NULL, "Rémi Roupsard", "remi.roupsard@gmail.com"},    /* fr */
+	{ NULL, "Lylliann Essandre", "lylliann@hotmail.fr"},  /* fr */
 	{ "hu", "Peter Polonkai", "polesz@nedudu.hu" },
 	{ "it", "Bautz", "bautz@email.com" },
+    { NULL, "Calogero Bonasia", "kbonasia@gmail.com" },
 	{ "ja", "Norihiro YONEDA", "aoba@avis.ne.jp" },
 	{ "lt", "Vaidotas Kazla", "joshas@gmail.com" },
 	{ "nl", "Tiger!P", "tigerp@tigerp.net" },
 	{ "pl", "Piotr Mąka", "silloz@users.sourceforge.net" },
 	{ "pt", "Bruno Miguel", "brunoalexandremiguel@gmail.com" },
     { "ru", "Vyacheslav A. Trishkin", "dedovsk@mail.ru" },
+	{ "sv", "Niklas Grahn", "terra.unknown@yahoo.com" },
     { "tr", "Hasan Yılmaz", "hasanyilmaz@users.sourceforge.net" },
     { "zh", "Sasaqqdan", "sasaqqdan@gmail.com" }
 };
