@@ -40,15 +40,21 @@
 
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
-
-#include <libnotify/notify.h>
+#include <libxml/parserInternals.h>
 
 #include <config.h>
 
+#ifdef HAVE_LIBNOTIFY
+#ifdef TASKS_ENABLED
+#include <libnotify/notify.h>
+#endif  /* TASKS_ENABLED */
+#endif  /* HAVE_LIBNOTIFY */
+
 #ifdef HAVE_LIBGRINGOTTS
 #include <libgringotts.h>
 #endif  /* HAVE_LIBGRINGOTTS */
 
+#define     APPLICATION_NAME        "Osmo (handy personal organizer)"
 #define     TRANSLATION_DOMAIN      "osmo"
 
 #define     MAX_MONTHS              12
@@ -60,27 +66,33 @@
 
 enum notebook_page {
     PAGE_CALENDAR = 0,
+#ifdef TASKS_ENABLED
     PAGE_TASKS,
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
     PAGE_CONTACTS,
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     PAGE_NOTES,
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
     PAGE_OPTIONS,
     PAGE_ABOUT,
     NUMBER_OF_TABS
 };
 
+#define MAX_VISIBLE_TASK_COLUMNS    6
+
 enum {                  /* tasks columns */
-    TA_COLUMN_DONE = 0,
-    TA_COLUMN_TYPE,
-    TA_COLUMN_DUE_DATE,
+    TA_COLUMN_DONE = 0,         /* V */
+    TA_COLUMN_TYPE,             /* V */
+    TA_COLUMN_DUE_DATE,         /* V */
     TA_COLUMN_DUE_DATE_JULIAN,
     TA_COLUMN_DUE_TIME,
     TA_COLUMN_START_DATE_JULIAN,
     TA_COLUMN_DONE_DATE_JULIAN,
-    TA_COLUMN_PRIORITY,
-    TA_COLUMN_CATEGORY,
-    TA_COLUMN_SUMMARY,
+    TA_COLUMN_PRIORITY,         /* V */
+    TA_COLUMN_CATEGORY,         /* V */
+    TA_COLUMN_SUMMARY,          /* V */
     TA_COLUMN_DESCRIPTION,
     TA_COLUMN_COLOR,
     TA_COLUMN_BOLD,
@@ -99,36 +111,62 @@ enum {                  /* tasks columns */
 	TA_COLUMN_ALARM_COMMAND,
 	TA_COLUMN_WARNING_DAYS,
 	TA_COLUMN_WARNING_TIME,
+	TA_COLUMN_POSTPONE_TIME,
 	TA_COLUMN_ID,
     TASKS_NUM_COLUMNS
 };
 
-enum {                  /* contacts columns */
-    COLUMN_GROUP = 0, COLUMN_FIRST_NAME, COLUMN_SECOND_NAME, 
-    COLUMN_LAST_NAME, COLUMN_NICK_NAME, COLUMN_BIRTH_DAY_DATE, COLUMN_NAME_DAY_DATE,
+#define MAX_VISIBLE_CONTACT_COLUMNS    3
 
-    COLUMN_HOME_ADDRESS, COLUMN_HOME_POST_CODE, COLUMN_HOME_CITY, COLUMN_HOME_STATE, 
+enum {                  /* contacts columns */
+    COLUMN_GROUP = 0    /* V */, COLUMN_FIRST_NAME  /* V */, COLUMN_LAST_NAME,  /* V */
+    COLUMN_SECOND_NAME, COLUMN_NICK_NAME, COLUMN_TAGS, COLUMN_BIRTH_DAY_DATE, COLUMN_NAME_DAY_DATE,
+
+    COLUMN_HOME_ADDRESS, COLUMN_HOME_POST_CODE, COLUMN_HOME_CITY, COLUMN_HOME_STATE,
     COLUMN_HOME_COUNTRY,
 
-    COLUMN_WORK_ORGANIZATION, COLUMN_WORK_DEPARTMENT, 
-    
-    COLUMN_WORK_ADDRESS, COLUMN_WORK_POST_CODE, COLUMN_WORK_CITY, COLUMN_WORK_STATE, 
-    COLUMN_WORK_COUNTRY, 
-    
+    COLUMN_WORK_ORGANIZATION, COLUMN_WORK_DEPARTMENT,
+
+    COLUMN_WORK_ADDRESS, COLUMN_WORK_POST_CODE, COLUMN_WORK_CITY, COLUMN_WORK_STATE,
+    COLUMN_WORK_COUNTRY,
+
     COLUMN_WORK_FAX,
-    
+
     COLUMN_HOME_PHONE_1, COLUMN_HOME_PHONE_2, COLUMN_HOME_PHONE_3, COLUMN_HOME_PHONE_4,
     COLUMN_WORK_PHONE_1, COLUMN_WORK_PHONE_2, COLUMN_WORK_PHONE_3, COLUMN_WORK_PHONE_4,
     COLUMN_CELL_PHONE_1, COLUMN_CELL_PHONE_2, COLUMN_CELL_PHONE_3, COLUMN_CELL_PHONE_4,
     COLUMN_EMAIL_1, COLUMN_EMAIL_2, COLUMN_EMAIL_3, COLUMN_EMAIL_4,
     COLUMN_WWW_1, COLUMN_WWW_2, COLUMN_WWW_3, COLUMN_WWW_4,
 
-    COLUMN_IM_GG, COLUMN_IM_YAHOO, COLUMN_IM_MSN, COLUMN_IM_ICQ, COLUMN_IM_AOL, 
+    COLUMN_IM_GG, COLUMN_IM_YAHOO, COLUMN_IM_MSN, COLUMN_IM_ICQ, COLUMN_IM_AOL,
     COLUMN_IM_JABBER, COLUMN_IM_SKYPE, COLUMN_IM_TLEN, COLUMN_BLOG, COLUMN_PHOTO, COLUMN_INFO,
     COLUMN_ID,
     CONTACTS_NUM_COLUMNS
 };
 
+#define MAX_VISIBLE_NOTE_COLUMNS    4
+
+enum {                  /* notes columns */
+    N_COLUMN_TYPE = 0,          /* V */
+    N_COLUMN_NAME,              /* V */
+    N_COLUMN_CATEGORY,          /* V */
+    N_COLUMN_LAST_CHANGES_DATE, /* V */
+    N_COLUMN_LAST_CHANGES_DATE_JULIAN,
+    N_COLUMN_LAST_CHANGES_TIME,
+    N_COLUMN_CREATE_DATE,
+    N_COLUMN_CREATE_DATE_JULIAN,
+    N_COLUMN_CREATE_TIME,
+    N_COLUMN_REMEMBER_EDITOR_LINE,
+    N_COLUMN_EDITOR_LINE,
+    N_COLUMN_FILENAME,
+    NOTES_NUM_COLUMNS
+};
+
+enum {
+    SELECTOR = 0,
+    EDITOR
+};
+
 enum {
     WRT_CALENDAR_NOTES = 1,
     WRT_TASKS = 1 << 1,
@@ -136,6 +174,11 @@ enum {
     WRT_NOTES = 1 << 3
 };
 
+enum {
+	PORTRAIT = 0,
+	LANDSCAPE
+};
+
 typedef struct {
 
     GtkWidget *calendar;
@@ -143,7 +186,7 @@ typedef struct {
 
     /* calendar toolbar */
     GtkToolbar *calendar_toolbar;
-    GtkBox  *vbox;      
+    GtkBox *vbox;
     PangoFontDescription *fd_cal_font;
 
     /* date label */
@@ -271,7 +314,7 @@ typedef struct {
     GtkWidget *spinbutton2_end_second;
     GtkWidget *label2_result;
     GtkWidget *radiobutton_add;
-    
+
     /* iCalendar */
     GtkWidget *events_window;
     GtkWidget *ical_combobox;
@@ -303,14 +346,29 @@ typedef struct {
     GtkWidget *notes_search_entry;
     GtkWidget *notes_search_checkbutton;
 
+	/* print */
+	GtkWidget *window_print_options;
+	GtkWidget *print_padding_spinbutton;
+	GtkWidget *print_event_length_spinbutton;
+	GtkWidget *print_tasks_checkbutton;
+	GtkWidget *print_birthdays_checkbutton;
+	GtkWidget *print_namedays_checkbutton;
+	GtkWidget *print_day_notes_checkbutton;
+	GtkWidget *print_ical_checkbutton;
+	GtkWidget *print_month_name_font_entry;
+	GtkWidget *print_day_name_font_entry;
+	GtkWidget *print_day_num_font_entry;
+	GtkWidget *print_event_font_entry;
+	GtkWidget *print_portrait_radiobutton;
 } CALENDAR;
 
 
+#ifdef TASKS_ENABLED
 typedef struct {
 
     /* tasks toolbar */
     GtkToolbar *tasks_toolbar;
-    GtkBox  *vbox;      
+    GtkBox *vbox;
 
     /* number of items label */
     GtkWidget *n_items_label;
@@ -318,7 +376,7 @@ typedef struct {
     GtkWidget *desc_textview;
     GtkWidget *tasks_desc_textview;
     GtkWidget *tasks_list;
-    GtkTreeSelection *tasks_list_selection; 
+    GtkTreeSelection *tasks_list_selection;
 
     gboolean tasks_panel_status;
     GtkListStore *tasks_list_store;
@@ -352,11 +410,12 @@ typedef struct {
     GtkWidget *aw_days_spinbutton;
     GtkWidget *aw_hours_spinbutton;
     GtkWidget *aw_minutes_spinbutton;
+    GtkWidget *postpone_spinbutton;
     GtkWidget *alarm_cmd_entry;
     GtkWidget *alarm_cmd_valid_image;
     GtkWidget *recurrent_task_vbox;
-    GtkWidget *rt_expander;
     GtkWidget *rt_enable_checkbutton;
+    GtkWidget *rt_frame;
     GtkWidget *ignore_alarm_checkbutton;
     GtkWidget *rt_start_hour_spinbutton;
     GtkWidget *rt_start_minute_spinbutton;
@@ -377,13 +436,14 @@ typedef struct {
     GSList *notifications;
 
 } TASKS;
+#endif  /* TASKS_ENABLED */
 
-
+#ifdef CONTACTS_ENABLED
 typedef struct {
 
     /* contacts toolbar */
     GtkToolbar *contacts_toolbar;
-    GtkBox  *vbox;      
+    GtkBox *vbox;
 
     GtkWidget *add_contact_button;
     GtkWidget *edit_contact_button;
@@ -434,7 +494,6 @@ typedef struct {
     GtkWidget *name_day_date_button;
     GtkWidget *combobox_group;
     GtkWidget *contact_entries[CONTACTS_NUM_COLUMNS];
-    GtkWidget *second_name_label;
     GtkWidget *select_date_window;
     GtkWidget *select_date_calendar;
     gboolean contacts_accept_state;
@@ -487,7 +546,9 @@ typedef struct {
     GtkWidget *use_wbxml_checkbutton;
 
 } CONTACTS;
+#endif  /* CONTACTS_ENABLED */
 
+#ifdef NOTES_ENABLED
 typedef struct {
 
     /* notes toolbar */
@@ -506,7 +567,7 @@ typedef struct {
     /* selector */
     GtkWidget *notes_list;
     GtkListStore *notes_list_store;
-    GtkTreeSelection *notes_list_selection; 
+    GtkTreeSelection *notes_list_selection;
 
     GtkWidget *add_entry_window;
     GtkWidget *edit_entry_window;
@@ -517,12 +578,17 @@ typedef struct {
     GtkWidget *password_entry;
     GtkWidget *spassword_entry;
     GtkWidget *category_combobox;
+	GtkWidget *note_normal_radiobutton;
+    GtkWidget *remember_cursor_checkbutton;
+    GtkTreeViewColumn *notes_columns[NOTES_NUM_COLUMNS];
+
+    gchar *filename;
+	gboolean encrypted;
 
 #ifdef HAVE_LIBGRINGOTTS
-    gchar *filename;
     GRG_CTX context;
     GRG_KEY keyholder;
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif /* HAVE_LIBGRINGOTTS */
 
     /* category filter */
     GtkTreeModel *notes_filter;
@@ -545,15 +611,20 @@ typedef struct {
     GtkWidget *find_case_checkbutton;
 
 } NOTES;
+#endif  /* NOTES_ENABLED */
 
 typedef struct {
 
     GtkWidget *calendar_options_radiobutton;
+#ifdef TASKS_ENABLED
     GtkWidget *tasks_options_radiobutton;
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
     GtkWidget *contacts_options_radiobutton;
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     GtkWidget *notes_options_radiobutton;
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
     GtkWidget *general_options_radiobutton;
 
     gboolean callback_active;
@@ -579,6 +650,7 @@ typedef struct {
     GtkWidget *enable_auxilary_calendars_checkbutton;
     GtkWidget *strikethrough_past_notes_checkbutton;
     GtkWidget *ascending_sorting_in_day_notes_checkbutton;
+    GtkWidget *spell_checker_in_day_notes_checkbutton;
     GtkWidget *enable_block_cursor_checkbutton;
     GtkWidget *day_marker_entry;
     GtkWidget *day_name_font_entry;
@@ -621,6 +693,7 @@ typedef struct {
     GtkWidget *di_show_notes_checkbutton;
     GtkWidget *di_show_zodiac_sign_checkbutton;
 
+#ifdef TASKS_ENABLED
     /* tasks */
     GtkWidget *tasks_vbox;
     GtkWidget *ti_font_entry;
@@ -648,7 +721,9 @@ typedef struct {
     GtkWidget *postpone_time_spinbutton;
     GtkWidget *global_notification_cmd_entry;
     GtkWidget *global_notification_valid_image;
+#endif  /* TASKS_ENABLED */
 
+#ifdef CONTACTS_ENABLED
     /* contacts */
     GtkWidget *contacts_vbox;
     GtkWidget *contacts_enable_rules_hint_checkbutton;
@@ -670,7 +745,9 @@ typedef struct {
     GtkWidget *vc_age_checkbutton;
     GtkWidget *vc_birthday_date_checkbutton;
     GtkWidget *vc_zodiac_sign_checkbutton;
+#endif  /* CONTACTS_ENABLED */
 
+#ifdef NOTES_ENABLED
     /* notes */
     GtkWidget *notes_vbox;
     GtkWidget *editor_font_entry;
@@ -687,8 +764,12 @@ typedef struct {
     GtkWidget *notes_sort_mode_combobox;
     GtkWidget *notes_category_add_button;
     GtkWidget *notes_category_remove_button;
+    GtkWidget *nvc_type_checkbutton;
+    GtkWidget *nvc_category_checkbutton;
+    GtkWidget *nvc_last_changes_checkbutton;
     GtkWidget *cn_remember_category_checkbutton;
     GtkWidget *cn_use_system_date_checkbutton;
+#endif  /* NOTES_ENABLED */
 
     /* general */
     GtkWidget *general_vbox;
@@ -697,6 +778,7 @@ typedef struct {
     GtkWidget *time_format_combobox;
     GtkWidget *entry_web_browser;
     GtkWidget *entry_email_client;
+    GtkWidget *entry_spell_lang;
     GtkWidget *enable_tooltips_checkbutton;
     GtkWidget *disable_underline_in_links_checkbutton;
     GtkWidget *default_stock_icons_checkbutton;
@@ -704,6 +786,8 @@ typedef struct {
     GtkWidget *save_data_checkbutton;
     GtkWidget *enable_systray_checkbutton;
     GtkWidget *start_minimised_checkbutton;
+    GtkWidget *blink_on_events_checkbutton;
+    GtkWidget *ignore_day_note_events_checkbutton;
     GtkWidget *hide_calendar_checkbutton;
     GtkWidget *hide_tasks_checkbutton;
     GtkWidget *hide_contacts_checkbutton;
@@ -722,13 +806,20 @@ typedef struct {
     gint current_tab;
     gint number_of_tabs;
 
-    /* tooltips */
-    GtkTooltips *osmo_tooltips; 
-
     /* tray icon */
     GtkStatusIcon *osmo_trayicon;
     GtkWidget *trayicon_popup_menu;
     gboolean no_tray;
+	GtkWidget *trayicon_menu_calendar_item;
+#ifdef TASKS_ENABLED
+	GtkWidget *trayicon_menu_tasks_item;
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
+	GtkWidget *trayicon_menu_contacts_item;
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
+	GtkWidget *trayicon_menu_notes_item;
+#endif  /* NOTES_ENABLED */
 
     /* command line parameters */
     gboolean calendar_only;
@@ -736,7 +827,7 @@ typedef struct {
     gint check_ndays_events;
     gchar *config_path;
     gboolean tiny_gui;
-    
+
     /* links handling */
     gboolean hovering_over_link;
     GdkCursor *hand_cursor;
@@ -776,9 +867,15 @@ typedef struct {
 
     /* modules */
     CALENDAR *cal;
+#ifdef TASKS_ENABLED
     TASKS *tsk;
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
     CONTACTS *cnt;
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     NOTES *nte;
+#endif  /* NOTES_ENABLED */
 
     OPTIONS *opt;
 
@@ -796,6 +893,7 @@ void        gui_save_all_data               (GUI *appGUI);
 void        gui_save_data_and_run_command   (gchar *command, GUI *appGUI);
 void        gui_quit_osmo                   (gboolean ignore_geometry, GUI *appGUI);
 void        gui_systray_initialize          (GUI *appGUI);
+void        gui_systray_update_icon         (GUI *appGUI);
 void        gui_systray_tooltip_update      (GUI *appGUI);
 void        about_switch_buttons            (gboolean left, GUI *appGUI);
 void        about_set_first_page            (GUI *appGUI);
