@@ -35,9 +35,19 @@ int main(int argc, char **argv) {
 
 GUI *appGUI = NULL;
 CALENDAR *cal = NULL;
+
+#ifdef TASKS_ENABLED
 TASKS *tsk = NULL;
+#endif  /* TASKS_ENABLED */
+
+#ifdef CONTACTS_ENABLED
 CONTACTS *cnt = NULL;
+#endif  /* CONTACTS_ENABLED */
+
+#ifdef NOTES_ENABLED
 NOTES *nte = NULL;
+#endif  /* NOTES_ENABLED */
+
 OPTIONS *opt = NULL;
 GtkWidget *info_dialog;
 gchar tmpbuf[BUFFER_SIZE];
@@ -66,21 +76,40 @@ GOptionEntry cmd_options[] = {
 
     cal = g_new0 (CALENDAR, 1);
     g_return_val_if_fail (cal != NULL, -1);
+
+#ifdef TASKS_ENABLED
     tsk = g_new0 (TASKS, 1);
     g_return_val_if_fail (tsk != NULL, -1);
+#endif  /* TASKS_ENABLED */
+
+#ifdef CONTACTS_ENABLED
     cnt = g_new0 (CONTACTS, 1);
     g_return_val_if_fail (cnt != NULL, -1);
+#endif  /* CONTACTS_ENABLED */
+
+#ifdef NOTES_ENABLED
     nte = g_new0 (NOTES, 1);
     g_return_val_if_fail (nte != NULL, -1);
+#endif  /* NOTES_ENABLED */
 
     opt = g_new0 (OPTIONS, 1);
     g_return_val_if_fail (opt != NULL, -1);
 
     /* register modules */
     appGUI->cal = cal;
+
+#ifdef TASKS_ENABLED
     appGUI->tsk = tsk;
+#endif  /* TASKS_ENABLED */
+
+#ifdef CONTACTS_ENABLED
     appGUI->cnt = cnt;
+#endif  /* CONTACTS_ENABLED */
+
+#ifdef NOTES_ENABLED
     appGUI->nte = nte;
+#endif  /* NOTES_ENABLED */
+
     appGUI->opt = opt;
 
     appGUI->run_date = utl_get_current_julian ();
@@ -104,18 +133,22 @@ GOptionEntry cmd_options[] = {
 	g_return_val_if_fail (appGUI->cal->date != NULL, -1);
 	g_date_set_time_t (appGUI->cal->date, time (NULL));
 
+#ifdef TASKS_ENABLED
     appGUI->tsk->id_counter = 0;
     appGUI->tsk->tasks_panel_status = FALSE;
     appGUI->tsk->tasks_filter_disabled = FALSE;
     appGUI->tsk->tasks_list_store = NULL;
     appGUI->tsk->notifications = NULL;
+#endif  /* TASKS_ENABLED */
 
+#ifdef CONTACTS_ENABLED
     appGUI->cnt->photo_image = NULL;
     appGUI->cnt->contacts_uim_widget = NULL;
     appGUI->cnt->contacts_panel_status = FALSE;
     appGUI->cnt->contacts_filter_disabled = TRUE;
     appGUI->cnt->export_button = NULL;
     appGUI->cnt->output_file_entry = NULL;
+#endif  /* CONTACTS_ENABLED */
 
     appGUI->opt->options_counter = 0;
 
@@ -153,38 +186,45 @@ GOptionEntry cmd_options[] = {
 
     prefs_read_config (appGUI);
 
-    close(creat(prefs_get_config_filename (RUN_FLAG_FILE, appGUI), S_IRUSR | S_IWUSR));     /* create lock file */
-
     gtk_init (&argc, &argv);
 
-    fhandle = open(prefs_get_config_filename (RUN_FLAG_FILE, appGUI), O_RDWR);
+	if (appGUI->calendar_only == FALSE) {
 
-    if (fhandle) {
-		if (fcntl(fhandle, F_SETLK, s_lock) == -1) {
-            close (fhandle);
+		close(creat(prefs_get_config_filename (RUN_FLAG_FILE, appGUI), S_IRUSR | S_IWUSR));     /* create lock file */
 
-            g_snprintf (tmpbuf, BUFFER_SIZE, "%s %s\n\n%s",
-                        _("Another copy of OSMO is already running."),
-                        _("Simultaneously use two or more copies of OSMO can be a cause of data loss."),
-                        _("Do you really want to continue?"));
+		fhandle = open(prefs_get_config_filename (RUN_FLAG_FILE, appGUI), O_RDWR);
 
-            info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW_TOPLEVEL, GTK_DIALOG_MODAL,
-                                                  GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, tmpbuf);
+		if (fhandle) {
+			if (fcntl(fhandle, F_SETLK, s_lock) == -1) {
+				close (fhandle);
 
-            gtk_window_set_title(GTK_WINDOW(info_dialog), _("Warning"));
-            gtk_window_set_position(GTK_WINDOW(info_dialog), GTK_WIN_POS_CENTER);
-            gtk_widget_show (info_dialog);
+				g_snprintf (tmpbuf, BUFFER_SIZE, "%s %s\n\n%s",
+							_("Another copy of OSMO is already running."),
+							_("Simultaneously use two or more copies of OSMO can be a cause of data loss."),
+							_("Do you really want to continue?"));
 
-            response = gtk_dialog_run(GTK_DIALOG(info_dialog));
-            gtk_widget_destroy(info_dialog);
+				info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW_TOPLEVEL, GTK_DIALOG_MODAL,
+													  GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, tmpbuf);
 
-            if (response == GTK_RESPONSE_NO || response == GTK_RESPONSE_DELETE_EVENT) {
-                goto finish;
-            }
-        }
-    }
+				gtk_window_set_title(GTK_WINDOW(info_dialog), _("Warning"));
+				gtk_window_set_position(GTK_WINDOW(info_dialog), GTK_WIN_POS_CENTER);
+				gtk_widget_show (info_dialog);
 
+				response = gtk_dialog_run(GTK_DIALOG(info_dialog));
+				gtk_widget_destroy(info_dialog);
+
+				if (response == GTK_RESPONSE_NO || response == GTK_RESPONSE_DELETE_EVENT) {
+					goto finish;
+				}
+			}
+		}
+	}
+
+#ifdef HAVE_LIBNOTIFY
+#ifdef TASKS_ENABLED
 	notify_init("Osmo notification");
+#endif  /* TASKS_ENABLED */
+#endif  /* HAVE_LIBNOTIFY */
 
     if (appGUI->calendar_only != TRUE) {
 
@@ -195,6 +235,9 @@ GOptionEntry cmd_options[] = {
 
     config.run_counter++;
 
+	g_set_application_name (_(APPLICATION_NAME));
+	gtk_window_set_default_icon_name ("osmo");
+
     if (gui_create_window (appGUI) == TRUE) {
         gtk_main ();
     }
@@ -208,7 +251,7 @@ GOptionEntry cmd_options[] = {
         prefs_write_config (appGUI);
     }
 
-    if (fhandle) {
+    if (fhandle && appGUI->calendar_only == FALSE) {
     	s_lock->l_type = F_UNLCK;
     	fcntl(fhandle, F_SETLK, s_lock);
         close (fhandle);
@@ -217,9 +260,19 @@ GOptionEntry cmd_options[] = {
 finish:
 	g_date_free (appGUI->cal->date);
 	g_free (opt);
+
+#ifdef NOTES_ENABLED
 	g_free (nte);
+#endif  /* NOTES_ENABLED */
+
+#ifdef CONTACTS_ENABLED
 	g_free (cnt);
+#endif  /* CONTACTS_ENABLED */
+
+#ifdef TASKS_ENABLED
 	g_free (tsk);
+#endif  /* TASKS_ENABLED */
+
 	g_free (cal);
 	g_free (appGUI);
 	g_free (s_lock);
