@@ -27,11 +27,18 @@
 #include "notes_items.h"
 #include "calendar_utils.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "stock_icons.h"
 
-#ifdef HAVE_LIBGRINGOTTS
+#ifdef NOTES_ENABLED
 
+#ifdef HAVE_LIBGRINGOTTS
 #include <libgringotts.h>
+#endif /* HAVE_LIBGRINGOTTS */
+
+#ifdef HAVE_GTKSPELL
+#include <gtkspell/gtkspell.h>
+#endif /* HAVE_GTKSPELL */
 
 /*------------------------------------------------------------------------------*/
 
@@ -45,6 +52,7 @@ GtkTreeIter n_iter;
 GtkTreePath *path, *sort_path, *filter_path;
 gchar *name;
 gint line;
+gboolean remember_cursor;
 gchar tmpbuf[BUFFER_SIZE];
 
     if (mode == SELECTOR) { 
@@ -76,17 +84,27 @@ gchar tmpbuf[BUFFER_SIZE];
         gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, path);
         gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, 
                             N_COLUMN_NAME, &name, 
-                            N_COLUMN_EDITOR_LINE, &line, -1);
+                            N_COLUMN_EDITOR_LINE, &line, 
+							N_COLUMN_REMEMBER_EDITOR_LINE, &remember_cursor, -1);
         sprintf (tmpbuf, "<i>%s</i>", name);
         gtk_label_set_markup (GTK_LABEL (appGUI->nte->title_label), tmpbuf);
         g_free(name);
         gtk_tree_path_free (path);
 
-        buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
-        gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (buffer), &iter, line);
-        gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (buffer), &iter);
-        cursor = gtk_text_buffer_get_mark (buffer, "insert");
-        gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (appGUI->nte->editor_textview), cursor, 0.0, TRUE, 0.0, 0.0);
+		/* restore cursor position */
+
+		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+
+		if (remember_cursor == TRUE) {
+			gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (buffer), &iter, line);
+			gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (buffer), &iter);
+			cursor = gtk_text_buffer_get_mark (buffer, "insert");
+			gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW (appGUI->nte->editor_textview), cursor, 0.0, TRUE, 0.0, 0.0);
+		} else {
+			gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
+			gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (buffer), &iter);
+			gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (appGUI->nte->editor_textview), &iter, 0.0, FALSE, 0.0, 0.0);
+		}
     }
 }
 
@@ -96,7 +114,6 @@ void
 editor_save_buffer_cb (GtkWidget *widget, gpointer user_data) {
 
 GtkTextBuffer *buffer;
-gint ret;
 guchar *text;
 guint32 current_date;
 gint current_time;
@@ -108,35 +125,44 @@ GtkTreeModel *model;
 
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
 
-    if (appGUI->nte->keyholder != NULL && appGUI->nte->context != NULL && appGUI->nte->filename != NULL) {
+	text = (unsigned char*) utl_gui_text_buffer_get_text_with_tags (buffer);
 
-        text = (unsigned char*) gui_text_buffer_get_text_with_tags (buffer);
+	if (appGUI->nte->encrypted == TRUE) {
 
-        ret = grg_encrypt_file (appGUI->nte->context, appGUI->nte->keyholder, 
-                                (unsigned char*) appGUI->nte->filename, 
-                                (guchar *) text, -1);
+#ifdef HAVE_LIBGRINGOTTS
+	if (appGUI->nte->keyholder != NULL && appGUI->nte->context != NULL && appGUI->nte->filename != NULL) {
+        grg_encrypt_file (appGUI->nte->context, appGUI->nte->keyholder,
+						  (unsigned char*) notes_get_full_filename(appGUI->nte->filename, appGUI), 
+						  (guchar *) text, -1);
 
         grg_free (appGUI->nte->context, text, -1);
+	}
+#endif /* HAVE_LIBGRINGOTTS */
 
-        appGUI->nte->changed = FALSE;
-        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/save"), FALSE);
+	} else {
 
-        if (gtk_tree_selection_get_selected (appGUI->nte->notes_list_selection, &model, &iter)) {
+		g_file_set_contents (notes_get_full_filename(appGUI->nte->filename, appGUI), 
+							 (gchar *) text, strlen((gchar *) text), NULL);
+	}
 
-            current_date = utl_get_current_julian ();
-            current_time = get_seconds_for_today ();
+	appGUI->nte->changed = FALSE;
+	gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/save"), FALSE);
 
-            gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), 
-                                                              &sort_child_iter, &iter);
-            gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), 
-                                                              &filter_child_iter, &sort_child_iter);
+	if (gtk_tree_selection_get_selected (appGUI->nte->notes_list_selection, &model, &iter)) {
 
-            gtk_list_store_set(appGUI->nte->notes_list_store, &filter_child_iter, 
-                               N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (current_date, current_time),
-                               N_COLUMN_LAST_CHANGES_DATE_JULIAN, current_date,
-                               N_COLUMN_LAST_CHANGES_TIME, current_time, -1);
-        }
-    }
+		current_date = utl_get_current_julian ();
+		current_time = get_seconds_for_today ();
+
+		gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), 
+														  &sort_child_iter, &iter);
+		gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), 
+														  &filter_child_iter, &sort_child_iter);
+
+		gtk_list_store_set(appGUI->nte->notes_list_store, &filter_child_iter, 
+						   N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (current_date, current_time),
+						   N_COLUMN_LAST_CHANGES_DATE_JULIAN, current_date,
+						   N_COLUMN_LAST_CHANGES_TIME, current_time, -1);
+	}
 }
 
 /*------------------------------------------------------------------------------*/
@@ -158,7 +184,7 @@ editor_find_text_hide_cb (GtkWidget *widget, gpointer user_data) {
 
     GUI *appGUI = (GUI *)user_data;
         
-    gui_change_bg_widget_state (appGUI->nte->find_entry, NULL, appGUI);
+    utl_gui_change_bg_widget_state (appGUI->nte->find_entry, NULL, appGUI);
 
     gtk_widget_hide (appGUI->nte->find_hbox);
     gtk_widget_grab_focus (appGUI->nte->editor_textview);
@@ -184,7 +210,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
         sprintf (tmpbuf, "%s\n\n%s", _("The note has changed."), _("Do you want to save it?"));
 
-        response = gui_create_dialog(GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
+        response = utl_gui_create_dialog (GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
 
         if (response == GTK_RESPONSE_YES) {   
             editor_save_buffer_cb (NULL, appGUI);
@@ -193,16 +219,25 @@ gchar tmpbuf[BUFFER_SIZE];
         }
     }
 
+#ifdef HAVE_GTKSPELL
+	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/spell_check")), FALSE);
+#endif /* HAVE_GTKSPELL */
+
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
 
-    if (appGUI->nte->keyholder != NULL && appGUI->nte->context != NULL && appGUI->nte->filename != NULL) {
+#ifdef HAVE_LIBGRINGOTTS
+    if (appGUI->nte->keyholder != NULL && appGUI->nte->context != NULL) {
         grg_key_free (appGUI->nte->context, appGUI->nte->keyholder);
         appGUI->nte->keyholder = NULL;
 	    grg_context_free (appGUI->nte->context);
         appGUI->nte->context = NULL;
+    }
+#endif /* HAVE_LIBGRINGOTTS */
+
+    if (appGUI->nte->filename != NULL) {
         g_free(appGUI->nte->filename);
         appGUI->nte->filename = NULL;
-    }
+	}
 
     cursor = gtk_text_buffer_get_mark (buffer, "insert");
     gtk_text_buffer_get_iter_at_mark (buffer, &l_iter, cursor);
@@ -371,23 +406,14 @@ time_t tmm;
 void
 insert_separator_cb (GtkWidget *widget, gpointer data) {
 
-gint chars, i, sbwidth;
+gint chars, i;
 gchar tmpbuf[BUFFER_SIZE];
 PangoLayout *layout;
 PangoRectangle logical_rect;
 GtkWidget *vscrollbar;
-GValue *value;
 
     GUI *appGUI = (GUI *)data;
 
-    value = g_new0 (GValue, 1);
-	value = g_value_init (value, G_TYPE_INT);
-    vscrollbar = gtk_scrolled_window_get_vscrollbar (GTK_SCROLLED_WINDOW (appGUI->nte->editor_scrolledwindow));
-    gtk_widget_style_get_property (vscrollbar, "slider-width", value);
-    sbwidth = g_value_get_int (value);
-	g_value_unset (value);
-    g_free (value);
-
     memset (tmpbuf, 0, BUFFER_SIZE);
 
     tmpbuf[0] = config.text_separator;
@@ -396,10 +422,12 @@ GValue *value;
     pango_layout_set_text (layout, tmpbuf, -1);
     pango_layout_get_pixel_extents (layout, NULL, &logical_rect);
 
-    if (GTK_WIDGET_VISIBLE(vscrollbar) == TRUE) {
+    vscrollbar = gtk_scrolled_window_get_vscrollbar (GTK_SCROLLED_WINDOW (appGUI->nte->editor_scrolledwindow));
+
+	if (GTK_WIDGET_VISIBLE(vscrollbar) == TRUE) {
         chars = ((appGUI->nte->editor_textview)->allocation.width) / logical_rect.width;
     } else {
-        chars = ((appGUI->nte->editor_textview)->allocation.width - sbwidth) / logical_rect.width;
+        chars = ((appGUI->nte->editor_textview)->allocation.width - utl_gui_get_sw_vscrollbar_width (appGUI->nte->editor_scrolledwindow)) / logical_rect.width;
     }
     chars = (chars > BUFFER_SIZE) ? BUFFER_SIZE - 2 : chars;
 
@@ -497,8 +525,8 @@ gint i, words, lines, chars, white_chars, bytes;
                 _("Characters"), chars,
                 _("White characters"), white_chars,
                 _("Bytes"), bytes,
-                _("Modified"), modified_date_str,
-                _("Created"), created_date_str);
+                _("Created"), created_date_str,
+                _("Modified"), modified_date_str);
 
     g_free (modified_date_str);
     g_free (created_date_str);
@@ -507,7 +535,7 @@ gint i, words, lines, chars, white_chars, bytes;
     g_free (text);
     g_free (attrs);
 
-	gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->main_window));
+	utl_gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW (appGUI->main_window));
 }
 
 /*------------------------------------------------------------------------------*/
@@ -582,7 +610,7 @@ gint i;
         if (gtk_text_iter_forward_search (iter, find_text, GTK_TEXT_SEARCH_TEXT_ONLY, 
                                           &match_start, &match_end, NULL)) {
 
-            gui_change_bg_widget_state (appGUI->nte->find_entry, COLOR_BG_OK, appGUI);
+            utl_gui_change_bg_widget_state (appGUI->nte->find_entry, COLOR_BG_OK, appGUI);
             gtk_text_buffer_select_range (buffer, &match_start, &match_end);
             gtk_text_buffer_create_mark (buffer, "last_pos", &match_end, FALSE);
 
@@ -591,7 +619,7 @@ gint i;
             gtk_text_buffer_delete_mark (buffer, found_pos);
 
         } else {
-            gui_change_bg_widget_state (appGUI->nte->find_entry, COLOR_BG_FAIL, appGUI);
+            utl_gui_change_bg_widget_state (appGUI->nte->find_entry, COLOR_BG_FAIL, appGUI);
             if (gtk_text_buffer_get_mark (buffer, "last_pos") != NULL) {
                 gtk_text_buffer_delete_mark_by_name (buffer, "last_pos");
             }
@@ -721,11 +749,11 @@ gchar *category;
 
     GUI *appGUI = (GUI *)data;
 
-    gtk_tree_model_get(model, iter, N_COLUMN_CATEGORY, &category, -1);
+    gtk_tree_model_get (model, iter, N_COLUMN_CATEGORY, &category, -1);
 
     if(appGUI->nte->filter_index) {
 
-        if (gui_list_store_get_text_index (appGUI->opt->notes_category_store, category) == appGUI->nte->filter_index) {
+        if (utl_gui_list_store_get_text_index (appGUI->opt->notes_category_store, category) == appGUI->nte->filter_index) {
             g_free (category);
             return TRUE;
         } else {
@@ -867,6 +895,44 @@ guint32 last_changes_date_s;
 
 /*------------------------------------------------------------------------------*/
 
+#ifdef HAVE_GTKSPELL
+void
+notes_spell_check_cb (GtkToggleToolButton *toggle_tool_button, gpointer data) {
+
+    GUI *appGUI = (GUI *)data;
+    GtkSpell *edSpell;
+
+	if (gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (toggle_tool_button)) == TRUE) {
+        edSpell = gtkspell_new_attach (GTK_TEXT_VIEW(appGUI->nte->editor_textview), NULL, NULL);
+        gtkspell_set_language (edSpell, config.spell_lang, NULL);
+    } else {
+        gtkspell_detach (gtkspell_get_from_text_view (GTK_TEXT_VIEW(appGUI->nte->editor_textview)));
+    }
+}
+#endif /* HAVE_GTKSPELL */
+
+/*------------------------------------------------------------------------------*/ 
+
+void
+store_note_columns_info (GUI *appGUI) {
+
+	config.notes_column_idx_0 = utl_gui_get_column_position (appGUI->nte->notes_columns[N_COLUMN_TYPE], 
+															 GTK_TREE_VIEW(appGUI->nte->notes_list), MAX_VISIBLE_NOTE_COLUMNS, appGUI);
+	config.notes_column_idx_1 = utl_gui_get_column_position (appGUI->nte->notes_columns[N_COLUMN_NAME], 
+															 GTK_TREE_VIEW(appGUI->nte->notes_list), MAX_VISIBLE_NOTE_COLUMNS, appGUI);
+	config.notes_column_idx_2 = utl_gui_get_column_position (appGUI->nte->notes_columns[N_COLUMN_CATEGORY], 
+															 GTK_TREE_VIEW(appGUI->nte->notes_list), MAX_VISIBLE_NOTE_COLUMNS, appGUI);
+	config.notes_column_idx_3 = utl_gui_get_column_position (appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE], 
+															 GTK_TREE_VIEW(appGUI->nte->notes_list), MAX_VISIBLE_NOTE_COLUMNS, appGUI);
+
+	config.notes_column_idx_0_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 0));
+	config.notes_column_idx_1_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 1));
+	config.notes_column_idx_2_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 2));
+	config.notes_column_idx_3_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 3));
+}
+
+/*------------------------------------------------------------------------------*/
+
 void 
 gui_create_notes (GUI *appGUI) {
 
@@ -878,12 +944,12 @@ GError              *error = NULL;
 GtkActionGroup      *action_group_selector = NULL;
 GtkActionGroup      *action_group_editor = NULL;
 GtkCellRenderer     *renderer;
-GtkTreeViewColumn   *column;
 GtkWidget           *hseparator;
 GtkWidget           *label;
 GtkWidget           *vseparator;
 GtkWidget           *close_button;
 GtkWidget           *table;
+gint i, n;
 
 gchar tmpbuf[BUFFER_SIZE];
 
@@ -907,6 +973,9 @@ const gchar *ui_info_editor =
 "  <toolbar name=\"toolbar\">\n"
 "    <toolitem name=\"save\" action=\"save\" />\n"
 "    <toolitem name=\"find\" action=\"find\" />\n"
+#ifdef HAVE_GTKSPELL
+"    <toolitem name=\"spell_check\" action=\"spell_check\" />\n"
+#endif /* HAVE_GTKSPELL */
 "    <separator name=\"sep1\" />\n"
 "    <toolitem name=\"bold\" action=\"bold\" />\n"
 "    <toolitem name=\"italic\" action=\"italic\" />\n"
@@ -938,7 +1007,22 @@ GtkActionEntry entries_editor[] = {
 };
 
 guint n_entries_editor = G_N_ELEMENTS (entries_editor);
-  
+
+gint columns_order[MAX_VISIBLE_NOTE_COLUMNS];
+
+gint nt_columns[MAX_VISIBLE_NOTE_COLUMNS] = { 
+		N_COLUMN_TYPE, N_COLUMN_NAME, N_COLUMN_CATEGORY, N_COLUMN_LAST_CHANGES_DATE
+};
+
+#ifdef HAVE_GTKSPELL
+
+GtkToggleActionEntry t_entries_editor[] = {
+    { "spell_check", OSMO_STOCK_EDITOR_SPELL_CHECKER, _("Toggle spell checker"), NULL, _("Toggle spell checker"), NULL, FALSE }
+};
+
+guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
+
+#endif /* HAVE_GTKSPELL */
 
     vbox1 = gtk_vbox_new (FALSE, 1);
     gtk_widget_show (vbox1);
@@ -978,12 +1062,14 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
     gtk_ui_manager_ensure_update (appGUI->nte->notes_uim_selector_widget);
 
     gtk_toolbar_set_style (appGUI->nte->notes_toolbar_selector, GTK_TOOLBAR_ICONS);
-    gtk_toolbar_set_tooltips (appGUI->nte->notes_toolbar_selector, config.enable_tooltips);
 
     /*-------------------------------------------------------------------------------------*/
 
     action_group_editor = gtk_action_group_new ("_actions");
     gtk_action_group_add_actions (action_group_editor, entries_editor, n_entries_editor, NULL);
+#ifdef HAVE_GTKSPELL
+    gtk_action_group_add_toggle_actions (action_group_editor, t_entries_editor, n_t_entries_editor, NULL);
+#endif /* HAVE_GTKSPELL */
     gtk_action_group_set_sensitive(action_group_editor, TRUE);
 
     appGUI->nte->notes_uim_editor_widget = gtk_ui_manager_new ();
@@ -999,7 +1085,6 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
     gtk_ui_manager_ensure_update (appGUI->nte->notes_uim_editor_widget);
 
     gtk_toolbar_set_style (appGUI->nte->notes_toolbar_editor, GTK_TOOLBAR_ICONS);
-    gtk_toolbar_set_tooltips (appGUI->nte->notes_toolbar_editor, config.enable_tooltips);
 
     /*-------------------------------------------------------------------------------------*/
     /* assign callbacks */
@@ -1080,10 +1165,10 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
     gtk_container_add (GTK_CONTAINER (viewport), scrolled_win);
 
     appGUI->nte->notes_list_store = gtk_list_store_new(NOTES_NUM_COLUMNS, 
-                                                       G_TYPE_STRING, G_TYPE_STRING,
+                                                       GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING,
                                                        G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT,
                                                        G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT,
-                                                       G_TYPE_UINT, G_TYPE_STRING);
+                                                       G_TYPE_BOOLEAN, G_TYPE_UINT, G_TYPE_STRING);
 
     appGUI->nte->notes_filter = gtk_tree_model_filter_new(GTK_TREE_MODEL(appGUI->nte->notes_list_store), NULL);
     gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), 
@@ -1108,87 +1193,142 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
 
     /* create columns */
 
+	renderer = gtk_cell_renderer_pixbuf_new();  /* icon */
+    appGUI->nte->notes_columns[N_COLUMN_TYPE] = gtk_tree_view_column_new_with_attributes(_("Type"),
+																						 renderer,
+																						 "pixbuf", N_COLUMN_TYPE,
+																						 NULL);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_TYPE]);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_TYPE], config.nte_visible_type_column);
+	gtk_tree_view_column_set_reorderable (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_TYPE]), TRUE);
+	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_TYPE]), TRUE);
+    gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_TYPE]), GTK_TREE_VIEW_COLUMN_FIXED);
+
     renderer = gtk_cell_renderer_text_new();
     g_object_set(G_OBJECT(renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
-    column = gtk_tree_view_column_new_with_attributes(_("Note name"),
-                                                      renderer,
-                                                      "text", N_COLUMN_NAME,
-                                                      NULL);
-    gtk_tree_view_column_set_visible (column, TRUE);
-    gtk_tree_view_column_set_expand (column, TRUE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    appGUI->nte->notes_columns[N_COLUMN_NAME] = gtk_tree_view_column_new_with_attributes(_("Note name"), 
+																						 renderer,
+																						 "text", N_COLUMN_NAME,
+																						 NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_NAME], TRUE);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_NAME]);
+	gtk_tree_view_column_set_reorderable (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_NAME]), TRUE);
+	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_NAME]), TRUE);
+    gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_NAME]), GTK_TREE_VIEW_COLUMN_FIXED);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Category"),
-                                                      renderer,
-                                                      "text", N_COLUMN_CATEGORY,
-                                                      NULL);
-    gtk_tree_view_column_set_visible (column, TRUE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    appGUI->nte->notes_columns[N_COLUMN_CATEGORY] = gtk_tree_view_column_new_with_attributes(_("Category"),
+																							 renderer,
+																							 "text", N_COLUMN_CATEGORY,
+																							 NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_CATEGORY], config.nte_visible_category_column);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_CATEGORY]);
+	gtk_tree_view_column_set_reorderable (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_CATEGORY]), TRUE);
+	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_CATEGORY]), TRUE);
+    gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_CATEGORY]), GTK_TREE_VIEW_COLUMN_FIXED);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Last changes"),
-                                                      renderer,
-                                                      "text", N_COLUMN_LAST_CHANGES_DATE,
-                                                      NULL);
-    gtk_tree_view_column_set_visible (column, TRUE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE] = gtk_tree_view_column_new_with_attributes(_("Last changes"),
+																									  renderer,
+																									  "text", N_COLUMN_LAST_CHANGES_DATE,
+																									  NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE], config.nte_visible_last_changes_column);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE]);
+	gtk_tree_view_column_set_reorderable (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE]), TRUE);
+	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE]), TRUE);
+    gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE]), GTK_TREE_VIEW_COLUMN_FIXED);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(NULL,
-                                                      renderer,
-                                                      "text", N_COLUMN_LAST_CHANGES_DATE_JULIAN,
-                                                      NULL);
-    gtk_tree_view_column_set_visible (column, FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE_JULIAN] = gtk_tree_view_column_new_with_attributes(NULL,
+																											 renderer, 
+																											 "text", N_COLUMN_LAST_CHANGES_DATE_JULIAN, 
+																											 NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE_JULIAN], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE_JULIAN]);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(NULL,
-                                                      renderer,
-                                                      "text", N_COLUMN_LAST_CHANGES_TIME,
-                                                      NULL);
-    gtk_tree_view_column_set_visible (column, FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_TIME] = gtk_tree_view_column_new_with_attributes(NULL,
+																									  renderer,
+																									  "text", N_COLUMN_LAST_CHANGES_TIME,
+																									  NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_TIME], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_TIME]);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(NULL,
-                                                      renderer,
-                                                      "text", N_COLUMN_CREATE_DATE,
-                                                      NULL);
-    gtk_tree_view_column_set_visible (column, FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    appGUI->nte->notes_columns[N_COLUMN_CREATE_DATE] = gtk_tree_view_column_new_with_attributes(NULL,
+																								renderer,
+																								"text", N_COLUMN_CREATE_DATE,
+																								NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_CREATE_DATE], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_CREATE_DATE]);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(NULL,
-                                                      renderer,
-                                                      "text", N_COLUMN_CREATE_DATE_JULIAN,
-                                                      NULL);
-    gtk_tree_view_column_set_visible (column, FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    appGUI->nte->notes_columns[N_COLUMN_CREATE_DATE_JULIAN] = gtk_tree_view_column_new_with_attributes(NULL,
+																									   renderer,
+																									   "text", N_COLUMN_CREATE_DATE_JULIAN,
+																									   NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_CREATE_DATE_JULIAN], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_CREATE_DATE_JULIAN]);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(NULL,
-                                                      renderer,
-                                                      "text", N_COLUMN_CREATE_TIME,
-                                                      NULL);
-    gtk_tree_view_column_set_visible (column, FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    appGUI->nte->notes_columns[N_COLUMN_CREATE_TIME] = gtk_tree_view_column_new_with_attributes(NULL,
+																								renderer, 
+																								"text", N_COLUMN_CREATE_TIME,
+																								NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_CREATE_TIME], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_CREATE_TIME]);
+
+	renderer = gtk_cell_renderer_text_new();
+    appGUI->nte->notes_columns[N_COLUMN_REMEMBER_EDITOR_LINE] = gtk_tree_view_column_new_with_attributes(NULL,
+																										 renderer,
+																										 "text", N_COLUMN_REMEMBER_EDITOR_LINE,
+																										 NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_REMEMBER_EDITOR_LINE], FALSE);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_REMEMBER_EDITOR_LINE]);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(NULL,
-                                                      renderer,
-                                                      "text", N_COLUMN_EDITOR_LINE,
-                                                      NULL);
-    gtk_tree_view_column_set_visible (column, FALSE);
-    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    appGUI->nte->notes_columns[N_COLUMN_EDITOR_LINE] = gtk_tree_view_column_new_with_attributes(NULL,
+																								renderer, 
+																								"text", N_COLUMN_EDITOR_LINE,
+																								NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_EDITOR_LINE], FALSE);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_EDITOR_LINE]);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(NULL,
-                                                      renderer,
-                                                      "text", N_COLUMN_FILENAME,
-                                                      NULL);
-    gtk_tree_view_column_set_visible (column, FALSE);
-    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    appGUI->nte->notes_columns[N_COLUMN_FILENAME] = gtk_tree_view_column_new_with_attributes(NULL,
+																							 renderer,
+																							 "text", N_COLUMN_FILENAME,
+																							 NULL);
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_FILENAME], FALSE);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_FILENAME]);
+
+	/* restore columns order */
+
+	columns_order[0] = config.notes_column_idx_0;
+	columns_order[1] = config.notes_column_idx_1;
+	columns_order[2] = config.notes_column_idx_2;
+	columns_order[3] = config.notes_column_idx_3;
+
+	n = MAX_VISIBLE_NOTE_COLUMNS-1;
+
+	while (n >= 0) {
+		for (i = 0; i < MAX_VISIBLE_NOTE_COLUMNS; i++) {
+			if (n == columns_order[i]) {
+				gtk_tree_view_move_column_after(GTK_TREE_VIEW(appGUI->nte->notes_list),
+												appGUI->nte->notes_columns[nt_columns[i]], NULL);
+				n--;
+			}
+		}
+	}
+
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 0),
+										  config.notes_column_idx_0_width);
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 1),
+										  config.notes_column_idx_1_width);
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 2),
+										  config.notes_column_idx_2_width);
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->nte->notes_list), 3),
+										  config.notes_column_idx_3_width);
 
     /* configure sorting */
 
@@ -1280,6 +1420,10 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
                       "clicked", G_CALLBACK (editor_save_buffer_cb), appGUI);
     g_signal_connect (G_OBJECT (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/find")), 
                       "clicked", G_CALLBACK (editor_find_text_show_cb), appGUI);
+#ifdef HAVE_GTKSPELL
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/spell_check")), "toggled", 
+                      G_CALLBACK(notes_spell_check_cb), appGUI);
+#endif /* HAVE_GTKSPELL */
 
     appGUI->nte->find_hbox = gtk_hbox_new (FALSE, 0);
     gtk_widget_show (appGUI->nte->find_hbox);
@@ -1308,13 +1452,15 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
 
 
     if (config.default_stock_icons) {
-        close_button = gui_stock_button(GTK_STOCK_CLOSE, FALSE);
+        close_button = utl_gui_stock_button (GTK_STOCK_CLOSE, FALSE);
     } else {
-        close_button = gui_stock_button(OSMO_STOCK_BUTTON_CLOSE, FALSE);
+        close_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLOSE, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
     gtk_button_set_relief (GTK_BUTTON(close_button), GTK_RELIEF_NONE);
-    gtk_tooltips_set_tip (appGUI->osmo_tooltips, close_button, _("Close find entry"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (close_button, _("Close find entry"));
+	}
     gtk_box_pack_end (GTK_BOX (appGUI->nte->find_hbox), close_button, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (close_button), "clicked",
                       G_CALLBACK (editor_find_text_hide_cb), appGUI);
@@ -1333,11 +1479,65 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
     notes_show_selector_editor (SELECTOR, appGUI);
 
     appGUI->nte->filename = NULL;
+
+#ifdef HAVE_LIBGRINGOTTS
     appGUI->nte->context = NULL;
     appGUI->nte->keyholder = NULL;
+#endif /* HAVE_LIBGRINGOTTS */
+
 }
 
 /*------------------------------------------------------------------------------*/
 
-#endif  /* HAVE_LIBGRINGOTTS */
+gboolean
+check_if_encrypted (gchar *filename, GUI *appGUI) {
+
+gchar *contents;
+gboolean result = FALSE;
+
+	if (g_file_get_contents (notes_get_full_filename(filename, appGUI), &contents, NULL, NULL) == TRUE) {
+
+		if (contents[0] == 'O' && contents[1] == 'S' && contents[2] == 'M' && g_ascii_isalnum(contents[3])) {
+			result = TRUE;
+		}
+
+		g_free (contents);
+	}
+
+	return result;
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+check_notes_type (GUI *appGUI) {
+
+GtkTreeIter iter;
+gint i;
+gchar *filename;
+GdkPixbuf *image;
+GtkWidget *helper;
+
+    helper = gtk_image_new ();
+	i = 0;
+
+    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, NULL, i++)) {
+
+        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, 
+                           N_COLUMN_FILENAME, &filename, -1);
+
+		if (check_if_encrypted (filename, appGUI) == TRUE) {
+			image = gtk_widget_render_icon (helper, OSMO_STOCK_TYPE_ENCRYPTED, GTK_ICON_SIZE_MENU, NULL);
+		} else {
+			image = gtk_widget_render_icon (helper, OSMO_STOCK_TYPE_NORMAL, GTK_ICON_SIZE_MENU, NULL);
+		}
+
+		gtk_list_store_set(appGUI->nte->notes_list_store, &iter, N_COLUMN_TYPE, image, -1);
+		g_object_unref (image);
+	}
+}
+
+/*------------------------------------------------------------------------------*/
+
+#endif  /* NOTES_ENABLED */
 
