@@ -30,28 +30,12 @@
 #define NOTES_DIRNAME               "notes"
 #define NOTES_ENTRIES_FILENAME      "notes_entries.xml"
 
-enum {                  /* notes columns */
-    N_COLUMN_NAME = 0,
-    N_COLUMN_CATEGORY,
-    N_COLUMN_LAST_CHANGES_DATE,
-    N_COLUMN_LAST_CHANGES_DATE_JULIAN,
-    N_COLUMN_LAST_CHANGES_TIME,
-    N_COLUMN_CREATE_DATE,
-    N_COLUMN_CREATE_DATE_JULIAN,
-    N_COLUMN_CREATE_TIME,
-    N_COLUMN_EDITOR_LINE,
-    N_COLUMN_FILENAME,
-    NOTES_NUM_COLUMNS
-};
-
-enum {
-    SELECTOR = 0,
-    EDITOR
-};
-
-void    notes_show_selector_editor  (gint mode, GUI *appGUI);
-void    gui_create_notes            (GUI *appGUI);
-void    update_notes_items          (GUI *appGUI);
+void        notes_show_selector_editor  (gint mode, GUI *appGUI);
+void        gui_create_notes            (GUI *appGUI);
+void        update_notes_items          (GUI *appGUI);
+gboolean    check_if_encrypted          (gchar *filename, GUI *appGUI);
+void        check_notes_type            (GUI *appGUI);
+void        store_note_columns_info     (GUI *appGUI);
 
 #endif /* _NOTES_H */
 
