@@ -21,6 +21,7 @@
 
 #include "options_gui.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
@@ -35,6 +36,10 @@
 #include "contacts.h"
 #include "stock_icons.h"
 
+#ifdef HAVE_GTKSPELL
+#include <gtkspell/gtkspell.h>
+#endif /* HAVE_GTKSPELL */
+
 struct  osmo_prefs              config;
 
 /*------------------------------------------------------------------------------*/
@@ -46,12 +51,14 @@ options_get_first_active_page (GUI *appGUI) {
         return OPT_PAGE_CALENDAR;
     if (!config.hide_tasks) 
         return OPT_PAGE_TASKS;
+#ifdef CONTACTS_ENABLED
     if (!config.hide_contacts) 
         return OPT_PAGE_CONTACTS;
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     if (!config.hide_notes) 
         return OPT_PAGE_NOTES;
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
 
     return OPT_PAGE_GENERAL;
 }
@@ -81,26 +88,30 @@ gint n = 1;
                     flag = TRUE;
                 }
                 break;
+#ifdef TASKS_ENABLED
             case OPT_PAGE_TASKS:
                 if (config.hide_tasks) {
                     appGUI->opt->options_counter += n;
                     flag = TRUE;
                 }
                 break;
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
             case OPT_PAGE_CONTACTS:
                 if (config.hide_contacts) {
                     appGUI->opt->options_counter += n;
                     flag = TRUE;
                 }
                 break;
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
             case OPT_PAGE_NOTES:
                 if (config.hide_notes) {
                     appGUI->opt->options_counter += n;
                     flag = TRUE;
                 }
                 break;
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
         }
     }
 
@@ -113,17 +124,21 @@ gint n = 1;
     if (appGUI->opt->options_counter == OPT_PAGE_CALENDAR){
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->calendar_options_radiobutton), TRUE);
         g_signal_emit_by_name(G_OBJECT(appGUI->opt->calendar_options_radiobutton), "released");
+#ifdef TASKS_ENABLED
     } else if (appGUI->opt->options_counter == OPT_PAGE_TASKS) {
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->tasks_options_radiobutton), TRUE);
         g_signal_emit_by_name(G_OBJECT(appGUI->opt->tasks_options_radiobutton), "released");
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
     } else if (appGUI->opt->options_counter == OPT_PAGE_CONTACTS) {
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_options_radiobutton), TRUE);
         g_signal_emit_by_name(G_OBJECT(appGUI->opt->contacts_options_radiobutton), "released");
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     } else if (appGUI->opt->options_counter == OPT_PAGE_NOTES) {
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->notes_options_radiobutton), TRUE);
         g_signal_emit_by_name(G_OBJECT(appGUI->opt->notes_options_radiobutton), "released");
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
     } else {
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->general_options_radiobutton), TRUE);
         g_signal_emit_by_name(G_OBJECT(appGUI->opt->general_options_radiobutton), "released");
@@ -138,11 +153,15 @@ options_button_released_cb (GtkButton *button, gpointer user_data) {
     GUI *appGUI = (GUI *)user_data;
 
     gtk_widget_hide (appGUI->opt->calendar_vbox);
+#ifdef TASKS_ENABLED
     gtk_widget_hide (appGUI->opt->tasks_vbox);
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
     gtk_widget_hide (appGUI->opt->contacts_vbox);
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     gtk_widget_hide (appGUI->opt->notes_vbox);
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
     gtk_widget_hide (appGUI->opt->general_vbox);
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->calendar_options_radiobutton)) == TRUE) {
@@ -150,22 +169,26 @@ options_button_released_cb (GtkButton *button, gpointer user_data) {
         gtk_widget_show (appGUI->opt->calendar_vbox);
         appGUI->opt->options_counter = OPT_PAGE_CALENDAR;
 
+#ifdef TASKS_ENABLED
     } else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->tasks_options_radiobutton)) == TRUE) {
 
         gtk_widget_show (appGUI->opt->tasks_vbox);
         appGUI->opt->options_counter = OPT_PAGE_TASKS;
+#endif  /* TASKS_ENABLED */
 
+#ifdef CONTACTS_ENABLED
     } else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_options_radiobutton)) == TRUE) {
 
         gtk_widget_show (appGUI->opt->contacts_vbox);
         appGUI->opt->options_counter = OPT_PAGE_CONTACTS;
+#endif  /* CONTACTS_ENABLED */
 
-#ifdef HAVE_LIBGRINGOTTS
+#ifdef NOTES_ENABLED
     } else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->notes_options_radiobutton)) == TRUE) {
 
         gtk_widget_show (appGUI->opt->notes_vbox);
         appGUI->opt->options_counter = OPT_PAGE_NOTES;
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
 
     } else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->general_options_radiobutton)) == TRUE) {
 
@@ -211,9 +234,10 @@ GSList              *radiobutton_group = NULL;
     }
 
     if (appGUI->tiny_gui == TRUE) {
-        appGUI->opt->calendar_options_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_CALENDAR, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        appGUI->opt->calendar_options_radiobutton = utl_gui_stock_label_radio_button (NULL, OSMO_STOCK_CALENDAR, 
+																					  GTK_ICON_SIZE_LARGE_TOOLBAR);
     } else {
-        appGUI->opt->calendar_options_radiobutton = gui_stock_label_radio_button(_("Calendar"), 
+        appGUI->opt->calendar_options_radiobutton = utl_gui_stock_label_radio_button(_("Calendar"), 
                                                                  OSMO_STOCK_CALENDAR, GTK_ICON_SIZE_LARGE_TOOLBAR);
         gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->calendar_options_radiobutton);
     }
@@ -228,10 +252,13 @@ GSList              *radiobutton_group = NULL;
     g_signal_connect (G_OBJECT (appGUI->opt->calendar_options_radiobutton), "released",
                       G_CALLBACK(options_button_released_cb), appGUI);
 
+#ifdef TASKS_ENABLED
+
     if (appGUI->tiny_gui == TRUE) {
-        appGUI->opt->tasks_options_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_TASKS, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        appGUI->opt->tasks_options_radiobutton = utl_gui_stock_label_radio_button (NULL, OSMO_STOCK_TASKS, 
+																				   GTK_ICON_SIZE_LARGE_TOOLBAR);
     } else {
-        appGUI->opt->tasks_options_radiobutton = gui_stock_label_radio_button(_("Tasks"), 
+        appGUI->opt->tasks_options_radiobutton = utl_gui_stock_label_radio_button(_("Tasks"), 
                                                                  OSMO_STOCK_TASKS, GTK_ICON_SIZE_LARGE_TOOLBAR);
         gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->tasks_options_radiobutton);
     }
@@ -245,10 +272,15 @@ GSList              *radiobutton_group = NULL;
     g_signal_connect (G_OBJECT (appGUI->opt->tasks_options_radiobutton), "released",
                       G_CALLBACK(options_button_released_cb), appGUI);
 
+#endif  /* TASKS_ENABLED */
+
+#ifdef CONTACTS_ENABLED
+
     if (appGUI->tiny_gui == TRUE) {
-        appGUI->opt->contacts_options_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_CONTACTS, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        appGUI->opt->contacts_options_radiobutton = utl_gui_stock_label_radio_button (NULL, OSMO_STOCK_CONTACTS, 
+																					  GTK_ICON_SIZE_LARGE_TOOLBAR);
     } else {
-        appGUI->opt->contacts_options_radiobutton = gui_stock_label_radio_button(_("Contacts"), 
+        appGUI->opt->contacts_options_radiobutton = utl_gui_stock_label_radio_button (_("Contacts"), 
                                                                  OSMO_STOCK_CONTACTS, GTK_ICON_SIZE_LARGE_TOOLBAR);
         gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->contacts_options_radiobutton);
     }
@@ -262,12 +294,15 @@ GSList              *radiobutton_group = NULL;
     g_signal_connect (G_OBJECT (appGUI->opt->contacts_options_radiobutton), "released",
                       G_CALLBACK(options_button_released_cb), appGUI);
 
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+
+#ifdef NOTES_ENABLED
 
     if (appGUI->tiny_gui == TRUE) {
-        appGUI->opt->notes_options_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_NOTES, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        appGUI->opt->notes_options_radiobutton = utl_gui_stock_label_radio_button (NULL, OSMO_STOCK_NOTES, 
+																			       GTK_ICON_SIZE_LARGE_TOOLBAR);
     } else {
-        appGUI->opt->notes_options_radiobutton = gui_stock_label_radio_button(_("Notes"), 
+        appGUI->opt->notes_options_radiobutton = utl_gui_stock_label_radio_button (_("Notes"), 
                                                                  OSMO_STOCK_NOTES, GTK_ICON_SIZE_LARGE_TOOLBAR);
         gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->notes_options_radiobutton);
     }
@@ -281,12 +316,13 @@ GSList              *radiobutton_group = NULL;
     g_signal_connect (G_OBJECT (appGUI->opt->notes_options_radiobutton), "released",
                       G_CALLBACK(options_button_released_cb), appGUI);
 
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
 
     if (appGUI->tiny_gui == TRUE) {
-        appGUI->opt->general_options_radiobutton = gui_stock_label_radio_button(NULL, OSMO_STOCK_PREFERENCES, GTK_ICON_SIZE_LARGE_TOOLBAR);
+        appGUI->opt->general_options_radiobutton = utl_gui_stock_label_radio_button (NULL, OSMO_STOCK_PREFERENCES, 
+																					 GTK_ICON_SIZE_LARGE_TOOLBAR);
     } else {
-        appGUI->opt->general_options_radiobutton = gui_stock_label_radio_button(_("General"), 
+        appGUI->opt->general_options_radiobutton = utl_gui_stock_label_radio_button(_("General"), 
                                                                  OSMO_STOCK_PREFERENCES, GTK_ICON_SIZE_LARGE_TOOLBAR);
         gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->general_options_radiobutton);
     }
@@ -302,11 +338,15 @@ GSList              *radiobutton_group = NULL;
 
     if (appGUI->tiny_gui == TRUE) {
         gtk_box_pack_end (GTK_BOX (hbox), appGUI->opt->general_options_radiobutton, FALSE, TRUE, 0);
-#ifdef HAVE_LIBGRINGOTTS
+#ifdef NOTES_ENABLED
         gtk_box_pack_end (GTK_BOX (hbox), appGUI->opt->notes_options_radiobutton, FALSE, TRUE, 0);
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
+#ifdef CONTACTS_ENABLED
         gtk_box_pack_end (GTK_BOX (hbox), appGUI->opt->contacts_options_radiobutton, FALSE, TRUE, 0);
+#endif  /* CONTACTS_ENABLED */
+#ifdef TASKS_ENABLED
         gtk_box_pack_end (GTK_BOX (hbox), appGUI->opt->tasks_options_radiobutton, FALSE, TRUE, 0);
+#endif  /* TASKS_ENABLED */
         gtk_box_pack_end (GTK_BOX (hbox), appGUI->opt->calendar_options_radiobutton, FALSE, TRUE, 0);
     }
 
@@ -332,11 +372,15 @@ GSList              *radiobutton_group = NULL;
     gtk_container_add (GTK_CONTAINER (viewport), vbox2);
 
     gui_create_calendar_options_page (vbox2, appGUI);
+#ifdef TASKS_ENABLED
     gui_create_tasks_options_page (vbox2, appGUI);
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
     gui_create_contacts_options_page (vbox2, appGUI);
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     gui_create_notes_options_page (vbox2, appGUI);
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
     gui_create_general_options_page (vbox2, appGUI);
 
     appGUI->opt->callback_active = FALSE;
@@ -356,6 +400,15 @@ GSList              *radiobutton_group = NULL;
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->strikethrough_past_notes_checkbutton), config.strikethrough_past_notes);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ascending_sorting_in_day_notes_checkbutton), config.ascending_sorting_in_day_notes_browser);
 
+#ifdef HAVE_GTKSPELL
+    if (config.day_note_spell_checker == TRUE) {
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->spell_checker_in_day_notes_checkbutton), TRUE);
+
+        GtkSpell *edSpell = gtkspell_new_attach (GTK_TEXT_VIEW(appGUI->cal->calendar_note_textview), NULL, NULL);
+        gtkspell_set_language (edSpell, config.spell_lang, NULL);
+    }
+#endif  /* HAVE_GTKSPELL */
+
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_current_time_checkbutton), 
                                   config.di_show_current_time);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_day_number_checkbutton), 
@@ -397,10 +450,16 @@ GSList              *radiobutton_group = NULL;
                                   config.enable_systray);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->start_minimised_checkbutton), 
                                   config.start_minimised_in_systray);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->blink_on_events_checkbutton), 
+                                  config.blink_on_events);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ignore_day_note_events_checkbutton), 
+                                  config.ignore_day_note_events);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->remember_latest_tab_checkbutton), 
                                   config.remember_latest_tab);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->save_data_checkbutton), 
                                   config.save_data_after_modification);
+
+#ifdef TASKS_ENABLED
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->tasks_enable_rules_hint_checkbutton), 
                                   config.tasks_rules_hint);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ct_bold_items_checkbutton), 
@@ -414,67 +473,79 @@ GSList              *radiobutton_group = NULL;
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ct_remember_category_checkbutton), 
                                   config.remember_category_in_tasks);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_due_date_checkbutton), 
-                                  config.visible_due_date_column);
+                                  config.tsk_visible_due_date_column);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_type_checkbutton), 
-                                  config.visible_type_column);
+                                  config.tsk_visible_type_column);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_priority_checkbutton), 
-                                  config.visible_priority_column);
+                                  config.tsk_visible_priority_column);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_category_checkbutton), 
-                                  config.visible_category_column);
+                                  config.tsk_visible_category_column);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_tasks_checkbutton), 
+                                  config.hide_tasks);
+
+    gtk_entry_set_text(GTK_ENTRY(appGUI->opt->global_notification_cmd_entry), config.global_notification_command);
+    utl_gui_update_command_status (appGUI->opt->global_notification_cmd_entry, 
+								   appGUI->opt->global_notification_valid_image, appGUI);
+
+    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->ti_font_entry), config.task_info_font);
+#endif  /* CONTACTS_ENABLED */
+
+#ifdef CONTACTS_ENABLED
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_enable_rules_hint_checkbutton), 
                                   config.contacts_rules_hint);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_select_first_entry_checkbutton), 
                                   config.show_after_search);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_hide_group_column_checkbutton), 
                                   config.hide_group_column);
-
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->cn_remember_category_checkbutton), 
-                                  config.remember_category_in_notes);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->cn_use_system_date_checkbutton), 
-                                  config.use_system_date_in_notes);
-
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_age_checkbutton), 
-                                  config.visible_age_column);
+                                  config.cnt_visible_age_column);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_birthday_date_checkbutton), 
-                                  config.visible_birthday_date_column);
+                                  config.cnt_visible_birthday_date_column);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_zodiac_sign_checkbutton), 
-                                  config.visible_zodiac_sign_column);
- 
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_calendar_checkbutton), 
-                                  config.hide_calendar);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_tasks_checkbutton), 
-                                  config.hide_tasks);
+                                  config.cnt_visible_zodiac_sign_column);
+
+    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->cn_font_entry), config.contact_name_font);
+    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->ci_font_entry), config.contact_item_font);
+
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_contacts_checkbutton), 
                                   config.hide_contacts);
+    gtk_tree_view_column_set_visible (appGUI->cnt->contacts_columns[COLUMN_GROUP], !config.hide_group_column);
+#endif  /* CONTACTS_ENABLED */
 
-    gtk_entry_set_text(GTK_ENTRY(appGUI->opt->global_notification_cmd_entry), config.global_notification_command);
-    gui_update_command_status (appGUI->opt->global_notification_cmd_entry, 
-                               appGUI->opt->global_notification_valid_image, appGUI);
+#if defined(TASKS_ENABLED) || defined(CONTACTS_ENABLED) || defined(NOTES_ENABLED)
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_calendar_checkbutton), 
+                                  config.hide_calendar);
+#endif
 
-#ifdef HAVE_LIBGRINGOTTS
+#ifdef NOTES_ENABLED
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_notes_checkbutton), 
                                   config.hide_notes);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->notes_enable_rules_hint_checkbutton), 
                                   config.notes_rules_hint);
-#endif  /* HAVE_LIBGRINGOTTS */
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->cn_remember_category_checkbutton), 
+                                  config.remember_category_in_notes);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->cn_use_system_date_checkbutton), 
+                                  config.use_system_date_in_notes);
+    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->editor_font_entry), config.notes_editor_font);
 
-    gtk_tree_view_column_set_visible (appGUI->cnt->contacts_columns[COLUMN_GROUP], !config.hide_group_column);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->nvc_type_checkbutton), 
+                                  config.nte_visible_type_column);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->nvc_category_checkbutton), 
+                                  config.nte_visible_category_column);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->nvc_last_changes_checkbutton), 
+                                  config.nte_visible_last_changes_column);
+#endif  /* NOTES_ENABLED */
 
     gtk_entry_set_text (GTK_ENTRY(appGUI->opt->day_name_font_entry), config.day_name_font);
     gtk_entry_set_text (GTK_ENTRY(appGUI->opt->calendar_font_entry), config.calendar_font);
     gtk_entry_set_text (GTK_ENTRY(appGUI->opt->notes_font_entry), config.notes_font);
 
-    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->ti_font_entry), config.task_info_font);
-
-#ifdef HAVE_LIBGRINGOTTS
-    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->editor_font_entry), config.notes_editor_font);
-#endif  /* HAVE_LIBGRINGOTTS */
-
     gtk_entry_set_text (GTK_ENTRY(appGUI->opt->entry_web_browser), config.web_browser);
     gtk_entry_set_text (GTK_ENTRY(appGUI->opt->entry_email_client), config.email_client);
 
-    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->cn_font_entry), config.contact_name_font);
-    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->ci_font_entry), config.contact_item_font);
+#ifdef HAVE_GTKSPELL
+    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->entry_spell_lang), config.spell_lang);
+#endif  /* HAVE_GTKSPELL */
 
     appGUI->opt->callback_active = TRUE;
 
@@ -482,36 +553,44 @@ GSList              *radiobutton_group = NULL;
         gtk_widget_hide (appGUI->opt->calendar_vbox);
         gtk_widget_hide (appGUI->opt->calendar_options_radiobutton);
     }
+#ifdef TASKS_ENABLED
     if (config.hide_tasks) {
         gtk_widget_hide (appGUI->opt->tasks_vbox);
         gtk_widget_hide (appGUI->opt->tasks_options_radiobutton);
     }
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
     if (config.hide_contacts) {
         gtk_widget_hide (appGUI->opt->contacts_vbox);
         gtk_widget_hide (appGUI->opt->contacts_options_radiobutton);
     }
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     if (config.hide_notes) {
         gtk_widget_hide (appGUI->opt->notes_vbox);
         gtk_widget_hide (appGUI->opt->notes_options_radiobutton);
     }
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
 
     switch(options_get_first_active_page (appGUI)) {
         case OPT_PAGE_CALENDAR:
             gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->calendar_options_radiobutton), TRUE);
             break;
+#ifdef TASKS_ENABLED
         case OPT_PAGE_TASKS:
             gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->tasks_options_radiobutton), TRUE);
             break;
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
         case OPT_PAGE_CONTACTS:
             gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->contacts_options_radiobutton), TRUE);
             break;
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
         case OPT_PAGE_NOTES:
             gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->notes_options_radiobutton), TRUE);
             break;
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
     }
 
     gtk_widget_show (appGUI->opt->calendar_vbox);
