@@ -21,6 +21,7 @@
 
 #include "options_gui_contacts.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
@@ -33,6 +34,8 @@
 #include "contacts.h"
 #include "stock_icons.h"
 
+#ifdef CONTACTS_ENABLED
+
 /*------------------------------------------------------------------------------*/
 
 void
@@ -358,9 +361,9 @@ visible_bb_columns_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
     if (!appGUI->opt->callback_active) return;
 
-    config.visible_age_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_age_checkbutton));
-    config.visible_birthday_date_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_birthday_date_checkbutton));
-    config.visible_zodiac_sign_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_zodiac_sign_checkbutton));
+    config.cnt_visible_age_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_age_checkbutton));
+    config.cnt_visible_birthday_date_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_birthday_date_checkbutton));
+    config.cnt_visible_zodiac_sign_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_zodiac_sign_checkbutton));
 
 }
 
@@ -435,7 +438,9 @@ gint i;
     gtk_widget_show (appGUI->opt->contact_tag_color_picker);
     g_signal_connect (G_OBJECT (appGUI->opt->contact_tag_color_picker), "color-set",
                       G_CALLBACK(contact_tag_color_changed_cb), appGUI);
-    gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->opt->contact_tag_color_picker, _("Color of contact tags"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (appGUI->opt->contact_tag_color_picker, _("Color of contact tags"));
+	}
     gdk_color_parse(config.contact_tag_color, &color);
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->contact_tag_color_picker), &color);
     gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->contact_tag_color_picker, FALSE, FALSE, 0);
@@ -444,7 +449,9 @@ gint i;
     gtk_widget_show (appGUI->opt->contact_link_color_picker);
     g_signal_connect (G_OBJECT (appGUI->opt->contact_link_color_picker), "color-set",
                       G_CALLBACK(contact_link_color_changed_cb), appGUI);
-    gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->opt->contact_link_color_picker, _("Color of links"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (appGUI->opt->contact_link_color_picker, _("Color of links"));
+	}
     gdk_color_parse(config.contact_link_color, &color);
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->contact_link_color_picker), &color);
     gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->contact_link_color_picker, FALSE, FALSE, 0);
@@ -467,9 +474,9 @@ gint i;
                       (GtkAttachOptions) (0), 0, 0);
 
     if (config.default_stock_icons) {
-        cn_font_button = gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
+        cn_font_button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
     } else {
-        cn_font_button = gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
+        cn_font_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(cn_font_button, GTK_CAN_FOCUS);
     gtk_widget_show (cn_font_button);
@@ -497,9 +504,9 @@ gint i;
                       (GtkAttachOptions) (0), 0, 0);
 
     if (config.default_stock_icons) {
-        ci_font_button = gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
+        ci_font_button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
     } else {
-        ci_font_button = gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
+        ci_font_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(cn_font_button, GTK_CAN_FOCUS);
     gtk_widget_show (ci_font_button);
@@ -651,9 +658,9 @@ gint i;
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->opt->contacts_group_treeview), column);
 
     if (config.default_stock_icons) {
-        appGUI->opt->contacts_group_add_button = gui_stock_button(GTK_STOCK_ADD, FALSE);
+        appGUI->opt->contacts_group_add_button = utl_gui_stock_button (GTK_STOCK_ADD, FALSE);
     } else {
-        appGUI->opt->contacts_group_add_button = gui_stock_button(OSMO_STOCK_BUTTON_ADD, FALSE);
+        appGUI->opt->contacts_group_add_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_ADD, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->contacts_group_add_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->contacts_group_add_button);
@@ -665,9 +672,9 @@ gint i;
     gtk_widget_set_sensitive(appGUI->opt->contacts_group_add_button, FALSE);
 
     if (config.default_stock_icons) {
-        appGUI->opt->contacts_group_remove_button = gui_stock_button(GTK_STOCK_REMOVE, FALSE);
+        appGUI->opt->contacts_group_remove_button = utl_gui_stock_button(GTK_STOCK_REMOVE, FALSE);
     } else {
-        appGUI->opt->contacts_group_remove_button = gui_stock_button(OSMO_STOCK_BUTTON_REMOVE, FALSE);
+        appGUI->opt->contacts_group_remove_button = utl_gui_stock_button(OSMO_STOCK_BUTTON_REMOVE, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->contacts_group_remove_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->contacts_group_remove_button);
@@ -808,3 +815,5 @@ gint i;
 
 /*------------------------------------------------------------------------------*/
 
+#endif  /* CONTACTS_ENABLED */
+
