@@ -21,6 +21,7 @@
 
 #include "options_gui_general.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
@@ -60,7 +61,9 @@ disable_underline_in_links_changed_cb (GtkComboBox *widget, gpointer user_data)
     if (!appGUI->opt->callback_active) return;
 
     config.disable_underline_links = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->disable_underline_in_links_checkbutton));
+#ifdef CONTACTS_ENABLED
     g_signal_emit_by_name(G_OBJECT(appGUI->cnt->contacts_list_selection), "changed");
+#endif  /* CONTACTS_ENABLED */
     about_set_first_page(appGUI);
 
 }
@@ -76,16 +79,9 @@ enable_tooltips_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->enable_tooltips_checkbutton)) == TRUE) {
         config.enable_tooltips = 1;
-        gtk_tooltips_enable(appGUI->osmo_tooltips);
     } else {
         config.enable_tooltips = 0;
-        gtk_tooltips_disable(appGUI->osmo_tooltips);
     }
-
-    gtk_toolbar_set_tooltips (appGUI->cal->calendar_toolbar, config.enable_tooltips);
-    gtk_toolbar_set_tooltips (appGUI->tsk->tasks_toolbar, config.enable_tooltips);
-    gtk_toolbar_set_tooltips (appGUI->cnt->contacts_toolbar, config.enable_tooltips);
-
 }
 
 /*------------------------------------------------------------------------------*/
@@ -96,11 +92,15 @@ get_visible_tabs (GUI *appGUI) {
     gint i = 2;
 
     if (!config.hide_calendar) i++;
+#ifdef TASKS_ENABLED
     if (!config.hide_tasks) i++;
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
     if (!config.hide_contacts) i++;
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     if (!config.hide_notes) i++;
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
 
     return i;
 }
@@ -110,32 +110,57 @@ get_visible_tabs (GUI *appGUI) {
 void
 hide_module_cb (GtkComboBox *widget, gpointer user_data) {
 
-gboolean ga_calendar, ga_tasks, ga_contacts, result;
+gboolean ga_calendar, result;
 
-#ifdef HAVE_LIBGRINGOTTS
+#ifdef TASKS_ENABLED
+gboolean ga_tasks;
+#endif  /* TASKS_ENABLED */
+
+#ifdef CONTACTS_ENABLED
+gboolean ga_contacts;
+#endif  /* CONTACTS_ENABLED */
+
+#ifdef NOTES_ENABLED
 gboolean ga_notes;
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
 
     GUI *appGUI = (GUI *)user_data;
 
     if (!appGUI->opt->callback_active) return;
 
     ga_calendar = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_calendar_checkbutton));
+#ifdef TASKS_ENABLED
     ga_tasks = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_tasks_checkbutton));
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
     ga_contacts = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_contacts_checkbutton));
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     ga_notes = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_notes_checkbutton));
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
+
+#ifdef TASKS_ENABLED
+
+    result = (ga_calendar == TRUE) && (ga_tasks == TRUE);
+    #if defined(NOTES_ENABLED) && defined(CONTACTS_ENABLED)
+        result = (ga_calendar == TRUE) && (ga_tasks == TRUE) && (ga_contacts == TRUE) && (ga_notes == TRUE);
+    #elif CONTACTS_ENABLED
+        result = (ga_calendar == TRUE) && (ga_tasks == TRUE) && (ga_contacts == TRUE);
+    #endif  /* NOTES_ENABLED */
 
-#ifdef HAVE_LIBGRINGOTTS
-    result = (ga_calendar == TRUE) && (ga_tasks == TRUE) && (ga_contacts == TRUE) && (ga_notes == TRUE);
 #else
-    result = (ga_calendar == TRUE) && (ga_tasks == TRUE) && (ga_contacts == TRUE);
-#endif  /* HAVE_LIBGRINGOTTS */
+        result = (ga_calendar == TRUE);
+    #if defined(NOTES_ENABLED) && defined(CONTACTS_ENABLED)
+        result = (ga_calendar == TRUE) && (ga_contacts == TRUE) && (ga_notes == TRUE);
+    #elif CONTACTS_ENABLED
+        result = (ga_calendar == TRUE) && (ga_contacts == TRUE);
+    #endif  /* NOTES_ENABLED */
+
+#endif  /* TASKS_ENABLED */
 
     if (result == TRUE) { 
-        gui_create_dialog(GTK_MESSAGE_ERROR, _("At least one module must be visible."), 
-                          GTK_WINDOW(appGUI->main_window));
+        utl_gui_create_dialog (GTK_MESSAGE_ERROR, _("At least one module must be visible."), 
+							   GTK_WINDOW(appGUI->main_window));
         ga_calendar = FALSE;
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->hide_calendar_checkbutton), ga_calendar);
     }
@@ -145,50 +170,62 @@ gboolean ga_notes;
         gtk_widget_hide (GTK_WIDGET(appGUI->cal->vbox));
         gtk_widget_hide (appGUI->opt->calendar_vbox);
         gtk_widget_hide (appGUI->opt->calendar_options_radiobutton);
+        gtk_widget_hide (appGUI->trayicon_menu_calendar_item);
     } else {
         config.hide_calendar = FALSE;
         gtk_widget_show (GTK_WIDGET(appGUI->cal->vbox));
         gtk_widget_show (appGUI->opt->calendar_vbox);
         gtk_widget_show (appGUI->opt->calendar_options_radiobutton);
+        gtk_widget_show (appGUI->trayicon_menu_calendar_item);
     }
 
+#ifdef TASKS_ENABLED
     if (ga_tasks == TRUE) {
         config.hide_tasks = TRUE;
         gtk_widget_hide(GTK_WIDGET(appGUI->tsk->vbox));
         gtk_widget_hide (appGUI->opt->tasks_vbox);
         gtk_widget_hide (appGUI->opt->tasks_options_radiobutton);
+        gtk_widget_hide (appGUI->trayicon_menu_tasks_item);
     } else {
         config.hide_tasks = FALSE;
         gtk_widget_show (GTK_WIDGET(appGUI->tsk->vbox));
         gtk_widget_show (appGUI->opt->tasks_vbox);
         gtk_widget_show (appGUI->opt->tasks_options_radiobutton);
+        gtk_widget_show (appGUI->trayicon_menu_tasks_item);
     }
+#endif  /* TASKS_ENABLED */
 
+#ifdef CONTACTS_ENABLED
     if (ga_contacts == TRUE) {
         config.hide_contacts = TRUE;
         gtk_widget_hide (GTK_WIDGET(appGUI->cnt->vbox));
         gtk_widget_hide (appGUI->opt->contacts_vbox);
         gtk_widget_hide (appGUI->opt->contacts_options_radiobutton);
+        gtk_widget_hide (appGUI->trayicon_menu_contacts_item);
     } else {
         config.hide_contacts = FALSE;
         gtk_widget_show (GTK_WIDGET(appGUI->cnt->vbox));
         gtk_widget_show (appGUI->opt->contacts_vbox);
         gtk_widget_show (appGUI->opt->contacts_options_radiobutton);
+        gtk_widget_show (appGUI->trayicon_menu_contacts_item);
     }
+#endif  /* CONTACTS_ENABLED */
 
-#ifdef HAVE_LIBGRINGOTTS
+#ifdef NOTES_ENABLED
     if (ga_notes == TRUE) {
         config.hide_notes = TRUE;
         gtk_widget_hide (GTK_WIDGET(appGUI->nte->vbox));
         gtk_widget_hide (appGUI->opt->notes_vbox);
         gtk_widget_hide (appGUI->opt->notes_options_radiobutton);
+        gtk_widget_hide (appGUI->trayicon_menu_notes_item);
     } else {
         config.hide_notes = FALSE;
         gtk_widget_show (GTK_WIDGET(appGUI->nte->vbox));
         gtk_widget_show (appGUI->opt->notes_vbox);
         gtk_widget_show (appGUI->opt->notes_options_radiobutton);
+        gtk_widget_show (appGUI->trayicon_menu_notes_item);
     }
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
 
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->general_options_radiobutton), TRUE);
     g_signal_emit_by_name(G_OBJECT(appGUI->opt->general_options_radiobutton), "released");
@@ -206,14 +243,15 @@ enable_systray_changed_cb (GtkComboBox *widget, gpointer user_data) {
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->enable_systray_checkbutton)) == TRUE) {
         config.enable_systray = 1;
         gtk_widget_set_sensitive(appGUI->opt->start_minimised_checkbutton, TRUE);
+        gtk_widget_set_sensitive(appGUI->opt->blink_on_events_checkbutton, TRUE);
+        gtk_widget_set_sensitive(appGUI->opt->ignore_day_note_events_checkbutton, TRUE);
         gtk_status_icon_set_visible(appGUI->osmo_trayicon, TRUE);
-        if (gtk_status_icon_is_embedded(appGUI->osmo_trayicon) == FALSE) {
-            appGUI->no_tray = TRUE;
-        }
     } else {
         config.enable_systray = 0;
         gtk_status_icon_set_visible(appGUI->osmo_trayicon, FALSE);
         gtk_widget_set_sensitive(appGUI->opt->start_minimised_checkbutton, FALSE);
+        gtk_widget_set_sensitive(appGUI->opt->blink_on_events_checkbutton, FALSE);
+        gtk_widget_set_sensitive(appGUI->opt->ignore_day_note_events_checkbutton, FALSE);
     }
 }
 
@@ -236,6 +274,40 @@ start_minimised_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+blink_on_events_changed_cb (GtkComboBox *widget, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->blink_on_events_checkbutton)) == TRUE) {
+        config.blink_on_events = 1;
+    } else {
+        config.blink_on_events = 0;
+    }
+
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+ignore_day_note_events_changed_cb (GtkComboBox *widget, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->opt->ignore_day_note_events_checkbutton)) == TRUE) {
+        config.ignore_day_note_events = 1;
+    } else {
+        config.ignore_day_note_events = 0;
+    }
+
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 remember_latest_tab_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
@@ -276,19 +348,48 @@ helpers_entry_changed_cb (GtkEntry *entry, gpointer  user_data) {
         strncpy(config.email_client, gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_email_client)), MAXHELPERCMD-1);
     }
     
-    gui_change_bg_widget_state (appGUI->opt->entry_web_browser, NULL, appGUI);
-    gui_change_bg_widget_state (appGUI->opt->entry_email_client, NULL, appGUI);
+    utl_gui_change_bg_widget_state (appGUI->opt->entry_web_browser, NULL, appGUI);
+    utl_gui_change_bg_widget_state (appGUI->opt->entry_email_client, NULL, appGUI);
 
 }
 
 /*------------------------------------------------------------------------------*/
 
+#ifdef HAVE_GTKSPELL
+void
+spell_checker_entry_changed_cb (GtkEntry *entry, gpointer  user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+
+    if (strlen(gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_spell_lang)))) {
+        strncpy(config.spell_lang, gtk_entry_get_text(GTK_ENTRY(appGUI->opt->entry_spell_lang)), MAXNAME-1);
+    }
+    
+    utl_gui_change_bg_widget_state (appGUI->opt->entry_spell_lang, NULL, appGUI);
+
+}
+
+
+gint 
+spell_checker_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
+
+    GUI *appGUI = (GUI *)data;
+
+    utl_gui_change_bg_widget_state (appGUI->opt->entry_spell_lang, COLOR_BG_OK, appGUI);
+    return FALSE;
+}
+#endif  /* HAVE_GTKSPELL */
+
+/*------------------------------------------------------------------------------*/
+
 gint 
 helper_www_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
 
-    gui_change_bg_widget_state (appGUI->opt->entry_web_browser, COLOR_BG_OK, appGUI);
+    utl_gui_change_bg_widget_state (appGUI->opt->entry_web_browser, COLOR_BG_OK, appGUI);
     return FALSE;
 }
 
@@ -299,7 +400,7 @@ helper_email_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 
     GUI *appGUI = (GUI *)data;
 
-    gui_change_bg_widget_state (appGUI->opt->entry_email_client, COLOR_BG_OK, appGUI);
+    utl_gui_change_bg_widget_state (appGUI->opt->entry_email_client, COLOR_BG_OK, appGUI);
     return FALSE;
 }
 
@@ -329,14 +430,18 @@ gint angle;
 
     label = gtk_notebook_get_tab_label (GTK_NOTEBOOK(appGUI->notebook), GTK_WIDGET(appGUI->cal->vbox));
     gtk_label_set_angle (GTK_LABEL(label), angle);
+#ifdef TASKS_ENABLED
     label = gtk_notebook_get_tab_label (GTK_NOTEBOOK(appGUI->notebook), GTK_WIDGET(appGUI->tsk->vbox));
     gtk_label_set_angle (GTK_LABEL(label), angle);
+#endif  /* TASKS_ENABLED */
+#ifdef CONTACTS_ENABLED
     label = gtk_notebook_get_tab_label (GTK_NOTEBOOK(appGUI->notebook), GTK_WIDGET(appGUI->cnt->vbox));
     gtk_label_set_angle (GTK_LABEL(label), angle);
-#ifdef HAVE_LIBGRINGOTTS
+#endif  /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
     label = gtk_notebook_get_tab_label (GTK_NOTEBOOK(appGUI->notebook), GTK_WIDGET(appGUI->nte->vbox));
     gtk_label_set_angle (GTK_LABEL(label), angle);
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
     label = gtk_notebook_get_tab_label (GTK_NOTEBOOK(appGUI->notebook), GTK_WIDGET(appGUI->opt->vbox));
     gtk_label_set_angle (GTK_LABEL(label), angle);
     label = gtk_notebook_get_tab_label (GTK_NOTEBOOK(appGUI->notebook), GTK_WIDGET(appGUI->about_vbox));
@@ -354,7 +459,10 @@ date_format_changed_cb (GtkComboBox *widget, gpointer user_data) {
     if (!appGUI->opt->callback_active) return;
 
     config.date_format = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->date_format_combobox));
+
+#ifdef TASKS_ENABLED
     refresh_tasks (appGUI);
+#endif  /* TASKS_ENABLED */
 
 }
 
@@ -368,7 +476,10 @@ time_format_changed_cb (GtkComboBox *widget, gpointer user_data) {
     if (!appGUI->opt->callback_active) return;
 
     config.time_format = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->time_format_combobox));
+
+#ifdef TASKS_ENABLED
     refresh_tasks (appGUI);
+#endif  /* TASKS_ENABLED */
 
 }
 
@@ -377,14 +488,19 @@ time_format_changed_cb (GtkComboBox *widget, gpointer user_data) {
 void
 gui_create_general_options_page (GtkWidget *vbox, GUI *appGUI) {
 
-GtkWidget   *general_vbox, *hide_vbox, *appearance_vbox;
+GtkWidget   *general_vbox, *appearance_vbox;
 GtkWidget   *helpers_vbox, *system_tray_vbox;
 GtkWidget   *label;
 GtkWidget   *frame;
 GtkWidget   *table;
 GtkWidget   *alignment;
 
-gchar       tmpbuf[BUFFER_SIZE];
+#if defined(TASKS_ENABLED) || defined(CONTACTS_ENABLED) || defined(NOTES_ENABLED)
+GtkWidget   *hide_vbox;
+#endif
+
+gint i = 0;
+gchar tmpbuf[BUFFER_SIZE];
 
 
     appGUI->opt->general_vbox = gtk_vbox_new (FALSE, 0);
@@ -452,6 +568,8 @@ gchar       tmpbuf[BUFFER_SIZE];
                       G_CALLBACK (disable_underline_in_links_changed_cb), appGUI);
     gtk_box_pack_start (GTK_BOX (appearance_vbox), appGUI->opt->disable_underline_in_links_checkbutton, FALSE, FALSE, 4);
 
+#if defined(TASKS_ENABLED) || defined(CONTACTS_ENABLED) || defined(NOTES_ENABLED)
+
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (appGUI->opt->general_vbox), frame, FALSE, TRUE, 0);
@@ -472,11 +590,10 @@ gchar       tmpbuf[BUFFER_SIZE];
     gtk_widget_show (hide_vbox);
     gtk_container_add (GTK_CONTAINER (alignment), hide_vbox);
 
-    table = gtk_table_new (2, 2, FALSE);
+    table = gtk_table_new (1, 4, FALSE);
     gtk_widget_show (table);
     gtk_box_pack_start (GTK_BOX (hide_vbox), table, TRUE, TRUE, 0);
     gtk_table_set_col_spacings (GTK_TABLE (table), 16);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 8);
 
     appGUI->opt->hide_calendar_checkbutton = gtk_check_button_new_with_mnemonic (_("Calendar"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->hide_calendar_checkbutton, GTK_CAN_FOCUS);
@@ -487,6 +604,7 @@ gchar       tmpbuf[BUFFER_SIZE];
                     (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
+#ifdef TASKS_ENABLED
     appGUI->opt->hide_tasks_checkbutton = gtk_check_button_new_with_mnemonic (_("Tasks"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->hide_tasks_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->hide_tasks_checkbutton);
@@ -495,26 +613,31 @@ gchar       tmpbuf[BUFFER_SIZE];
     gtk_table_attach (GTK_TABLE (table), appGUI->opt->hide_tasks_checkbutton, 1, 2, 0, 1,
                     (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
+#endif  /* TASKS_ENABLED */
 
+#ifdef CONTACTS_ENABLED
     appGUI->opt->hide_contacts_checkbutton = gtk_check_button_new_with_mnemonic (_("Contacts"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->hide_contacts_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->hide_contacts_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->hide_contacts_checkbutton), "toggled",
                       G_CALLBACK (hide_module_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->hide_contacts_checkbutton, 0, 1, 1, 2,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->hide_contacts_checkbutton, 2, 3, 0, 1,
                     (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
+#endif  /* CONTACTS_ENABLED */
 
-#ifdef HAVE_LIBGRINGOTTS
+#ifdef NOTES_ENABLED
     appGUI->opt->hide_notes_checkbutton = gtk_check_button_new_with_mnemonic (_("Notes"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->hide_notes_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->hide_notes_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->hide_notes_checkbutton), "toggled",
                       G_CALLBACK (hide_module_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->hide_notes_checkbutton, 1, 2, 1, 2,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->hide_notes_checkbutton, 3, 4, 0, 1,
                     (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
+
+#endif
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
@@ -536,7 +659,7 @@ gchar       tmpbuf[BUFFER_SIZE];
     gtk_widget_show (general_vbox);
     gtk_container_add (GTK_CONTAINER (alignment), general_vbox);
 
-    table = gtk_table_new (4, 4, FALSE);
+    table = gtk_table_new (6, 4, FALSE);
     gtk_widget_show (table);
     gtk_box_pack_start (GTK_BOX (general_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_col_spacings (GTK_TABLE (table), 16);
@@ -546,7 +669,7 @@ gchar       tmpbuf[BUFFER_SIZE];
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                    (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
@@ -555,7 +678,7 @@ gchar       tmpbuf[BUFFER_SIZE];
     g_signal_connect (G_OBJECT (appGUI->opt->date_format_combobox), "changed",
                       G_CALLBACK(date_format_changed_cb), appGUI);
     gtk_table_attach (GTK_TABLE (table), appGUI->opt->date_format_combobox, 1, 2, 0, 1,
-                    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                    (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->date_format_combobox), _("DD-MM-YYYY"));
@@ -567,8 +690,8 @@ gchar       tmpbuf[BUFFER_SIZE];
     sprintf(tmpbuf, "%s:", _("Time format"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1,
-                    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
+                    (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
@@ -576,8 +699,8 @@ gchar       tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appGUI->opt->time_format_combobox);
     g_signal_connect (G_OBJECT (appGUI->opt->time_format_combobox), "changed",
                       G_CALLBACK(time_format_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->time_format_combobox, 3, 4, 0, 1,
-                    (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->time_format_combobox, 1, 2, 1, 2,
+                    (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
     sprintf(tmpbuf, "24 %s", _("hours"));
@@ -586,13 +709,37 @@ gchar       tmpbuf[BUFFER_SIZE];
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->time_format_combobox), tmpbuf);
     gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->time_format_combobox), config.time_format);
 
+#ifdef HAVE_GTKSPELL
+
+    sprintf (tmpbuf, "%s:", _("Spell checker language"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
+    appGUI->opt->entry_spell_lang = gtk_entry_new ();
+    gtk_widget_show (appGUI->opt->entry_spell_lang);
+    g_signal_connect (G_OBJECT (appGUI->opt->entry_spell_lang), "activate",
+                      G_CALLBACK (spell_checker_entry_changed_cb), appGUI);
+    g_signal_connect (G_OBJECT (appGUI->opt->entry_spell_lang), "key_press_event",
+                      G_CALLBACK (spell_checker_key_press_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->entry_spell_lang, 1, 2, 2, 3,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_entry_set_max_length (GTK_ENTRY (appGUI->opt->entry_spell_lang), MAXNAME);
+
+    i++;
+
+#endif  /* HAVE_GTKSPELL */
 
     appGUI->opt->enable_tooltips_checkbutton = gtk_check_button_new_with_mnemonic (_("Enable tooltips"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->enable_tooltips_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->enable_tooltips_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->enable_tooltips_checkbutton), "toggled",
                       G_CALLBACK (enable_tooltips_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->enable_tooltips_checkbutton, 0, 4, 1, 2,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->enable_tooltips_checkbutton, 0, 4, i+2, i+3,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
@@ -601,7 +748,7 @@ gchar       tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appGUI->opt->remember_latest_tab_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->remember_latest_tab_checkbutton), "toggled",
                       G_CALLBACK (remember_latest_tab_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->remember_latest_tab_checkbutton, 0, 4, 2, 3,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->remember_latest_tab_checkbutton, 0, 4, i+3, i+4,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
@@ -610,7 +757,7 @@ gchar       tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appGUI->opt->save_data_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->save_data_checkbutton), "toggled",
                       G_CALLBACK (save_data_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->save_data_checkbutton, 0, 4, 3, 4,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->save_data_checkbutton, 0, 4, i+4, i+5,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
@@ -731,8 +878,27 @@ gchar       tmpbuf[BUFFER_SIZE];
     gtk_table_attach (GTK_TABLE (table), appGUI->opt->start_minimised_checkbutton, 1, 2, 0, 1,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
-    gtk_widget_set_sensitive(appGUI->opt->start_minimised_checkbutton, config.enable_systray);
+    gtk_widget_set_sensitive (appGUI->opt->start_minimised_checkbutton, config.enable_systray);
 
+	appGUI->opt->blink_on_events_checkbutton = gtk_check_button_new_with_mnemonic (_("Blink on events"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->blink_on_events_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->blink_on_events_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->blink_on_events_checkbutton), "toggled",
+                      G_CALLBACK (blink_on_events_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->blink_on_events_checkbutton, 2, 3, 0, 1,
+                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                    (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_widget_set_sensitive (appGUI->opt->blink_on_events_checkbutton, config.enable_systray);
+
+	appGUI->opt->ignore_day_note_events_checkbutton = gtk_check_button_new_with_mnemonic (_("Ignore day note events"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ignore_day_note_events_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->ignore_day_note_events_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->ignore_day_note_events_checkbutton), "toggled",
+                      G_CALLBACK (ignore_day_note_events_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->ignore_day_note_events_checkbutton, 0, 3, 1, 2,
+                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                    (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_widget_set_sensitive (appGUI->opt->ignore_day_note_events_checkbutton, config.enable_systray);
 }
 
 /*------------------------------------------------------------------------------*/
