@@ -32,13 +32,17 @@
 #include "options_prefs.h"
 #include "contacts.h"
 #include "stock_icons.h"
+#include "utils_gui.h"
+
+#ifdef NOTES_ENABLED
 
 #ifdef HAVE_LIBGRINGOTTS
-
 #include <libgringotts.h>
+#endif  /* HAVE_LIBGRINGOTTS */
 
 /*------------------------------------------------------------------------------*/
 
+#ifdef HAVE_LIBGRINGOTTS
 gint
 get_enc_algorithm_value (void) {
 
@@ -79,40 +83,7 @@ gint ratio_table [4] = {
 
     return ratio_table[config.notes_comp_ratio % 4];
 }
-
-/*------------------------------------------------------------------------------*/
-
-void
-editor_font_select_cb (GtkWidget *widget, gpointer data) {
-
-GtkWidget *font_selector;
-gchar *font_name;
-gint response;
-
-    GUI *appGUI = (GUI *)data;
-
-    font_selector = gtk_font_selection_dialog_new (_("Select a font..."));
-    gtk_window_set_modal(GTK_WINDOW(font_selector), TRUE);
-    gtk_window_set_position(GTK_WINDOW(font_selector), GTK_WIN_POS_MOUSE);
-    gtk_window_set_transient_for(GTK_WINDOW(font_selector), GTK_WINDOW(appGUI->main_window));
-    gtk_font_selection_dialog_set_font_name (GTK_FONT_SELECTION_DIALOG(font_selector), config.notes_editor_font);
-    gtk_widget_show (font_selector);
-    response = gtk_dialog_run (GTK_DIALOG (font_selector));
-
-    if (response == GTK_RESPONSE_OK) {
-
-        font_name = gtk_font_selection_dialog_get_font_name (GTK_FONT_SELECTION_DIALOG(font_selector));
-        strncpy(config.notes_editor_font, font_name, MAXFONTNAME-1);
-        gtk_entry_set_text(GTK_ENTRY(appGUI->opt->editor_font_entry), font_name);
-        g_free (font_name);
-
-        pango_font_description_free(appGUI->nte->fd_notes_font);
-        appGUI->nte->fd_notes_font = pango_font_description_from_string(config.notes_editor_font);
-        gtk_widget_modify_font (GTK_WIDGET(appGUI->nte->editor_textview), appGUI->nte->fd_notes_font);
-    }
-
-    gtk_widget_destroy (font_selector);
-}
+#endif  /* HAVE_LIBGRINGOTTS */
 
 /*------------------------------------------------------------------------------*/
 
@@ -129,6 +100,7 @@ notes_enable_rules_hint_checkbutton_cb (GtkComboBox *widget, gpointer user_data)
 
 /*------------------------------------------------------------------------------*/
 
+#ifdef HAVE_LIBGRINGOTTS
 void
 notes_enc_algorithm_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
@@ -174,6 +146,7 @@ notes_comp_ratio_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
     config.notes_comp_ratio = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->notes_comp_ratio_combobox));
 }
+#endif  /* HAVE_LIBGRINGOTTS */
 
 /*------------------------------------------------------------------------------*/
 
@@ -226,7 +199,9 @@ gchar *item;
         gtk_entry_set_text(GTK_ENTRY(appGUI->opt->notes_category_entry), "");
         gtk_widget_set_sensitive(appGUI->opt->notes_category_add_button, FALSE);
 
-        gui_create_category_combobox (GTK_COMBO_BOX (appGUI->nte->cf_combobox), appGUI->opt->notes_category_store, FALSE);
+        utl_gui_create_category_combobox (GTK_COMBO_BOX (appGUI->nte->cf_combobox), 
+										  appGUI->opt->notes_category_store, FALSE);
+
         gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->nte->cf_combobox), 0);
 
     }
@@ -249,7 +224,9 @@ GtkTreePath *path;
         gtk_list_store_remove(appGUI->opt->notes_category_store, &iter);
         gtk_tree_path_free(path);
 
-        gui_create_category_combobox (GTK_COMBO_BOX (appGUI->nte->cf_combobox), appGUI->opt->notes_category_store, FALSE);
+        utl_gui_create_category_combobox (GTK_COMBO_BOX (appGUI->nte->cf_combobox), 
+										  appGUI->opt->notes_category_store, FALSE);
+
         gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->nte->cf_combobox), 0);
     }
 }
@@ -352,11 +329,32 @@ use_system_date_cb (GtkToggleButton *togglebutton, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+notes_visible_columns_changed_cb (GtkComboBox *widget, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+
+    config.nte_visible_type_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->nvc_type_checkbutton));
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_TYPE], config.nte_visible_type_column);
+    config.nte_visible_category_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->nvc_category_checkbutton));
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_CATEGORY], config.nte_visible_category_column);
+    config.nte_visible_last_changes_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->nvc_last_changes_checkbutton));
+    gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_LAST_CHANGES_DATE], config.nte_visible_last_changes_column);
+
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 gui_create_notes_options_page (GtkWidget *vbox, GUI *appGUI) {
 
-GtkWidget           *sorting_vbox, *appearance_vbox, *encryption_vbox;
-GtkWidget           *categories_vbox, *notes_opt_vbox;
+GtkWidget           *sorting_vbox, *appearance_vbox;
+#ifdef HAVE_LIBGRINGOTTS
+GtkWidget           *encryption_vbox;
+#endif /* HAVE_LIBGRINGOTTS */
+GtkWidget           *categories_vbox, *notes_opt_vbox, *visible_columns_vbox;
 GtkWidget           *frame;
 GtkWidget           *alignment;
 GtkWidget           *table;
@@ -369,6 +367,7 @@ GtkTreeViewColumn   *column;
 
 gchar tmpbuf[BUFFER_SIZE];
 
+	static FONT_SEL sel;
 
     appGUI->opt->notes_vbox = gtk_vbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), appGUI->opt->notes_vbox, FALSE, FALSE, 0);
@@ -414,15 +413,22 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
+	sel.appGUI = appGUI;
+	sel.config = config.notes_editor_font;
+	sel.entry = appGUI->opt->editor_font_entry;
+	sel.widget = appGUI->nte->editor_textview;
+	sel.font = &appGUI->nte->fd_notes_font;
+	sel.save = TRUE;
+
     if (config.default_stock_icons) {
-        editor_font_button = gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
+        editor_font_button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
     } else {
-        editor_font_button = gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
+        editor_font_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(editor_font_button, GTK_CAN_FOCUS);
     gtk_widget_show (editor_font_button);
     g_signal_connect (G_OBJECT (editor_font_button), "clicked",
-                      G_CALLBACK (editor_font_select_cb), appGUI);
+                      G_CALLBACK (utl_gui_font_select_cb), &sel);
     gtk_table_attach (GTK_TABLE (table), editor_font_button, 2, 3, 0, 1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
@@ -436,6 +442,7 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
+#ifdef HAVE_LIBGRINGOTTS
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (appGUI->opt->notes_vbox), frame, FALSE, TRUE, 0);
@@ -545,6 +552,60 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_comp_ratio_combobox), _("Good"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_comp_ratio_combobox), _("Best"));
     gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->notes_comp_ratio_combobox), config.notes_comp_ratio);
+#endif /* HAVE_LIBGRINGOTTS */
+
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (appGUI->opt->notes_vbox), frame, FALSE, TRUE, 0);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+    sprintf(tmpbuf, "<b>%s</b>", _("Visible columns"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+    gtk_misc_set_padding (GTK_MISC (label), 0, 4);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+    gtk_widget_show (alignment);
+    gtk_container_add (GTK_CONTAINER (frame), alignment);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
+
+    visible_columns_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (visible_columns_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), visible_columns_vbox);
+
+    table = gtk_table_new (1, 3, FALSE);
+    gtk_widget_show (table);
+    gtk_box_pack_start (GTK_BOX (visible_columns_vbox), table, FALSE, FALSE, 0);
+    gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+    gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+
+    appGUI->opt->nvc_type_checkbutton = gtk_check_button_new_with_mnemonic (_("Type"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->nvc_type_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->nvc_type_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->nvc_type_checkbutton), "toggled",
+                      G_CALLBACK (notes_visible_columns_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->nvc_type_checkbutton, 0, 1, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
+
+    appGUI->opt->nvc_category_checkbutton = gtk_check_button_new_with_mnemonic (_("Category"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->nvc_category_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->nvc_category_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->nvc_category_checkbutton), "toggled",
+                      G_CALLBACK (notes_visible_columns_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->nvc_category_checkbutton, 1, 2, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
+
+    appGUI->opt->nvc_last_changes_checkbutton = gtk_check_button_new_with_mnemonic (_("Last changes"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->nvc_last_changes_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->nvc_last_changes_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->nvc_last_changes_checkbutton), "toggled",
+                      G_CALLBACK (notes_visible_columns_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->nvc_last_changes_checkbutton, 2, 3, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
@@ -611,9 +672,9 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->opt->notes_category_treeview), column);
 
     if (config.default_stock_icons) {
-        appGUI->opt->notes_category_add_button = gui_stock_button(GTK_STOCK_ADD, FALSE);
+        appGUI->opt->notes_category_add_button = utl_gui_stock_button (GTK_STOCK_ADD, FALSE);
     } else {
-        appGUI->opt->notes_category_add_button = gui_stock_button(OSMO_STOCK_BUTTON_ADD, FALSE);
+        appGUI->opt->notes_category_add_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_ADD, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->notes_category_add_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->notes_category_add_button);
@@ -625,9 +686,9 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_set_sensitive(appGUI->opt->notes_category_add_button, FALSE);
 
     if (config.default_stock_icons) {
-        appGUI->opt->notes_category_remove_button = gui_stock_button(GTK_STOCK_REMOVE, FALSE);
+        appGUI->opt->notes_category_remove_button = utl_gui_stock_button (GTK_STOCK_REMOVE, FALSE);
     } else {
-        appGUI->opt->notes_category_remove_button = gui_stock_button(OSMO_STOCK_BUTTON_REMOVE, FALSE);
+        appGUI->opt->notes_category_remove_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_REMOVE, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->notes_category_remove_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->notes_category_remove_button);
@@ -749,5 +810,5 @@ gchar tmpbuf[BUFFER_SIZE];
 
 /*------------------------------------------------------------------------------*/
 
-#endif  /* HAVE_LIBGRINGOTTS */
+#endif  /* NOTES_ENABLED */
 
