@@ -20,6 +20,7 @@
  */
 
 #include "utils.h"
+#include "utils_gui.h"
 #include "calendar.h"
 #include "i18n.h"
 #include "tasks.h"
@@ -28,6 +29,8 @@
 #include "options_prefs.h"
 #include "stock_icons.h"
 
+#ifdef TASKS_ENABLED
+
 /*------------------------------------------------------------------------------*/
 
 void
@@ -178,7 +181,9 @@ gchar *item;
         gtk_entry_set_text(GTK_ENTRY(appGUI->opt->tasks_category_entry), "");
         gtk_widget_set_sensitive(appGUI->opt->tasks_category_add_button, FALSE);
 
-        gui_create_category_combobox (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), appGUI->opt->tasks_category_store, FALSE);
+        utl_gui_create_category_combobox (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), 
+										  appGUI->opt->tasks_category_store, FALSE);
+
         gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), 0);
 
         apply_task_attributes (appGUI);
@@ -308,14 +313,14 @@ visible_columns_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
     if (!appGUI->opt->callback_active) return;
 
-    config.visible_due_date_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_due_date_checkbutton));
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE], config.visible_due_date_column);
-    config.visible_type_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_type_checkbutton));
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_TYPE], config.visible_type_column);
-    config.visible_category_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_category_checkbutton));
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY], config.visible_category_column);
-    config.visible_priority_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_priority_checkbutton));
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY], config.visible_priority_column);
+    config.tsk_visible_due_date_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_due_date_checkbutton));
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE], config.tsk_visible_due_date_column);
+    config.tsk_visible_type_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_type_checkbutton));
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_TYPE], config.tsk_visible_type_column);
+    config.tsk_visible_category_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_category_checkbutton));
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY], config.tsk_visible_category_column);
+    config.tsk_visible_priority_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_priority_checkbutton));
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY], config.tsk_visible_priority_column);
 
 }
 
@@ -479,8 +484,8 @@ gint
 global_notification_entry_key_release_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
 	GUI *appGUI = (GUI *) user_data;
-    gui_update_command_status (appGUI->opt->global_notification_cmd_entry, 
-                               appGUI->opt->global_notification_valid_image, appGUI);
+    utl_gui_update_command_status (appGUI->opt->global_notification_cmd_entry, 
+								   appGUI->opt->global_notification_valid_image, appGUI);
     
 	g_strlcpy (config.global_notification_command, 
                gtk_entry_get_text(GTK_ENTRY(appGUI->opt->global_notification_cmd_entry)), MAXHELPERCMD);
@@ -551,7 +556,9 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appGUI->opt->due_today_color_picker);
     g_signal_connect (G_OBJECT (appGUI->opt->due_today_color_picker), "color-set",
                       G_CALLBACK(due_today_color_changed_cb), appGUI);
-    gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->opt->due_today_color_picker, _("Color of items that are due today"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (appGUI->opt->due_today_color_picker, _("Color of items that are due today"));
+	}
     gdk_color_parse(config.due_today_color, &color);
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->due_today_color_picker), &color);
     gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->due_today_color_picker, FALSE, FALSE, 0);
@@ -560,7 +567,9 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appGUI->opt->due_7days_color_picker);
     g_signal_connect (G_OBJECT (appGUI->opt->due_7days_color_picker), "color-set",
                       G_CALLBACK(due_7days_color_changed_cb), appGUI);
-    gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->opt->due_7days_color_picker, _("Color of items that are due in the next 7 days"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (appGUI->opt->due_7days_color_picker, _("Color of items that are due in the next 7 days"));
+	}
     gdk_color_parse(config.due_7days_color, &color);
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->due_7days_color_picker), &color);
     gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->due_7days_color_picker, FALSE, FALSE, 0);
@@ -569,7 +578,9 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appGUI->opt->past_due_color_picker);
     g_signal_connect (G_OBJECT (appGUI->opt->past_due_color_picker), "color-set",
                       G_CALLBACK(past_due_color_changed_cb), appGUI);
-    gtk_tooltips_set_tip (appGUI->osmo_tooltips, appGUI->opt->past_due_color_picker, _("Color of items that are past due"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (appGUI->opt->past_due_color_picker, _("Color of items that are past due"));
+	}
     gdk_color_parse(config.past_due_color, &color);
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->past_due_color_picker), &color);
     gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->past_due_color_picker, FALSE, FALSE, 0);
@@ -582,9 +593,9 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
 
     if (config.default_stock_icons) {
-        ti_font_button = gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
+        ti_font_button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
     } else {
-        ti_font_button = gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
+        ti_font_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(ti_font_button, GTK_CAN_FOCUS);
     gtk_widget_show (ti_font_button);
@@ -769,9 +780,9 @@ gchar tmpbuf[BUFFER_SIZE];
     g_signal_connect (renderer, "toggled", G_CALLBACK (tsk_show_in_tasks_list_toggled), appGUI);
 
     if (config.default_stock_icons) {
-        appGUI->opt->tasks_category_add_button = gui_stock_button(GTK_STOCK_ADD, FALSE);
+        appGUI->opt->tasks_category_add_button = utl_gui_stock_button (GTK_STOCK_ADD, FALSE);
     } else {
-        appGUI->opt->tasks_category_add_button = gui_stock_button(OSMO_STOCK_BUTTON_ADD, FALSE);
+        appGUI->opt->tasks_category_add_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_ADD, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->tasks_category_add_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->tasks_category_add_button);
@@ -783,9 +794,9 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_set_sensitive(appGUI->opt->tasks_category_add_button, FALSE);
 
     if (config.default_stock_icons) {
-        appGUI->opt->tasks_category_remove_button = gui_stock_button(GTK_STOCK_REMOVE, FALSE);
+        appGUI->opt->tasks_category_remove_button = utl_gui_stock_button (GTK_STOCK_REMOVE, FALSE);
     } else {
-        appGUI->opt->tasks_category_remove_button = gui_stock_button(OSMO_STOCK_BUTTON_REMOVE, FALSE);
+        appGUI->opt->tasks_category_remove_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_REMOVE, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->tasks_category_remove_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->tasks_category_remove_button);
@@ -953,7 +964,7 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    postpone_time_spinbutton_adj = gtk_adjustment_new (0, 0, 60, 1, 10, 10);
+    postpone_time_spinbutton_adj = gtk_adjustment_new (0, 0, 1440, 1, 10, 0);
     appGUI->opt->postpone_time_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (postpone_time_spinbutton_adj), 1, 0);
     g_signal_connect (G_OBJECT (appGUI->opt->postpone_time_spinbutton), "value-changed",
                       G_CALLBACK (postpone_time_changed_cb), appGUI);
@@ -1000,3 +1011,5 @@ gchar tmpbuf[BUFFER_SIZE];
 
 /*------------------------------------------------------------------------------*/
 
+#endif  /* TASKS_ENABLED */
+
