@@ -28,6 +28,7 @@
 #define CONFIG_FILENAME     "config.xml"
 #define CONFIG_NAME         "osmo_config"
 
+#define MAXNAME             1024
 #define MAXFONTNAME         512
 #define MAXCOLORNAME        128
 #define MAXHELPERCMD        1024
@@ -52,6 +53,8 @@ struct osmo_prefs
     gint        time_format;
     gint        enable_systray;
     gint        start_minimised_in_systray;
+    gint        blink_on_events;
+    gint        ignore_day_note_events;
     gint        run_counter;
     gint        lastrun_date;
     gint        lastrun_time;
@@ -59,6 +62,7 @@ struct osmo_prefs
     gint        hide_tasks;
     gint        hide_contacts;
     gint        hide_notes;
+    gchar       spell_lang[MAXNAME];
     gchar       web_browser[MAXHELPERCMD];
     gchar       email_client[MAXHELPERCMD];
 
@@ -67,6 +71,10 @@ struct osmo_prefs
     gint        fy_window_size_y;
     gint        fy_simple_view;
     gint        fy_alternative_view;
+    gint        cb_window_size_x;
+    gint        cb_window_size_y;
+    gint        ib_window_size_x;
+    gint        ib_window_size_y;
     gint        display_options;
     gint        day_notes_visible;
     gint        timeline_start;
@@ -89,6 +97,7 @@ struct osmo_prefs
     gint        strikethrough_past_notes;
     gint        ascending_sorting_in_day_notes_browser;
     gint        auxilary_calendars_state;
+    gint        day_note_spell_checker;
     gchar       day_note_marker;
     gint        event_marker_type;
     gint        today_marker_type;
@@ -104,6 +113,18 @@ struct osmo_prefs
     gchar       day_name_font[MAXFONTNAME];
     gchar       calendar_font[MAXFONTNAME];
     gchar       notes_font[MAXFONTNAME];
+	gchar       cal_print_month_name_font[MAXFONTNAME];
+	gchar       cal_print_day_name_font[MAXFONTNAME];
+	gchar       cal_print_day_num_font[MAXFONTNAME];
+	gchar       cal_print_event_font[MAXFONTNAME];
+	gint        cal_print_event_length;
+	gint        cal_print_padding;
+	gint        cal_print_page_orientation;
+	gint        cal_print_tasks;
+	gint        cal_print_birthdays;
+	gint        cal_print_namedays;
+	gint        cal_print_day_notes;
+	gint        cal_print_ical;
 
     /* TASKS */
     gint        tasks_rules_hint;
@@ -116,15 +137,27 @@ struct osmo_prefs
     gint        tasks_pane_pos;
     gint        tasks_sorting_order;
     gint        tasks_sorting_mode;
-    gint        visible_due_date_column;
-    gint        visible_type_column;
-    gint        visible_priority_column;
-    gint        visible_category_column;
+    gint        tsk_visible_due_date_column;
+    gint        tsk_visible_type_column;
+    gint        tsk_visible_priority_column;
+    gint        tsk_visible_category_column;
     gint        tasks_addedit_win_x;
     gint        tasks_addedit_win_y;
     gint        tasks_addedit_win_w;
     gint        tasks_addedit_win_h;
     gint        postpone_time;
+	gint        tasks_column_idx_0;
+	gint        tasks_column_idx_0_width;
+	gint        tasks_column_idx_1;
+	gint        tasks_column_idx_1_width;
+	gint        tasks_column_idx_2;
+	gint        tasks_column_idx_2_width;
+	gint        tasks_column_idx_3;
+	gint        tasks_column_idx_3_width;
+	gint        tasks_column_idx_4;
+	gint        tasks_column_idx_4_width;
+	gint        tasks_column_idx_5;
+	gint        tasks_column_idx_5_width;
     gchar       due_today_color[MAXCOLORNAME];
     gchar       due_7days_color[MAXCOLORNAME];
     gchar       past_due_color[MAXCOLORNAME];
@@ -138,9 +171,9 @@ struct osmo_prefs
     gint        contacts_pane_pos;
     gint        contacts_rules_hint;
     gint        photo_width;
-    gint        visible_age_column;
-    gint        visible_birthday_date_column;
-    gint        visible_zodiac_sign_column;
+    gint        cnt_visible_age_column;
+    gint        cnt_visible_birthday_date_column;
+    gint        cnt_visible_zodiac_sign_column;
     gint        contacts_sorting_order;
     gint        contacts_sorting_mode;
     gint        contacts_addedit_win_x;
@@ -159,6 +192,12 @@ struct osmo_prefs
     gint        contacts_import_win_h;
     gint        contacts_birthdays_win_w;
     gint        contacts_birthdays_win_h;
+	gint        contacts_column_idx_0;
+	gint        contacts_column_idx_0_width;
+	gint        contacts_column_idx_1;
+	gint        contacts_column_idx_1_width;
+	gint        contacts_column_idx_2;
+	gint        contacts_column_idx_2_width;
     gchar       contact_tag_color[MAXCOLORNAME];
     gchar       contact_link_color[MAXCOLORNAME];
     gchar       contact_name_font[MAXFONTNAME];
@@ -180,6 +219,17 @@ struct osmo_prefs
     gint        notes_comp_ratio;
     gint        notes_sorting_order;
     gint        notes_sorting_mode;
+    gint        nte_visible_type_column;
+    gint        nte_visible_category_column;
+    gint        nte_visible_last_changes_column;
+	gint        notes_column_idx_0;
+	gint        notes_column_idx_0_width;
+	gint        notes_column_idx_1;
+	gint        notes_column_idx_1_width;
+	gint        notes_column_idx_2;
+	gint        notes_column_idx_2_width;
+	gint        notes_column_idx_3;
+	gint        notes_column_idx_3_width;
     gint        remember_category_in_notes;
     gint        current_category_in_notes;
     gint        use_system_date_in_notes;
