@@ -41,9 +41,8 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_BUTTON_CLOSE,            (gchar*) N_("Close"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_CANCEL,           (gchar*) N_("Cancel"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_JUMPTO,           (gchar*) N_("Jump to"),                      0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_BUTTON_CONTACTS_EXPORT,  (gchar*) N_("Export"),                       0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_BUTTON_CONTACTS_IMPORT,  (gchar*) N_("Import"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_EDIT,             (gchar*) N_("Edit"),                         0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_BUTTON_DOWN,             (gchar*) N_("Go Down"),                      0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_INFO,             (gchar*) N_("Info"),                         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_INSERT_TIMELINE,  (gchar*) N_("Insert"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_NEXT_YEAR,        (gchar*) N_("Next year"),                    0, 0, TRANSLATION_DOMAIN },
@@ -58,22 +57,32 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_BUTTON_TODAY,            (gchar*) N_("Today"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_YES,              (gchar*) N_("Yes"),                          0, 0, TRANSLATION_DOMAIN },
 
-    { (gchar*) OSMO_STOCK_SYSTRAY_BIRTHDAY,        (gchar*) N_("Birthday"),                     0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_SYSTRAY_NORMAL,          (gchar*) "Osmo",                             0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_SYSTRAY_TASK,            (gchar*) N_("Task"),                         0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_SYSTRAY_NOTE,            (gchar*) N_("Note"),                         0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_SYSTRAY_MENU_CALENDAR,   (gchar*) N_("Calendar"),                     0, 0, TRANSLATION_DOMAIN },
 
     { (gchar*) OSMO_STOCK_ABOUT,                   (gchar*) N_("About"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CALENDAR,                (gchar*) N_("Calendar"),                     0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CLOSE,                   (gchar*) N_("Close"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CALCULATOR,              (gchar*) N_("Calculator"),                   0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDIT_NOTE,               (gchar*) N_("Edit day note"),                0, 0, TRANSLATION_DOMAIN },
+
+#ifdef CONTACTS_ENABLED
     { (gchar*) OSMO_STOCK_CONTACTS_ADD,            (gchar*) N_("Add contact"),                  0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_BIRTHDAYS,      (gchar*) N_("Show birthdays"),               0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_EDIT,           (gchar*) N_("Edit contact"),                 0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_EXPORT,         (gchar*) N_("Export contacts"),              0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_IMPORT,         (gchar*) N_("Import contacts"),              0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_CONTACTS_MAP_LOCATION,   (gchar*) N_("Contact map location"),         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_REMOVE,         (gchar*) N_("Remove contact"),               0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_BUTTON_CONTACTS_EXPORT,  (gchar*) N_("Export"),                       0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_BUTTON_CONTACTS_IMPORT,  (gchar*) N_("Import"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS,                (gchar*) N_("Contacts"),                     0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_EDIT_NOTE,               (gchar*) N_("Edit day note"),                0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_SYSTRAY_BIRTHDAY,        (gchar*) N_("Birthday"),                     0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_SYSTRAY_MENU_CONTACTS,   (gchar*) N_("Contacts"),                     0, 0, TRANSLATION_DOMAIN },
+#endif /* CONTACTS_ENABLED */
+
+#ifdef NOTES_ENABLED
     { (gchar*) OSMO_STOCK_EDITOR_BOLD,             (gchar*) N_("Bold"),                         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_CLEAR,            (gchar*) N_("Clear"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_FIND,             (gchar*) N_("Find"),                         0, 0, TRANSLATION_DOMAIN },
@@ -83,10 +92,19 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_EDITOR_INSERT_SEPARATOR, (gchar*) N_("Insert separator"),             0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_ITALIC,           (gchar*) N_("Italic"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_SAVE,             (gchar*) N_("Save"),                         0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_SPELL_CHECKER,    (gchar*) N_("Toggle spell checker"),         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_STRIKETHROUGH,    (gchar*) N_("Strikethrough"),                0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDITOR_UNDERLINE,        (gchar*) N_("Underline"),                    0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_NOTES_ADD,               (gchar*) N_("Add note"),                     0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_NOTES_EDIT,              (gchar*) N_("Edit note"),                    0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_NOTES_REMOVE,            (gchar*) N_("Remove note"),                  0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_NOTES,                   (gchar*) N_("Notes"),                        0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_SYSTRAY_MENU_NOTES,      (gchar*) N_("Notes"),                        0, 0, TRANSLATION_DOMAIN },
+#endif /* NOTES_ENABLED */
+
     { (gchar*) OSMO_STOCK_FULLYEAR,                (gchar*) N_("Display full-year calendar"),   0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_HELP,                    (gchar*) N_("Help"),                         0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_INFO_HELP,               (gchar*) N_("Help"),                         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_JUMPTO,                  (gchar*) N_("Jump to date"),                 0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_LICENSE,                 (gchar*) N_("License"),                      0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_LIST_INVALID,            (gchar*) N_("Invalid item"),                 0, 0, TRANSLATION_DOMAIN },
@@ -94,24 +112,32 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_NEXT_DAY,                (gchar*) N_("Next day"),                     0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_NEXT_MONTH,              (gchar*) N_("Next month"),                   0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_NEXT_YEAR,               (gchar*) N_("Next year"),                    0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_NOTES_ADD,               (gchar*) N_("Add note"),                     0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_NOTES_EDIT,              (gchar*) N_("Edit note"),                    0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_NOTES_REMOVE,            (gchar*) N_("Remove note"),                  0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_NOTES,                   (gchar*) N_("Notes"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_PREFERENCES,             (gchar*) N_("Preferences"),                  0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_PREV_DAY,                (gchar*) N_("Previous day"),                 0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_PREV_MONTH,              (gchar*) N_("Previous month"),               0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_PREV_YEAR,               (gchar*) N_("Previous year"),                0, 0, TRANSLATION_DOMAIN },
+
+#ifdef TASKS_ENABLED
     { (gchar*) OSMO_STOCK_TASKS_ADD,               (gchar*) N_("Add task"),                     0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_TASKS_EDIT,              (gchar*) N_("Edit task"),                    0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_TASKS_REMOVE,            (gchar*) N_("Remove task"),                  0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_TASKS_PREV_DAY,          (gchar*) N_("Change due date to previous day"), 0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_TASKS_NEXT_DAY,          (gchar*) N_("Change due date to next day"),  0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_TASKS_TYPE_NORMAL,       (gchar*) N_("Normal task"),                  0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_TASKS_TYPE_RECURRENT,    (gchar*) N_("Recurrent task"),               0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_TASKS,                   (gchar*) N_("Tasks"),                        0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_SYSTRAY_TASK,            (gchar*) N_("Task"),                         0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_SYSTRAY_MENU_TASKS,      (gchar*) N_("Tasks"),                        0, 0, TRANSLATION_DOMAIN },
+#endif /* TASKS_ENABLED */
+
     { (gchar*) OSMO_STOCK_TODAY,                   (gchar*) N_("Today"),                        0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_PRINT,                   (gchar*) N_("Print"),                        0, 0, TRANSLATION_DOMAIN }
+
+#ifdef PRINTING_SUPPORT
+    { (gchar*) OSMO_STOCK_PRINT,                   (gchar*) N_("Print"),                        0, 0, TRANSLATION_DOMAIN },
+#endif /* PRINTING_SUPPORT */
+
+	{ (gchar*) OSMO_STOCK_TYPE_NORMAL,              (gchar*) N_("Normal"),                      0, 0, TRANSLATION_DOMAIN },
+	{ (gchar*) OSMO_STOCK_TYPE_ENCRYPTED,           (gchar*) N_("Encrypted"),                   0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_TYPE_RECURRENT,           (gchar*) N_("Recurrent"),                   0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_TYPE_RECURRENT_INACTIVE,  (gchar*) N_("Inactive recurrent"),          0, 0, TRANSLATION_DOMAIN }
 };
 
 const guint8* osmo_stock_item_data[] = {
@@ -121,9 +147,8 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_button_close,
     (const guint8*) osmo_stock_button_cancel,
     (const guint8*) osmo_stock_button_jumpto,
-    (const guint8*) osmo_stock_button_contacts_export,
-    (const guint8*) osmo_stock_button_contacts_import,
     (const guint8*) osmo_stock_button_edit,
+    (const guint8*) osmo_stock_button_down,
     (const guint8*) osmo_stock_button_info,
     (const guint8*) osmo_stock_button_insert_timeline,
     (const guint8*) osmo_stock_button_next_year,
@@ -138,22 +163,32 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_button_today,
     (const guint8*) osmo_stock_button_yes,
 
-    (const guint8*) osmo_stock_systray_birthday,
     (const guint8*) osmo_stock_systray_normal,
-    (const guint8*) osmo_stock_systray_task,
+    (const guint8*) osmo_stock_systray_note,
+    (const guint8*) osmo_stock_systray_menu_calendar,
 
     (const guint8*) osmo_stock_about,
     (const guint8*) osmo_stock_calendar,
     (const guint8*) osmo_stock_close,
     (const guint8*) osmo_stock_calculator,
+    (const guint8*) osmo_stock_edit_note,
+
+#ifdef CONTACTS_ENABLED
     (const guint8*) osmo_stock_contacts_add,
     (const guint8*) osmo_stock_contacts_birthdays,
     (const guint8*) osmo_stock_contacts_edit,
     (const guint8*) osmo_stock_contacts_export,
     (const guint8*) osmo_stock_contacts_import,
+    (const guint8*) osmo_stock_contacts_map_location,
     (const guint8*) osmo_stock_contacts_remove,
+    (const guint8*) osmo_stock_button_contacts_export,
+    (const guint8*) osmo_stock_button_contacts_import,
     (const guint8*) osmo_stock_contacts,
-    (const guint8*) osmo_stock_edit_note,
+    (const guint8*) osmo_stock_systray_birthday,
+    (const guint8*) osmo_stock_systray_menu_contacts,
+#endif /* CONTACTS_ENABLED */
+
+#ifdef NOTES_ENABLED
     (const guint8*) osmo_stock_editor_bold,
     (const guint8*) osmo_stock_editor_clear,
     (const guint8*) osmo_stock_editor_find,
@@ -163,10 +198,19 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_editor_insert_separator,
     (const guint8*) osmo_stock_editor_italic,
     (const guint8*) osmo_stock_editor_save,
+    (const guint8*) osmo_stock_editor_spell_checker,
     (const guint8*) osmo_stock_editor_strikethrough,
     (const guint8*) osmo_stock_editor_underline,
+    (const guint8*) osmo_stock_notes_add,
+    (const guint8*) osmo_stock_notes_edit,
+    (const guint8*) osmo_stock_notes_remove,
+    (const guint8*) osmo_stock_notes,
+    (const guint8*) osmo_stock_systray_menu_notes,
+#endif  /* NOTES_ENABLED */
+ 
     (const guint8*) osmo_stock_fullyear,
     (const guint8*) osmo_stock_help,
+    (const guint8*) osmo_stock_info_help,
     (const guint8*) osmo_stock_jumpto,
     (const guint8*) osmo_stock_license,
     (const guint8*) osmo_stock_list_invalid,
@@ -174,24 +218,31 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_next_day,
     (const guint8*) osmo_stock_next_month,
     (const guint8*) osmo_stock_next_year,
-    (const guint8*) osmo_stock_notes_add,
-    (const guint8*) osmo_stock_notes_edit,
-    (const guint8*) osmo_stock_notes_remove,
-    (const guint8*) osmo_stock_notes,
     (const guint8*) osmo_stock_preferences,
     (const guint8*) osmo_stock_prev_day,
     (const guint8*) osmo_stock_prev_month,
     (const guint8*) osmo_stock_prev_year,
+ 
+#ifdef TASKS_ENABLED
     (const guint8*) osmo_stock_tasks_add,
     (const guint8*) osmo_stock_tasks_edit,
     (const guint8*) osmo_stock_tasks_remove,
     (const guint8*) osmo_stock_tasks_prev_day,
     (const guint8*) osmo_stock_tasks_next_day,
-    (const guint8*) osmo_stock_tasks_type_normal,
-    (const guint8*) osmo_stock_tasks_type_recurrent,
     (const guint8*) osmo_stock_tasks,
+    (const guint8*) osmo_stock_systray_task,
+    (const guint8*) osmo_stock_systray_menu_tasks,
+#endif  /* TASKS_ENABLED */
+
     (const guint8*) osmo_stock_today,
-    (const guint8*) osmo_stock_print
+#ifdef PRINTING_SUPPORT
+    (const guint8*) osmo_stock_print,
+#endif /* PRINTING_SUPPORT */
+
+	(const guint8*) osmo_stock_type_normal,
+	(const guint8*) osmo_stock_type_encrypted,
+    (const guint8*) osmo_stock_type_recurrent,
+    (const guint8*) osmo_stock_type_recurrent_inactive
 };
 
     gtk_stock_add (osmo_stock_items, G_N_ELEMENTS (osmo_stock_items));
