@@ -27,10 +27,13 @@
 #include "calendar_widget.h"
 #include "calendar_utils.h"
 #include "utils.h"
+#include "utils_gui.h"
 #include "options_prefs.h"
 #include "options_gui_tasks.h"
 #include "stock_icons.h"
 
+#ifdef TASKS_ENABLED
+
 /*------------------------------------------------------------------------------*/
 
 gint
@@ -43,7 +46,7 @@ gchar *priority_table[] = {
 gint i;
 
     if (text != NULL) {
-        for(i=0; i<3; i++) {
+        for(i=0; i < 3; i++) {
             if (!strcmp(gettext(priority_table[i]), text)) 
                 break;
         }
@@ -65,7 +68,7 @@ gchar *priority_table[] = {
     N_("Low"), N_("Medium"), N_("High")
 };
 
-	g_return_val_if_fail (index >=0 && index <= 2, NULL);
+	g_return_val_if_fail (index >= LOW_PRIORITY && index <= HIGH_PRIORITY, NULL);
 	return gettext (priority_table[index]);
 }
 
@@ -220,13 +223,13 @@ gint cycles;
 				gtk_list_store_remove (appGUI->tsk->tasks_list_store, iter);
 			} else {
 				gtk_list_store_set (appGUI->tsk->tasks_list_store, iter,
-				                    TA_COLUMN_COLOR, get_date_color (item->due_date_julian, item->due_time, TRUE),
+				                    TA_COLUMN_COLOR, get_date_color (item->due_date_julian, item->due_time, TRUE, appGUI),
 				                    TA_COLUMN_DONE, TRUE, -1);
 			}
 
 		} else {
 			gtk_list_store_set (appGUI->tsk->tasks_list_store, iter,
-			                    TA_COLUMN_COLOR, get_date_color (new_date, new_time, FALSE),
+			                    TA_COLUMN_COLOR, get_date_color (new_date, new_time, FALSE, appGUI),
 			                    TA_COLUMN_DUE_DATE_JULIAN, new_date,
 			                    TA_COLUMN_DUE_DATE, get_date_time_full_str (new_date, new_time),
 			                    TA_COLUMN_DUE_TIME, new_time,
@@ -242,7 +245,7 @@ gint cycles;
 		} else {
 			gtk_list_store_set (appGUI->tsk->tasks_list_store, iter,
 			                    TA_COLUMN_REPEAT_COUNTER, 0,
-			                    TA_COLUMN_COLOR, get_date_color (new_date, new_time, TRUE),
+			                    TA_COLUMN_COLOR, get_date_color (new_date, new_time, TRUE, appGUI),
 			                    TA_COLUMN_DUE_DATE_JULIAN, new_date,
 			                    TA_COLUMN_DUE_DATE, get_date_time_full_str (new_date, new_time),
 			                    TA_COLUMN_DUE_TIME, new_time,
@@ -328,13 +331,13 @@ gboolean repeat, prev_state, next_state;
 
     GUI *appGUI = (GUI *)data;
 
-    text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->tsk->tasks_desc_textview));
-    gui_clear_text_buffer (text_buffer, &titer);
+    text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(appGUI->tsk->tasks_desc_textview));
+    utl_gui_clear_text_buffer (text_buffer, &titer);
 
     if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
 
-        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/edit"), TRUE);
-        gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete"), TRUE);
+        gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/edit"), TRUE);
+        gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete"), TRUE);
 
         gtk_tree_model_get (model, &iter, TA_COLUMN_DESCRIPTION, &text,
                             TA_COLUMN_DUE_DATE_JULIAN, &due_date_julian,
@@ -345,7 +348,8 @@ gboolean repeat, prev_state, next_state;
 
 		if (repeat == TRUE) {
 			prev_state = FALSE;
-			next_state = is_date_in_the_past (due_date_julian, due_time, utl_get_current_julian (), get_seconds_for_today ());
+			next_state = is_date_in_the_past (due_date_julian, due_time, 
+											  utl_get_current_julian (), get_seconds_for_today ());
 		} else {
 			prev_state = next_state = (due_date_julian != 0) ? TRUE : FALSE;
 		}
@@ -374,7 +378,7 @@ gboolean repeat, prev_state, next_state;
                                                           "italic", NULL);
             }
 
-            gtk_text_view_set_buffer(GTK_TEXT_VIEW(appGUI->tsk->tasks_desc_textview), text_buffer);
+            gtk_text_view_set_buffer (GTK_TEXT_VIEW(appGUI->tsk->tasks_desc_textview), text_buffer);
 
             hseparator = gtk_hseparator_new ();
             gtk_widget_show (hseparator);
@@ -447,7 +451,7 @@ TASK_ITEM *item;
 		} else {
 			due_date += value;
 			gtk_list_store_set (appGUI->tsk->tasks_list_store, e_iter,
-			                    TA_COLUMN_COLOR, get_date_color (due_date, due_time, FALSE),
+			                    TA_COLUMN_COLOR, get_date_color (due_date, due_time, FALSE, appGUI),
 			                    TA_COLUMN_DUE_DATE_JULIAN, due_date,
 			                    TA_COLUMN_DUE_DATE, get_date_time_full_str (due_date, due_time), -1);
 		}
@@ -477,12 +481,14 @@ tasks_change_due_date_to_next_day_cb (GtkWidget *widget, gpointer data) {
 
 /*------------------------------------------------------------------------------*/
 
+#ifdef PRINTING_SUPPORT
 void
 tasks_print_visible_items_cb (GtkWidget *widget, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
     tasks_print (appGUI);
 }
+#endif /* PRINTING_SUPPORT */
 
 /*------------------------------------------------------------------------------*/
 
@@ -535,19 +541,28 @@ GtkTreeModel *model;
 
     apply_task_attributes (appGUI);
     cal_set_day_info (appGUI);
+	refresh_tasks (appGUI);
+
+    if (config.save_data_after_modification) {
+        write_tasks_entries (appGUI);
+    }
 }
 
 /*------------------------------------------------------------------------------*/
 
 gchar *
-get_date_color (guint32 julian_day, gint time, gboolean done)
+get_date_color (guint32 julian_day, gint time, gboolean done, GUI *appGUI)
 {
 static gchar due_date_color[MAXCOLORNAME];
 gint current_time;
 gint32 r;
+GdkColor *color;
 
 	current_time = get_seconds_for_today ();
-	g_strlcpy (due_date_color, "black", MAXCOLORNAME);
+
+  	color = &appGUI->main_window->style->text[GTK_STATE_NORMAL];
+    g_snprintf (due_date_color, MAXCOLORNAME, "#%02X%02X%02X", color->red * 256 / 65536,
+                color->green * 256 / 65536, color->blue * 256 / 65536);
 
 	if (julian_day != 0 && done == FALSE) {
 
@@ -590,13 +605,13 @@ gint time;
                            TA_COLUMN_DONE, &done, TA_COLUMN_DUE_DATE_JULIAN, &julian_day, 
                            TA_COLUMN_DUE_TIME, &time, TA_COLUMN_PRIORITY, &priority, -1);
 
-        if (get_priority_index (priority) == 2 && config.tasks_high_in_bold == TRUE) {    /* high priority ? */
+        if (get_priority_index (priority) == HIGH_PRIORITY && config.tasks_high_in_bold == TRUE) {    /* high priority ? */
             gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, 
-                               TA_COLUMN_COLOR, get_date_color (julian_day, time, done), 
+                               TA_COLUMN_COLOR, get_date_color (julian_day, time, done, appGUI), 
                                TA_COLUMN_BOLD, PANGO_WEIGHT_BOLD,-1);
         } else {
             gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, 
-                               TA_COLUMN_COLOR, get_date_color (julian_day, time, done), 
+                               TA_COLUMN_COLOR, get_date_color (julian_day, time, done, appGUI), 
                                TA_COLUMN_BOLD, PANGO_WEIGHT_NORMAL,-1);
         }
 
@@ -615,7 +630,7 @@ guint32 julian_day;
 gchar *category;
 gboolean done, tasks_state;
 
-    n = gui_get_combobox_items(GTK_COMBO_BOX (appGUI->tsk->cf_combobox));
+    n = utl_gui_get_combobox_items(GTK_COMBO_BOX (appGUI->tsk->cf_combobox));
 
     for (i = n-1; i >= 0; i--) {
         gtk_combo_box_remove_text (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), i);
@@ -651,7 +666,7 @@ gboolean done, tasks_state;
 
         gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter, 
                             TA_COLUMN_DUE_DATE, get_date_time_full_str (julian_day, due_time), 
-                            TA_COLUMN_COLOR, get_date_color (julian_day, due_time, done),
+                            TA_COLUMN_COLOR, get_date_color (julian_day, due_time, done, appGUI),
                             -1);
     }
 
@@ -675,10 +690,14 @@ gchar tmpbuf[BUFFER_SIZE];
 
 	if (i > 0) {
 		g_snprintf (tmpbuf, BUFFER_SIZE, "<i>%4d %s</i>", i, ngettext ("entry", "entries", i));
+#ifdef PRINTING_SUPPORT
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print"), TRUE);
+#endif /* PRINTING_SUPPORT */
 	} else {
 		g_snprintf (tmpbuf, BUFFER_SIZE, "<i>%s</i>", _("no entries"));
+#ifdef PRINTING_SUPPORT
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print"), FALSE);
+#endif /* PRINTING_SUPPORT */
 	}
 
 	gtk_label_set_markup (GTK_LABEL (appGUI->tsk->n_items_label), tmpbuf);
@@ -697,32 +716,40 @@ const gchar *stock_id;
 
 	gtk_list_store_append (appGUI->tsk->tasks_list_store, &iter);
 
-	gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter, TA_COLUMN_DONE, item->done,
+	gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter,
+	                    TA_COLUMN_DONE, item->done,
 	                    TA_COLUMN_DUE_DATE_JULIAN, item->due_date_julian,
 	                    TA_COLUMN_START_DATE_JULIAN, item->start_date_julian,
 	                    TA_COLUMN_DONE_DATE_JULIAN, item->done_date_julian,
 	                    TA_COLUMN_DUE_TIME, item->due_time,
-	                    TA_COLUMN_PRIORITY, item->priority, TA_COLUMN_CATEGORY, item->category,
-	                    TA_COLUMN_SUMMARY, item->summary, TA_COLUMN_DESCRIPTION, item->desc,
-	                    TA_COLUMN_COLOR, get_date_color (item->due_date_julian, item->due_time, item->done),
-	                    TA_COLUMN_ACTIVE, item->active, TA_COLUMN_OFFLINE_IGNORE, item->offline_ignore,
+	                    TA_COLUMN_PRIORITY, item->priority,
+	                    TA_COLUMN_CATEGORY, item->category,
+	                    TA_COLUMN_SUMMARY, item->summary,
+	                    TA_COLUMN_DESCRIPTION, item->desc,
+	                    TA_COLUMN_COLOR, get_date_color (item->due_date_julian, item->due_time, item->done, appGUI),
+	                    TA_COLUMN_ACTIVE, item->active,
+	                    TA_COLUMN_OFFLINE_IGNORE, item->offline_ignore,
 	                    TA_COLUMN_ACTIVE_WARNING, item->active_warning,
-	                    TA_COLUMN_REPEAT, item->repeat, TA_COLUMN_REPEAT_DAY, item->repeat_day,
+	                    TA_COLUMN_REPEAT, item->repeat,
+	                    TA_COLUMN_REPEAT_DAY, item->repeat_day,
 	                    TA_COLUMN_REPEAT_MONTH_INTERVAL, item->repeat_month_interval,
 	                    TA_COLUMN_REPEAT_DAY_INTERVAL, item->repeat_day_interval,
 	                    TA_COLUMN_REPEAT_START_DAY, item->repeat_start_day,
 	                    TA_COLUMN_REPEAT_TIME_START, item->repeat_time_start,
 	                    TA_COLUMN_REPEAT_TIME_END, item->repeat_time_end,
 	                    TA_COLUMN_REPEAT_TIME_INTERVAL, item->repeat_time_interval,
-	                    TA_COLUMN_REPEAT_COUNTER, item->repeat_counter, TA_COLUMN_ALARM_COMMAND, item->alarm_command,
-	                    TA_COLUMN_WARNING_DAYS, item->warning_days, TA_COLUMN_WARNING_TIME, item->warning_time,
+	                    TA_COLUMN_REPEAT_COUNTER, item->repeat_counter,
+	                    TA_COLUMN_ALARM_COMMAND, item->alarm_command,
+	                    TA_COLUMN_WARNING_DAYS, item->warning_days,
+	                    TA_COLUMN_WARNING_TIME, item->warning_time,
+	                    TA_COLUMN_POSTPONE_TIME, item->postpone_time,
 	                    TA_COLUMN_ID, appGUI->tsk->id_counter++,
 	                    -1);
 
     helper = gtk_image_new ();
-    stock_id = (item->repeat == TRUE) ? OSMO_STOCK_TASKS_TYPE_RECURRENT : OSMO_STOCK_TASKS_TYPE_NORMAL;
+    stock_id = (item->repeat == TRUE) ? OSMO_STOCK_TYPE_RECURRENT : OSMO_STOCK_TYPE_NORMAL;
     image = gtk_widget_render_icon (helper, stock_id, GTK_ICON_SIZE_MENU, NULL);
-    gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, TA_COLUMN_TYPE, image,-1);
+    gtk_list_store_set(appGUI->tsk->tasks_list_store, &iter, TA_COLUMN_TYPE, image, -1);
     g_object_unref (image);
 
 	if (item->due_date_julian == 0) {   /* use 'No date' text when due date is 0 */
@@ -778,12 +805,12 @@ gchar *category, *category_cf;
     }
 
     category_cf = gtk_combo_box_get_active_text (GTK_COMBO_BOX (appGUI->tsk->cf_combobox));
-    idx = gui_list_store_get_text_index (appGUI->opt->tasks_category_store, category_cf);
+    idx = utl_gui_list_store_get_text_index (appGUI->opt->tasks_category_store, category_cf);
     g_free (category_cf);
 
     if(idx) {
 
-        if (gui_list_store_get_text_index (appGUI->opt->tasks_category_store, category) == idx) {
+        if (utl_gui_list_store_get_text_index (appGUI->opt->tasks_category_store, category) == idx) {
 
             if(config.hide_completed && done == TRUE) {
                 g_free (category);
@@ -999,6 +1026,32 @@ tasks_selection_activate (gboolean active, GUI *appGUI) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+store_task_columns_info (GUI *appGUI) {
+
+	config.tasks_column_idx_0 = utl_gui_get_column_position (appGUI->tsk->tasks_columns[TA_COLUMN_DONE], 
+															 GTK_TREE_VIEW(appGUI->tsk->tasks_list), MAX_VISIBLE_TASK_COLUMNS, appGUI);
+	config.tasks_column_idx_1 = utl_gui_get_column_position (appGUI->tsk->tasks_columns[TA_COLUMN_TYPE], 
+															 GTK_TREE_VIEW(appGUI->tsk->tasks_list), MAX_VISIBLE_TASK_COLUMNS, appGUI);
+	config.tasks_column_idx_2 = utl_gui_get_column_position (appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE], 
+															 GTK_TREE_VIEW(appGUI->tsk->tasks_list), MAX_VISIBLE_TASK_COLUMNS, appGUI);
+	config.tasks_column_idx_3 = utl_gui_get_column_position (appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY], 
+															 GTK_TREE_VIEW(appGUI->tsk->tasks_list), MAX_VISIBLE_TASK_COLUMNS, appGUI);
+	config.tasks_column_idx_4 = utl_gui_get_column_position (appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY], 
+															 GTK_TREE_VIEW(appGUI->tsk->tasks_list), MAX_VISIBLE_TASK_COLUMNS, appGUI);
+	config.tasks_column_idx_5 = utl_gui_get_column_position (appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY], 
+															 GTK_TREE_VIEW(appGUI->tsk->tasks_list), MAX_VISIBLE_TASK_COLUMNS, appGUI);
+
+	config.tasks_column_idx_0_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 0));
+	config.tasks_column_idx_1_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 1));
+	config.tasks_column_idx_2_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 2));
+	config.tasks_column_idx_3_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 3));
+	config.tasks_column_idx_4_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 4));
+	config.tasks_column_idx_5_width = gtk_tree_view_column_get_width(gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 5));
+}
+
+/*------------------------------------------------------------------------------*/
+
 void 
 gui_create_tasks(GUI *appGUI) {
 
@@ -1016,6 +1069,7 @@ GtkTextBuffer       *text_buffer;
 GError              *error = NULL;
 GtkActionGroup      *action_group = NULL;
 gchar tmpbuf[BUFFER_SIZE];
+gint i, n;
 
  const gchar *ui_info =
 "  <toolbar name=\"toolbar\">\n"
@@ -1026,8 +1080,10 @@ gchar tmpbuf[BUFFER_SIZE];
 "    <separator name=\"sep2\" />\n"
 "    <toolitem name=\"prev_day\" action=\"prev_day\" />\n"
 "    <toolitem name=\"next_day\" action=\"next_day\" />\n"
+#ifdef PRINTING_SUPPORT
 "    <separator name=\"sep3\" />\n"
 "    <toolitem name=\"print\" action=\"print\" />\n"
+#endif /* PRINTING_SUPPORT */
 "  </toolbar>\n";
 
 GtkActionEntry entries[] = {
@@ -1036,7 +1092,16 @@ GtkActionEntry entries[] = {
   { "delete", OSMO_STOCK_TASKS_REMOVE, _("Remove task"), NULL, _("Remove task"), NULL },
   { "prev_day", OSMO_STOCK_TASKS_PREV_DAY, _("Change due date to previous day"), NULL, _("Change due date to previous day"), NULL },
   { "next_day", OSMO_STOCK_TASKS_NEXT_DAY, _("Change due date to next day"), NULL, _("Change due date to next day"), NULL },
+#ifdef PRINTING_SUPPORT
   { "print", OSMO_STOCK_PRINT, _("Print visible tasks list"), NULL, _("Print visible tasks list"), NULL },
+#endif /* PRINTING_SUPPORT */
+};
+
+gint columns_order[MAX_VISIBLE_TASK_COLUMNS];
+
+gint ta_columns[MAX_VISIBLE_TASK_COLUMNS] = { 
+		TA_COLUMN_DONE, TA_COLUMN_TYPE, TA_COLUMN_DUE_DATE,
+		TA_COLUMN_PRIORITY, TA_COLUMN_CATEGORY, TA_COLUMN_SUMMARY 
 };
 
 guint n_entries = G_N_ELEMENTS (entries);
@@ -1073,7 +1138,6 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_ui_manager_ensure_update (appGUI->tsk->tasks_uim_widget);
 
     gtk_toolbar_set_style (appGUI->tsk->tasks_toolbar, GTK_TOOLBAR_ICONS);
-    gtk_toolbar_set_tooltips (appGUI->tsk->tasks_toolbar, config.enable_tooltips);
 
     /*-------------------------------------------------------------------------------------*/
     /* assign callbacks */
@@ -1088,8 +1152,10 @@ guint n_entries = G_N_ELEMENTS (entries);
                       G_CALLBACK(tasks_change_due_date_to_prev_day_cb), appGUI);
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_day")), "clicked", 
                       G_CALLBACK(tasks_change_due_date_to_next_day_cb), appGUI);
+#ifdef PRINTING_SUPPORT
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print")), "clicked", 
                       G_CALLBACK(tasks_print_visible_items_cb), appGUI);
+#endif /* PRINTING_SUPPORT */
 
     /*-------------------------------------------------------------------------------------*/
 
@@ -1097,7 +1163,9 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete"), FALSE);
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_day"), FALSE);
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_day"), FALSE);
+#ifdef PRINTING_SUPPORT
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/print"), FALSE);
+#endif /* PRINTING_SUPPORT */
 
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
@@ -1173,12 +1241,12 @@ guint n_entries = G_N_ELEMENTS (entries);
 	                                    G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_BOOLEAN,
 	                                    G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_INT,
 	                                    G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,
-	                                    G_TYPE_INT, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT);
+	                                    G_TYPE_INT, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT);
 
-    appGUI->tsk->tasks_filter = gtk_tree_model_filter_new(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), NULL);
-    gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter), 
-                                            (GtkTreeModelFilterVisibleFunc)tasks_list_filter_cb, 
-                                            appGUI, NULL);
+	appGUI->tsk->tasks_filter = gtk_tree_model_filter_new (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), NULL);
+	gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (appGUI->tsk->tasks_filter),
+	                                        (GtkTreeModelFilterVisibleFunc) tasks_list_filter_cb,
+	                                        appGUI, NULL);
 
     appGUI->tsk->tasks_sort = gtk_tree_model_sort_new_with_model(GTK_TREE_MODEL(appGUI->tsk->tasks_filter));
 
@@ -1205,15 +1273,21 @@ guint n_entries = G_N_ELEMENTS (entries);
                              "active", TA_COLUMN_DONE,
                              NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_DONE]);
+	gtk_tree_view_column_set_reorderable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_DONE]), TRUE);
+	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_DONE]), TRUE);
+    gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_DONE]), GTK_TREE_VIEW_COLUMN_FIXED);
 
-    g_signal_connect (renderer, "toggled", G_CALLBACK (done_toggled), appGUI);
+	g_signal_connect (renderer, "toggled", G_CALLBACK (done_toggled), appGUI);
 
     renderer = gtk_cell_renderer_pixbuf_new();  /* icon */
-    appGUI->tsk->tasks_columns[TA_COLUMN_TYPE]  = gtk_tree_view_column_new_with_attributes(_("Type"), 
-                             renderer, 
-                             "pixbuf", TA_COLUMN_TYPE, 
+    appGUI->tsk->tasks_columns[TA_COLUMN_TYPE]  = gtk_tree_view_column_new_with_attributes(_("Type"),
+                             renderer,
+                             "pixbuf", TA_COLUMN_TYPE,
                              NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_TYPE]);
+	gtk_tree_view_column_set_reorderable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_TYPE]), TRUE);
+	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_TYPE]), TRUE);
+    gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_TYPE]), GTK_TREE_VIEW_COLUMN_FIXED);
 
     renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE] = gtk_tree_view_column_new_with_attributes(_("Due date"),
@@ -1223,8 +1297,54 @@ guint n_entries = G_N_ELEMENTS (entries);
                               "foreground", TA_COLUMN_COLOR,
                               "weight", TA_COLUMN_BOLD,
                               NULL);
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE], config.visible_due_date_column);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE], config.tsk_visible_due_date_column);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE]);
+	gtk_tree_view_column_set_reorderable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE]), TRUE);
+	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE]), TRUE);
+    gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE]), GTK_TREE_VIEW_COLUMN_FIXED);
+
+    renderer = gtk_cell_renderer_text_new();
+    appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY] = gtk_tree_view_column_new_with_attributes(_("Priority"),
+                              renderer,
+                              "text", TA_COLUMN_PRIORITY,
+                              "strikethrough", TA_COLUMN_DONE,
+                              "foreground", TA_COLUMN_COLOR,
+                              "weight", TA_COLUMN_BOLD,
+                              NULL);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY], config.tsk_visible_priority_column);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY]);
+	gtk_tree_view_column_set_reorderable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY]), TRUE);
+	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY]), TRUE);
+    gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY]), GTK_TREE_VIEW_COLUMN_FIXED);
+
+    renderer = gtk_cell_renderer_text_new();
+    appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY] = gtk_tree_view_column_new_with_attributes(_("Category"),
+                              renderer,
+                              "text", TA_COLUMN_CATEGORY,
+                              "strikethrough", TA_COLUMN_DONE,
+                              "foreground", TA_COLUMN_COLOR,
+                              "weight", TA_COLUMN_BOLD,
+                              NULL);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY], config.tsk_visible_category_column);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY]);
+	gtk_tree_view_column_set_reorderable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY]), TRUE);
+	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY]), TRUE);
+    gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY]), GTK_TREE_VIEW_COLUMN_FIXED);
+
+    renderer = gtk_cell_renderer_text_new();
+    g_object_set (G_OBJECT(renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
+    gtk_cell_renderer_set_fixed_size (renderer, 0, -1);
+    appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY] = gtk_tree_view_column_new_with_attributes(_("Summary"),
+                              renderer,
+                              "text", TA_COLUMN_SUMMARY,
+                              "strikethrough", TA_COLUMN_DONE,
+                              "foreground", TA_COLUMN_COLOR,
+                              "weight", TA_COLUMN_BOLD,
+                              NULL);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY]);
+	gtk_tree_view_column_set_reorderable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY]), TRUE);
+	gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY]), TRUE);
+    gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY]), GTK_TREE_VIEW_COLUMN_FIXED);
 
     renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE_JULIAN] = gtk_tree_view_column_new_with_attributes(NULL,
@@ -1270,41 +1390,6 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DONE_DATE_JULIAN], FALSE);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_DONE_DATE_JULIAN]);
 
-    renderer = gtk_cell_renderer_text_new();
-    appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY] = gtk_tree_view_column_new_with_attributes(_("Priority"),
-                              renderer,
-                              "text", TA_COLUMN_PRIORITY,
-                              "strikethrough", TA_COLUMN_DONE,
-                              "foreground", TA_COLUMN_COLOR,
-                              "weight", TA_COLUMN_BOLD,
-                              NULL);
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY], config.visible_priority_column);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_PRIORITY]);
-
-    renderer = gtk_cell_renderer_text_new();
-    appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY] = gtk_tree_view_column_new_with_attributes(_("Category"),
-                              renderer,
-                              "text", TA_COLUMN_CATEGORY,
-                              "strikethrough", TA_COLUMN_DONE,
-                              "foreground", TA_COLUMN_COLOR,
-                              "weight", TA_COLUMN_BOLD,
-                              NULL);
-    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY], config.visible_category_column);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY]);
-
-    renderer = gtk_cell_renderer_text_new();
-    g_object_set (G_OBJECT(renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
-    gtk_cell_renderer_set_fixed_size (renderer, 0, -1);
-    appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY] = gtk_tree_view_column_new_with_attributes(_("Summary"),
-                              renderer,
-                              "text", TA_COLUMN_SUMMARY,
-                              "strikethrough", TA_COLUMN_DONE,
-                              "foreground", TA_COLUMN_COLOR,
-                              "weight", TA_COLUMN_BOLD,
-                              NULL);
-    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_SUMMARY]);
-
-
     renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_DESCRIPTION] = gtk_tree_view_column_new_with_attributes(_("Description"),
                               renderer,
@@ -1441,6 +1526,14 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_WARNING_TIME], FALSE);
     gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_WARNING_TIME]);
 
+	renderer = gtk_cell_renderer_text_new ();
+    appGUI->tsk->tasks_columns[TA_COLUMN_POSTPONE_TIME] = gtk_tree_view_column_new_with_attributes (NULL,
+                              renderer,
+                              "text", TA_COLUMN_POSTPONE_TIME,
+                              NULL);
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_POSTPONE_TIME], FALSE);
+    gtk_tree_view_append_column (GTK_TREE_VIEW (appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_POSTPONE_TIME]);
+
     renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[TA_COLUMN_ID] = gtk_tree_view_column_new_with_attributes(NULL,
                               renderer,
@@ -1449,6 +1542,40 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_ID], FALSE);
     gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_ID]);
 
+	/* restore columns order */
+
+	columns_order[0] = config.tasks_column_idx_0;
+	columns_order[1] = config.tasks_column_idx_1;
+	columns_order[2] = config.tasks_column_idx_2;
+	columns_order[3] = config.tasks_column_idx_3;
+	columns_order[4] = config.tasks_column_idx_4;
+	columns_order[5] = config.tasks_column_idx_5;
+
+	n = MAX_VISIBLE_TASK_COLUMNS-1;
+
+	while (n >= 0) {
+		for (i = 0; i < MAX_VISIBLE_TASK_COLUMNS; i++) {
+			if (n == columns_order[i]) {
+				gtk_tree_view_move_column_after(GTK_TREE_VIEW(appGUI->tsk->tasks_list),
+												appGUI->tsk->tasks_columns[ta_columns[i]], NULL);
+				n--;
+			}
+		}
+	}
+
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 0),
+										  config.tasks_column_idx_0_width);
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 1),
+										  config.tasks_column_idx_1_width);
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 2),
+										  config.tasks_column_idx_2_width);
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 3),
+										  config.tasks_column_idx_3_width);
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 4),
+										  config.tasks_column_idx_4_width);
+	gtk_tree_view_column_set_fixed_width (gtk_tree_view_get_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), 5),
+										  config.tasks_column_idx_5_width - 2 * utl_gui_get_sw_vscrollbar_width (top_scrolledwindow));
+
     /* configure list options */
 
     gtk_container_add (GTK_CONTAINER (top_scrolledwindow), appGUI->tsk->tasks_list);
@@ -1488,13 +1615,15 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_box_pack_start (GTK_BOX (appGUI->tsk->panel_hbox), label, FALSE, FALSE, 0);
 
     if (config.default_stock_icons) {
-        close_button = gui_stock_button(GTK_STOCK_CLOSE, FALSE);
+        close_button = utl_gui_stock_button(GTK_STOCK_CLOSE, FALSE);
     } else {
-        close_button = gui_stock_button(OSMO_STOCK_BUTTON_CLOSE, FALSE);
+        close_button = utl_gui_stock_button(OSMO_STOCK_BUTTON_CLOSE, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
     gtk_button_set_relief (GTK_BUTTON(close_button), GTK_RELIEF_NONE);
-    gtk_tooltips_set_tip (appGUI->osmo_tooltips, close_button, _("Close description panel"), NULL);
+	if (config.enable_tooltips) {
+		gtk_widget_set_tooltip_text (close_button, _("Close description panel"));
+	}
     gtk_box_pack_end (GTK_BOX (appGUI->tsk->panel_hbox), close_button, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (close_button), "clicked",
                         G_CALLBACK (panel_close_desc_cb), appGUI);
@@ -1525,4 +1654,5 @@ guint n_entries = G_N_ELEMENTS (entries);
 
 /*------------------------------------------------------------------------------*/
 
+#endif  /* TASKS_ENABLED */
 
