@@ -59,8 +59,15 @@ typedef struct {
 	gchar *alarm_command;
 	gint warning_days;
 	gint warning_time;
+	gint postpone_time;
 } TASK_ITEM;
 
+enum {
+	LOW_PRIORITY = 0,
+	MEDIUM_PRIORITY,
+	HIGH_PRIORITY
+};
+
 void    gui_create_tasks                        (GUI *appGUI);
 void    update_tasks_number                     (GUI *appGUI);
 gint    get_priority_index                      (gchar *text);
@@ -71,8 +78,9 @@ void    show_tasks_desc_panel                   (gboolean enable, GUI *appGUI);
 void    tasks_select_first_position_in_list     (GUI *appGUI);
 void    apply_task_attributes                   (GUI *appGUI);
 void    refresh_tasks                           (GUI *appGUI);
+void    store_task_columns_info                 (GUI *appGUI);
 void    add_item_to_list                        (TASK_ITEM *item, GUI *appGUI);
-gchar*  get_date_color                          (guint32 julian_day, gint time, gboolean done);
+gchar*  get_date_color                          (guint32 julian_day, gint time, gboolean done, GUI *appGUI);
 void    tasks_selection_activate                (gboolean active, GUI *appGUI);
 
 #endif /* _TASKS_H */
